#!/bin/sh

# This is update 001 for teTeX-0.4.
#
# What this script does:
#
# - fix bugs in makeindex and texconfig scripts
# - fix one line in psfonts.map (for pslatex)
# - fix one type1 file for xypic
# - update dc fonts to patchlevel 4
# - update teTeX-FAQ

# This script won't ask any question and overwrite your files in $TEXMF
# and $TETEXDIR/bin. So, if you want to be careful, make a backup first.

# To install it, just run it with a bourne shell, e.g.
#   sh ./update-001.sh

force=false
for i
do
  case "x$i" in
    x-f) force=true;;
  esac
done

: ${TEXMF=`kpsetool -v '$TEXMF'`}
: ${TETEXDIR=`kpsetool -v '$TETEXDIR'`}

test ! -z "$TETEXDIR" || { echo '$TETEXDIR: variable is unset.'; exit 1; }
test -d "$TETEXDIR" || { echo "$TETEXDIR: no such directory."; exit 1; }
test -w "$TETEXDIR" || { echo "$TETEXDIR: no write permission."; exit 1; }
test ! -z "$TEXMF" || { echo '$TEXMF: variable is unset.'; exit 1; }
test -d "$TEXMF" || { echo "$TEXMF: no such directory."; exit 1; }
test -w "$TEXMF" || { echo "$TEXMF: no write permission."; exit 1; }

trap 'cd /; rm -rf $tmp; trap 0; exit 0' 0 1 2 15

tmp=${TMP-/tmp}/inst.tmp.$$
test -d $tmp || mkdir $tmp
cd $tmp || { echo "$tmp: cannot change to that directory"; exit 1; }

if test -d $TEXMF/fonts/source/jknappen/dc; then
  test -w $TEXMF/fonts/source/jknappen/dc || {
    echo "$TEXMF/fonts/source/jknappen/dc: cannot write to this directory."
    exit 1
  }
  test -w $TEXMF/fonts/source/jknappen/tc || {
    echo "$TEXMF/fonts/source/jknappen/tc: cannot write to this directory."
    exit 1
  }
fi

if test -d $TEXMF/fonts/type1/public/xypic; then
  test -w $TEXMF/fonts/type1/public/xypic || {
    echo "$TEXMF/fonts/type1/public/xypic: cannot write to this directory."
    exit 1
  }
fi

files=`(find $TETEXDIR/bin -name makeindex -print 2>/dev/null)`
for i in $files; do if test ! -w $i; then echo "Cannot write to $i."; exit 1; fi; done

files=`(find $TETEXDIR/bin -name texconfig -print 2>/dev/null)`
for i in $files; do if test ! -w $i; then echo "Cannot write to $i."; exit 1; fi; done

files=`(find $TEXMF/dvips -name psfonts.map -print 2>/dev/null)`
for i in $files; do if test ! -w $i; then echo "Cannot write to $i."; exit 1; fi; done

files=$TEXMF/doc/tetex/teTeX-FAQ
if test -f $files; then
  for i in $files; do if test ! -w $i; then echo "Cannot write to $i."; exit 1; fi; done
fi

if test -f $TEXMF/updates.dat; then
  if grep 'Main version number: teTeX-0.4' $TEXMF/updates.dat >/dev/null; then
    :
  else
    echo 'This update requires teTeX-0.4.'
    exit 1
  fi
  if grep 'update 001 for teTeX-0.4' $TEXMF/updates.dat >/dev/null; then
    if $force; then
      :
    else
      echo 'Error: update 001 for teTeX-0.4 already installed.'
      echo 'To force reinstallation, call this script with -f flag.'
      exit 1
    fi
  else
    echo '  update 001 for teTeX-0.4' >> $TEXMF/updates.dat
  fi
else
  cat > $TEXMF/updates.dat <<'end-of-input'
Main version number: teTeX-0.4
Installed updates:
  update 001 for teTeX-0.4
end-of-input
fi

files=`(find $TEXMF/dvips -name psfonts.map -print 2>/dev/null)`
for i in $files; do
  grep '^pcrr8rn' $i >/dev/null || continue
  sed 's/^pcrr8rn.*/pcrr8rn Courier " .85 ExtendFont TeXBase1Encoding ReEncodeFont " <8r.enc/' $i > .tmp_file
  cat .tmp_file > $i
  echo $i
done

uudecode <<'end-of-input'
begin 644 dc.tar.gz
M'XL(`/S)*3(``^Q<^U/;2+:>G_DKNI)PL2>.8_G!PPQ32PB981("%\C>S`XI
M1TAM6R"KM7H`)L[_?K]SNEN634QV)E3NWEI44VE+ZO[Z].GS;C%]%67I\U3E
MB2>?GU]$;AS+Z+GOX;]4U4?]'^[A<AJ-U79;_"#H:LRUPG&:K;80JTUT:S=:
MC54\ZC3;JS^(QGU,_K4K3S,W$>*'1*GLKGY?>___]%H69J.7EI>61<6KBAT5
MCY-@,,R$L['1J=&_J^*W1RH9B-=:/+[4L<$=F^*M2LYDDHEC;WCE)C>,>C(,
M4M$/0BG0QB[>JCZF[9/HB4N9I(&*A%-O<>?#4+JI%(ET?9$-)8]+1:-!#T:R
MGEUG-=P%49K9WS))5*)OW,@'A,>$9=Q9]%4B^GD"J$0$$>Y&;H;Y>*[?50[\
MR!>I&DGA*R\?R2CC]^@+$O&HGLEK48FD]%/QQCV1[YNRRH-W0#YZ=_D&UZ&;
MN".981I,8A_NYHF*I1NA]RC.Z>6^\F42B6,W2L6Q3(*^>*%"7^Q>`\R7OC@X
M"X-_YI(`EHA#O<#'+$$_D$EWZ]'+G>/C%^\/'FWJ=VEP(\5`1M3^&&>/-Y?.
MP#Q?]L5=5T4(["M?&[IU&J9MHG76ZLWUZN;2@`@BI#^<YZU5H'^HB/SQ#%*U
MHH?04`/5-/?--=VV&PN@K@(_&_9<__SQUZ"*^[4%4"GQL=</,@OUQ[/.!XSY
MX]DZ-6@W]*W3,&W[PP(HSXU[)3B"6M5C+(1C6C-#L[$(*I09-KP@"PL4ALV+
MVP509\H?]X:2E.TQ0SDMO8/-=DNW:QJBU6QSVUY=70#EIEX)B:'TT*:%7#50
MCKYOMSMW\&H6JFD@;-LQ4`W=MIN+H/K!8`&4$0H+U5S7"VXW%HGH=1F(V6Z&
M.&TM1\ZJAG8VU@WD(K;#5$!"KX.T$-&V49QULV,;NG4:&LKI+-Q!-YE=X"(H
ML6&H:RUDNQJ-W)XOXVSXV"B.49!6V[2:&M$Q]VN+H'P):2B0",H(`=RQ&6JH
M6M=03G/1`EW/^^("5]?J'4M%::%.$\\74:6R.2B]H+\`E<]B$10OJ-.J.X9'
MS+NU1IVF0`A2;RUB>Q*D\=3\E>R5$55HSGR[`"H+HG')D):AVG\2"NY+SD(5
MMGUMUL9/VT54#8.H=ZZ":&J0#8^<]3E#[-B%+X`:ND$R2Y7E4=O(D]%%8=0:
M>[O(MF=RM`#*^9-07IY<RL?W`B73M.P)"<KLH%4@8YAA/@W4(L7IAVXR1Y69
MO;4QQS,KLHM,'PD[A0)3TV?EJ8"P7MGLZ.J=MGVZBV4H9Q;BZVPGESK=18):
MG>51QR[,VJM%O"*HTBY^*U1I%^^",CN[NHCM21[*'K3'NX@(D13'JJTUS'9'
M#61KD3K[03J<4^>_'#,DKG<AL\?W`'6>9W/2_I>AB.TEN&]:H'0O2EC?"C7#
M]KKQ,(YQ$T[=WFNI;RWT.)>W3)]CY*F(C*UPK%F+L0`J4IDWA+QG4VFWQJ7Y
M97O56:2#"#_F=K"@:M[3?(VJ-'3/YA:X/FOZ6@:J98W-74:F1!E!V=E;<Q%-
ML?`[H2)_*@Q6!V_IGN7=72):8CVQ?<Z6V]"M;:;H+(H9=";A(P<L4@`S^^+V
M#C_8\U22%,(@S((6MW>(Z!S47Z7*C>7U+)3)&HJ=O!4[+&*[NI5:WHIDUF<C
M&6=A+$I43?'^M&4H+GCGW!_(,E7U=4W%'>T"*,XFTI@K&QK*R)%M1?U6"RCH
M6Y1UMU*J4SC-YYY*J<7S/)8).9SN5NMYV]S'>1AVMYSGSOKF$MM'WTTN=*<&
MNOPS1ZS10YB`^RS)Y>;24/:SL;UA<<6KOANFN!VI2*6QZ\GBR:6;!*"F-RB>
MA.JJYT(V$1Q?3`?22I'W(LZ=]ESR0HDD2%YGB=L;R9%*QG@(1LG$S:3PKQ,U
M<J.E)7`NB.(\VUSZOZZ-_2=<_3OJO]??J_[;Y/IO8ZW5ZC2;3:[_KC4>ZK_?
MX^+Z[_6_1_U7'+KPNJ&\E*%X*`;[TK^S"/Q0`WZH`?.0AQKP0PWXH0;\4`,N
M03W4@!]JP%.HAQKP0PWXFZ$>:L#?5`.V[N&A!OQ0`WZH`?_[UH!-M;7Q)ZO!
M]UD._EH]^*'N^W#=V[6X_GN-;`X"=`\UX#OKOX[36%OMV/IOJ]-I4';NK#[4
M?[_+M2Q*&_V?4JW=Y@6K)`!Y+F'$T@O<4,!&!U%`&"E/'JL0L;@IXJ4TT'?C
M3&)U"FRC,BL/U\P19V/QV^E<G7Q:(Z>*.5?(7ZA!GIZ&GSZ[5^(WA.?J*KT(
MQ.E_B7W8Z`MQ-#Y=P<,OC2V*\?.S/+N_RPK`E9N*PS>]EP<OZ_NO1.73Z5G0
M__395[Z;@>+QYYH(ZK*.;?-]9ABXQS)#;*.]/V36`4U2+9ME!F*TLR_Z[B@(
MQU7:)&P/;S*VM7[?JUC^=(IM.^V>IN'2\FFW)-5QHBX#GW:^)`5$]LB]@-\R
ME",+<SU(8N!A9=[012)%,M`5C.8B*I0,$&DQG3S:>32IH7FKFS>Z.=;-/ZB!
M]YT=04\9S4M4FIJ'&,@RI08J@C3HA]OFX>31[J-)78@],#/QH1600_=2!;Y@
M[\I@L3UY2$5EM2G2H<I#'\F-D)'*!\,J[\[(I3E!DG!%J%C#/W[T2)>3E16$
MF7F_KTG+DC'Q!//T@T&>2*'R3)!&00G\8*1W-JUK]N*_B!897KECL!>#@TNH
ME09RTPM>`_:=5=:#]J0BS;VA)KY,^,@=\S9)FABDYQ&OTCT+99W1CHE2;$Q)
M^N:&8Y2;IL$@`J$NHMTPES5@!HJ91A8)Z]*4@1\^**6S&LA'C2@LN`L:D@32
MHGO)OIN'4'0Y="\#N,SZ$B,<1)(XB"XC\(`?"9)F;00A.)C4@X5(5!@R-_$X
M#57,H[1(I#P3*#_/4R^'V:P9&+HFE(WT0S>;;(J@/T.*A@G2FDC=<4T\.3V3
MF?NDQGT2F:*+7::^;'\A$1*&M,))Q7EF\:L_3@S")E4"TRE3:4B>THE4`44*
M3`OAT"$U#(#`A@@-:97L,+H88$/>PS<[QSMTRG3XYN6[M[_J7R?\3//Q722O
M88EA8,,QI*O?#SQ:(XB$,`Q`B<CRA#:4A%!+AE83".#_$$^\P#<D9D,W8WK.
M9)I!Q!6KMIL4([3D<3=7I'@)R_#B]*.\";#85`[(FS`2E<>3`#!"NAB!96J$
M%3Q`,F!E/Y)D3`)X($DRCKWV<X_F1&P[GE?,>6&(56J\#N#-2SP,2"XJ;)I4
M0NO+W"#4\I5*R6<`+#IV)\`ZLK,?/Q[\<O!V][78WMG9/3X^.-K;/5Y9J=;%
M=AA2QU0R1$7%6G6J7]"=-`X1QNNE*`Q*,-\@47G,)`:C6"69&R%#T$M+@I&;
M0/Y`@HJ0>HQ9U0&8!;@A%DG;J3P9[4<0V;-.VC;>U(\?(W(*83B&,=)6.H#J
MTUO(8)+6['+-7-B.%.JF(HA-$&F32KX9E,J13)!J>&,]QE)DAR`#H>""K189
MKM!H]&)ZNTO_FG[S@<I46D#SA!]QHCPA]9(E72I4U8R;4=#IN!]+9S43:PK8
MMI6P,&=Y*L*ZB-15Q!24ABM:^E60RG]M02$2QI&",O'.!O%4:&?G=B.S9,Q'
M8S05N,&8WK4FB7T9W8\U-TH(9>/F!RD+F1:4%)X8`IFGEB)>N#4\)0C"E&FL
M*)\<E+=/7W/+)5@V5WK9-G[)5%RL](S<139,9Y=7-M#HW3.]9M8[\TQ+SC$Y
M/V,L%Z@$&=JOF5?&LB:6C>L+;5!?O._H9E4W:[I9I^;5GNZS=W*B?QQQWR/N
M>K16,TA'W/EH@_^E4REJ&.?XS;IN-G2C7QX?__>Z:??XQ\E>@75BG^BN?Z>9
MISI6]A9Y4N;#%?FO@9O`>VN^E_2];'[F=A/Q<&'AB97:H,"OD^A<!=D0&Z/?
M]]`56E#)=.0R)X)L2U*$?;&-Q*:ND*.8=-$NS0%].B4S31OUZ3,VX)73^,P`
M<\_WZ#EO9W5N1;:04[(EUDA;%9UJQ94J\7!&0AL_Q8GLA91.$-I/CM%"/(=2
MS[RH@?-]"GMTX&>TH01F]6)6VTGGR`,A'QQO%MR972=D%.G$Y](2(\H!YN@6
M$Z(55B"4US`PAE*F<_JP9I=?)DP8@YZ2]Q!%9P"0?Z]08B@'\&5IU2I4$$7H
MK]=0-F1Y!JM`,22Y6="FDSX6#?YR!_W9B(\ULV2)4SJ5G4K!G9R:Z@+-@Y0%
MEA9FCR-R$VC,1`Z`(8%6>>3/^7T&^I+OKZ^L%+,D'/P!5H<4%<.O/+(ZE96B
M`6Q$D/;2D;J0R#KV^AP3,A+7`\]TB:`49K.?L<'V1Q[HKU#PIOK0:"@A>UK:
M-]?X:9</SB#0R84UZ_JD?AH:`]DDX(C]ES_?>[K[Z][QR<'1[V2OUL0K><99
M>K=4Z6@T\,YQOOS.T9]V52)%66*$@)#%`G)]572+\M$9F.SG+"6F&^W>Z;Y\
M_^FS28&A^*+9$?O0[5NS-/4LLR:3M(8**)%4N=T&#@CA$29"W/3<[E;ENN=C
M3YZ"I!Y[8VA1K=Z![0.__>JF0$\J@''LP1&G&>O36*K^5(!3?58,J8U[7)-X
M.@5A</)VP&9`:3ROAF.7S&LN5&BZ!HK#OD;NF,FP5ENEU6\A^S;8TPF/%5]?
M!;ON(NHV:Z+*A;,N7DKO]K:UOD4X7NV][NWOO8:]U"BN+79Y*H5Z!EZY\\[^
MB_>.@[XU_#PJ?L'MVI]PUOQ3@^'^^,4>6V,NO8G#@S?;;W''4NB([3CABE-7
ME[R(4(J,;A6]3/2!Y9/I\J>5$E")K!G>55'_A'SP-=Z?C9D!.RJYH`TD?^Y7
M9R$F,$64^_<N9!*E$_URFZL<OLK)Z"1D_6AOC`&<ENTX^.T':3RAF?1S].-'
MCPW4O@O")K3;1@HX(,9^7R/G\8*L</R56YT>3PRM.T:>YV:&M40J;>8YDG'H
M>F078?>4Y^6)C$R,P"$(;&//-;[-WLL)!RDZH.6)B%',2A/M3I27/6JV'5L1
MTK>KN)WQ*K,43'Q%R5SO'V:0N;TQLVF05FL&<PVW&N9+P!$\!'J"9RZ7@'HZ
M?)YPPE)^>L%/SZ3GYCHC,P9!17UPVZ0\!1.U$38FL`,IC/7_%`'F4294H>TG
M:B2\&^E!KD)UZ5[HH$E4O%1[B_JH7]4:6:#8S9K$>=;3O:84[8DK.#V36HJ`
M8I'`DYQ&<AP`3UG(-/)8!:<T#"15IH:!242M,\3FW-3A_PT7;^IL<0P3K\CU
M)I9O-W^<GW\H]^5[W?\+_"Y68`1,N`,X4(IGO#`G_DR<U?4):VBHMY0+E*S+
M&R5V^M1WONQ)2Q@D[J6M9Y:GU*&",7E<B"%KJ,O?7NJ!V8+*^53PQ];&*KQP
M8SY'H`WX+8_TO*QQ7'9-37F>MX++GI."AK/0C6`4QJ,SBND*3;T]#M)K1N6(
M&JA4R^(L/NZMT,0-3!S.[CPE#D%V"X,+@7U=Z+.LK8NWNKIIMLUHH\@\+6EU
M'0L44QB>1IQ-&V(5`Y:GB;D<!",8*E?+O"(^-UOS0!;@"SQ*I!?$B/;@Y8F&
M-;&=#_30DYS"K_FX20L)5^A)0H9!W7X5^[?'3Z=?:OX-29!>JW'.(RCC*!]-
MF4:SM:U'6!4O\B#T,Z+PBR<9*RF;^G1:FX8\JS`W2+A@2DFKN0Z.?^#+DL!+
MZX:*/:3]OJ[(Q'&HW85V=);`*6>YC%TK=#DS\:T&,D[7XW$74L:DW5A4BO#:
M%N$Y&"GMR8P*[.LB.1\$)8JK4.@U/0LPIB+6Q<B)]HV0?M+XYNJ488<Y<\LZ
M?&\HO0O.X'D2>#H$N"Y"?C">3A68*:G,\MC`QJG,?66`G<:S_>W?GS'P#A4Z
M//:95&`(,C=D:1NY%UQ$L#D.D@85\4&&=FPC^!/C5K5L&-)Z3-KDWB/LA=??
M=X^.]P[>BIU?=W=>[[W]Y9YGGEE6I5';0.`HEN>7RT==MF*KDU;?X_\;T?=B
MPYOMWP_>G8CCW9-WA]UIQ\JVV-][?_+N:%<<O!*[[T]VW[[<?8G0K3:]V3[>
MV=NKB>VW+Y'ZO3G8V7ZSLE*]=\K_\'5L]N'[\430&H^VQ>'VT?;^[@D$Y?Y7
M-1=I"KM*L;04])$3ZW264V#$<.0>NN),J9#^A*?\='/FSGSW`BNXN<2GJ=,(
M04S"8!3`>,$$<6$6:LY*WGG>SB<D>73D^H:#<OS:IU_F8)QO7Q?ANBVOS,0T
MNDQ2>`VD[-F<<`.H%(IQ-M'/HV@L*FZ(4#T?P-DE'&33NZIQ>68-B#\Y>"5*
MR<;:I`Z1]H0^&:*_X\FQL!I<$9E=F%NS1)5G*1VB3<[D`#$+C-!$U.MU1(J1
MSW=`,Y6(;$C,C:A[?0FY$<(^3TRYMOG=)/"7W;>[1]MOQ.&[H\.#X]UR0>6^
MS11R(-DG&9*#,7(M,&`+4TQ8CK3OY\*[L>9TAD[;4D/&XB$K,3O(SX@]$_JF
M:QI6[>SH5TOZ0T3]P4/%J;='[G6%_W*@IO^JH:;_)*'Z$W_<6;7]5OGV9_YX
MNTH?:8%6"/:4Z#/ZB[4M.HTPGY&)"G\T_K3>T8-^=NJ=_+&06$U7?\K_<Q/W
M_>#T5'P!#RJ$]</\52I.<TW\Q!Z74B!#DKW%&Z>S7JT*E0"(!S@;SIW]F\UV
MU0R@_L6;+8'XN0K70*R[%49/%[V\O,P%/E#)MJ%X@(BG=QDD$.[20K3YN!%I
MWL=[\81W%9OKYM=!R*=0'+_H,_XI@KB!!K%^8_^5N!K21PL4MX`XG3"9,O"2
MJ.@IKI_0FJ9WX>QM4@5_5%)T'\]T'\]V'Z/[K5TN$P=F+>LO;^C(/DA(+,T[
MN@555FN#H'9^OBG.S[M;SN82+9-.[;O@?%#F#Z4^1,#,DZ?.AR[FL39XX,:Z
MZLUY-!`(%)8DP0\C6.?G6T%`1A=J@;"U;XJ1`:PP21EFQP\>%CQU2$_P&E%_
M8,SF^?E$GS(5Q\)(RH+@0SE!TST^?LRC3*&;]%=69F6#(C"*Q(0-Q\A*ZB#-
ME`CH(55NI@\K7K\N7M;%;EV\1OPWK+&U/=U_]>DS?,U%3<1U!'V=:M=NAL6>
MEZS)S1/V*7ST3Y$]&PU[2J?/4.AXA*K@)D.(87.K2Z)@%H>'4,#0,[M$8?CT
M:U`\$RDEBJ0X@=?;M#^V*DE6@10^2ZK/AW$</^6O:'\</WE^27>D_ILT&(AF
MQ,^Z[9K[[E8!V0_0$_]0!8XW%C\F^NT6>QG]^S%_44,$#BF6IA$S6T&630P#
M_#>`6R'VZ%_,(A=,Q";*A#]O(P<<JBMZ5Z%S=?OI6I'C5FMZ_(0.":&Z=,B?
MFB,7C6JK,Q5H*^3'Y5R?C@7(#YJ#?"XIS"0<5RH)??M9E#[[H0T&U5M&14J!
MAYEHUFI:^Q,GDLXHZ$R+(4KW,T)B&?-$+/-0255_LD3[KT[(QES27QDC3^.M
M>O(S?^[LU\F<=\63[E;IWFS4D[HYXNQN/:$MC@/O`HD+C=YJ=&$*_K>]?W]L
MV[@2AN'^S+\"KRV7I`E0!'B3J#"OTS3=[6[3Y$O<[N[CZ%4@$A)90P0#DA:I
MR,_?_IW;W`"0DATG3;I6&Q.7F<%<SIQSYES3%/O`*PE7DWD^2;4N]^@,6ST*
MDN6*V"5L;S&_'(T1RJ#TF5*]7KRB%^?R%=C,/"J8\J.C<7JU]O.U#Q/A7V9K
MH#&S^=4:IJ%QU#XZ\H^.T+!;<`!-P0\_J`G(\NE\43%^,\%B"I"A=D2)^=!V
M_A@)V;V<95?>-(<3'!ZQ4K0ML(Z\B&F2]G7;)S3?[72\Z7+N36XNMV&'6QHK
M51RV..[?<\EA;V"5A$8:4M<'/'@-19=>ORD-].P&P@A:(*+A\WY&>>8R(=LV
M@F.BP,?DHC+NML-^]R2\/Q.6+6;1M&97MUCLWIL!$WF9)`N7DQ3;+.%$630-
M)`K%="1W7-FR(>KI?5LA,6H8P!P[\YSZ<LSN86KF?[&#!O)U?WWY,[)WSUC8
MK&VX&`'ML;+`$DK;:UN&02O&-NP,ZBL;"6;+12&LK-46R).S0HC,GJ04RT^@
M*;/`IE=$AXCCH.[>(W\N9H)SI;JT98=-O9;VZ)!ST^1$/1SI*T($FE,DJ&5'
M!"\\[@N6"(^[-C;_\-:M,.P9D$4QCW%4F3#09=&>4`OS>`Y@=]W``7"M-P`>
M<-*,MSX?7/:?<WR<G-B;P0S>H1:TS"`@$"CJK$@WF9>A4'*D3T1Z`!]\@@[1
MA9$F.$J4B&:R-UY\<0OLX`7<SO&?C15@@);^,W@/_:1H#V:0QH16\S;8T(NG
M@!=.9_/VYH6-#HQX\T!M%&="[1K*TAJF$R^>^I$C__3W2T.;>[_)6FCO^WE=
M?W%.7VP(B<6Y:,H.<(FW]`P8VM6&`$6)*E%*B7)'LOZ,Q6X!3T#PE9ILB-)8
M@!\\'KHC:/?QX]A[9^LX,Z[Z_UG=:SCR`P%LB\64-:/)#+O.0AP@FR-%7=\#
M.HAM03,`>=-(MLM<&-)9D_A;N=%,KB7P7AA;`92B$IK<R]?B3IRMX2"@CIO`
M7!&CJHZH_!WA2.97P'`UR(8!<.FGG:;8_U!%Z-8?_L-+YZ]9WCU#YEC,'=Z@
MJ2%C!6#YR4"B@31REMTVB9.F<MG5%>"/1L>?!=RMY]B1(+RY:9XQ'TR\,%KW
M>DF<IW.TRF!^0MMF(`,!8]EEFWJ>*"OV@O4%G3RG6`;`;5%?4Y]UE_=:8=`<
M.H(P:%3.!F9*1GR-;30::>OV./)E,'@8:*XO_$;>VA2>-86#A):F\Q4P##MI
M:S7)@=5XK\;L0X`ZM^+>IH,I;DS[(`OS2VB:S%J12]M.X$"P9A6CA<%QN'3J
MN?5G9][MF+3/#01J^.I,W\[6S;-2*[983*:MXCBU@6./0NQXO;D8C1'_/3V3
M]_#HZ6@,K["**EG4LM)+?4*ZG3X=1W!H:%L1:%K%*L]Q%'PTP^_!)YX^+Y7!
M*:8BMZ.QU7RPFN7SQ6ML."A\2"#W&2(-A7QD7E8U,P#>LA=PMO=OYE,*#W#F
MJ:MQ=-Q]A1>(JO'WG#>C$C+1#N+#!HFO\'A`O=SB2;T^GO&ZW`:(^#=H"6*^
MP45&8_X-\$M\Z=\&?$$?\W;2E%6Y!4>5`"5G6&EFDY%S^Z:5M?"01'O8&N<8
MP21H<+LMTVHSL.I2'3C'>"1_4/#%;2#9]_&]U6C+PF,F&H_@,JM=6!+N#\DR
MQM1ZJT$W=6K2:B?/V)"]$=C,W7,RHY,JS:9N4"THE%W'9_PS5F7A*P'5:+9.
M.U0<QH#W#35ZGRK`9L(74)S$A^HA5*"16.N-)UB]W'!^YR7+U9*W^[=!V([Z
MM.Y4!AD6O99ON%1Y_=3D0`_J8V#08/^?J;[636<[IJ/U!IY<\$G5,O,72RMK
M9IDF7<W=)4T=_CO>/^<!]XZ_MQ<^+-`P\*#KE-9>+_:EFG"!_'Q,/RG_G,%#
MJ(4/X2?E'RZ-Y]7M=C3^QS_\^7SDGLY'X]3/>:@>?'"[/3_B433U=P,:]>T,
M;H!HON)>'?D\UB/Y!A_?6?:!YWC/@HL'.@`4TT^E"]R#,?W4CUI[-E?%]K*8
MN=(F*^VPJMXJN18^(I)SYM(JH\@9UXHH$GL&#5MW8X!R+["W;'NH#E#M/DN)
M-HPPF7CK`\/(:^EK9G$<*GF&"E+GR3T>\5=HJ_X&_;6-U?W]+9JY`S_VW>]1
M*61Z;0XGV)AUU@+&C4Y*M$37<&Z:HTLI^R^@".66S;GF\34>P48U%]^7T#W9
M=5,U%"O!]LR!._$8K).`P2RA%;'L:\;3N1RWV)9E0]:Y7"G_D7^X:OZVW?Z1
MKE+&8.E;_K&:!-12;!#M%M^K207/131GAOG($9JN\;=IC6N6X-B4Q162`VA9
M-HU,(_$N;'N(K(@`>H-U>[8)O'+14GHG993S?^K([LX<=GNG.B@02X<#%-U7
M\^STZ:EL,F"-F-FS#PO8P-,FUE\FBS2^A&8;.#<^$9ZSGTV8L/_OW[[Y[.]?
M_!+")?(^4ZY?E[!VV>T*EBE^,X>3!W&AN!H--@C3ID%&CJ,99;0!^\@I?^24
MJSAE3_CBEO>167XLL]QPN.4@/.G\2ECF]$KQS.DX^-=DFAM57#,MP4?6^5^3
M=4;J-5\]FG5N?3C6V=!-S3N;1__BS#,ZZ_PO89_W\\+K66;+HTE;@^)\UMG\
MK^1^__C5RU^`]WWVS+O.LJDG/EX:%Z!"1>EDE).:QPJ%Z?2B219,T\SH==#V
M@P(&&`U/B0%6VW,*7"!49T-J;`15'*@FK.&K,;1_Q@XMR<7M+$N3B\L40W#F
M%TO`J;`NTRDQOP)+`C)*WP8L.T.+T%L+:!I6H.T6&=2UX'O-FC7IHEO59FUC
MY<?#]EW.XTX8/6F.2"'S%/ODV0T1"F31.HQ<]I-,)&\IQ8],I_ZI1=OQGD@L
ML1?C+5%97*+V%CF,EMC_F,YUNT\(Z?)&*+_NP^N.)E@>,"C4.<;1^"'-I>3C
M62L40@L8_A737Y_?G9\Y*#);PRS#O\XF>6:=6.%,.X/57HLQ58*T`\TH<".:
M([#LU3-;J:?T)L]<7:X<A#TQ#T+O1U(839-)3C&S+BDD!3L'LD,@!MV:7Y$-
MT5JK(DD7'Y.QT)GN[UV=##0**C$+K`&>$?S16)2U=$B')?*54CBN'#LP&^,@
M/-H/SA@^;`2DP8C@Y5>"@_Y27WF??_/5M]_^C"A(81PRN&8,DV(X6C_'?YL5
M!VF#1V`!I^/"<>0RS@74\8I8C`,GA3#<//7;<!Y3B,&WD,2YM7<MJF_M5&JJ
MI?>O[&?SM"8G!22\@#/EI+`-`QIB$ZVVH(P2P*=VD1:/O\5%K!.-YE6?`]F7
M,:%NM]V/[I5G.AO$-4R2C/AZ/FG*OEBA6U`2Y^+^B=%UL+1(GS#F@1?#V?N:
MPYNL"M(I]N;Y@^^)&?V_`R*PN&>$5^KF^5B,'\4>V3)487-?L3C>AKZ-M+H1
MX"BS'KY1=`<F"NPYVAE/E+L;>G,YZ%LW%O:&V)KFD*F6[01FJB$.C2S>&OM'
M*.TRN:+(08#Z=.`I9H+$]0%UKX""UO.[F'$#LS:P;BA"P9^1G%H"PN.[!M\U
MV:#7/:QX<%QA#'PDM<BT[T(;W^D&B:73#>+=H0;A_9'4*C98Y.V8I0L8V!*D
MU&CFJU$_ERJ*0M/#4M!?#48KAW;X>:2)9!6+YE#3&PH"A:0O6\(;-&B`>]^;
M`6UY@Z8(,9J8)!1`<9UO;F#O(B%5=$N9C0&WM$PH/AQL1[1\$],IV94WR71$
M.Y_*&7,G:`JW*U(G7[M8XI/OXSK;YZN(&KMD[19(W`*(%58<K@/I'1D]F%YB
MOH-5V_L2MDHFHUK%BQ5M634$+HUV%&15=P4S03P!22]C3\HN$JQ,'A$J@!^_
M7V2+`!_[)@Z(C([0BG@Q2[`^F&?HY*75Q;;W&1J=D)&'MT;W/HK+!<P%VC&3
M7;&*=Q:OYNRJBD$]UN2M@]:!XD(YW>02=@&ZO%)A&;$X-"(Q><DJ70M?"??A
M$@3$*P3$*W`(&`Z>=I7<.IP*[!8=H884!,CGX`;4<=:8S?;)8@4&"B0#9A:#
M`0`N1E"3F&G>_?Q*V<\ADI/KJ_D]IS]!N]MBN"0360)Q*#KKPO^_VNBP/13M
MA>*V.3%9U'%!@@1Y]ZF8U.;W'*ZEC4YUY!]0'2I.`COHV#`^>4>L9[R?[^$H
M>1&WVV+MN?+N+BZI_;N+"0SJ[F**'E#SE7'S2"CN$8]F-?*NYV\2\:_P[J$I
ME!U@+9\CV\##.%W.8GR!\\8W4QX#A@E1M/.>XVM@=0F(@>;&Z,RAV[Y4'@\7
M$^R4\8<@,AKCY"SO-<-IYAMMI-'D*9&0$(VXZ=WKL[VWI(`<8]5-+G)9*C)5
M1:8HK1//9`Q_ZI3C4?AH3G6Q:XYI2%QR6BA)1;8J^D=SK%WRQ:S[,J68C0!T
MZ1L=1BGVOO^>0TW4Z][E7"E7X)@WRZ:^"B!*+N*\!Y8X^'P>4_">&SPWX$36
M>94NZW4SI?)L@L_([P<G7(RS:,K=Z$`^P1RM_AE'[%DB![#"5YI48!OC^Z/O
MTOCF<AI?7![=O\*O^G?PY7/S::O(A(I,H,@$BS#LK39+8`-YO\X0@V'_&/`*
MH_%+0V$?13(!/^I\HGOBZP]^$AZU);IP8NW"(LRCV3(@FSRYVJ3HIDQXUC:-
MU1L,W<6AN3]?6;;0.BXGQ<K:Y%HG*8%)5]#4Z@KMS#AP`P831$Q%U`'1>L%2
MVH+N[[_7D03K3D"FAH:&+^CPA!0".4JXG6.`5:C<-#Z]=F"^4GR\Q\20LU;=
MQ-/S[6!Z$CV+\`+=8-@LN3.5.1@8@*HN8N[L.&'6:_W$;<6.R%45IPMQ\&?`
MI/,"KA(GT)<^<;*7FR)`M`>1*/F6EIE<"?A@;99\E5"P>8DPZ8;18R4GA@O%
M8&YOYK'8LUO+40[PXO-#%7Q(W9<7QVVDO%#F.37C%G=6B!Y8JV2*Z#711>1)
MN35GQ:SB%:NFJI163E=S5\\)&U8=$Z\050\=%`P:(Z\S\AAFP=C4$VJBE9XJ
M-'.#(A^3(PH%.$&'Z*_^\I^??4U^T%=K=N3BK(<8(.&^Z3A#*\>M584;M6\\
MJ!5$&@M_Y%:()R34+;Y@DO.@X!.F^]/\X"&KB5(#FS;=:4!5]M@H7K@@^3@+
M&6+_4DDT)_Z4Y`QT;KN#HQ$Y9>+%W871#$&%<_<)U*,G-79*HT_H>%>X+!C_
M;H6QJ]::R0'B&@>!XA`F03"E0SN<'RDN;\EOE-PD80_<)-S7I?\#2U]C/;L4
M-@E=\5:6$N!>AK.]`,I]!L=L_&V.EYY=$IM=>3]02.3MQ2>=D=>1P_#NXN=T
M(,'9PH`!28J!J-;H3J=L7G@/&"\-X5/XIZZX$/5;]X4;DM_I64W6+O:!T/I,
MQ)'BPK\3GPDVTEOX%\IRX<7=A;^$U29C?V#.EBELG#I`,7$T]UX"C!]2)[1$
M9[3((;H1R*>^=ONZQ,A'T.772`QI;8Q!OWCE4H-J9?G.N#[<7;"-/D:3$?-\
M#'7$R!KP8DKV%FL,0X+^ZK2`9Q(A`&CO!J,B(2_%;0`C6&]^,NX@+N.[>O-3
MX`:1+5FY?(GAK8`/$;!1<^(Y,P1@![S3)E\A2C+3L<PXNG`-"XZ`3Z]#/;FJ
MNV[+^+3=?R4-GFM/X_ARU8"'`3R$7J^S%(@83"M^D:.0$:FZUR_&[?">%8PT
M.!SI"+^NW"3O$'X][('V74:ZMZ#OX5!ICALS8+B!3\)@^HLDSB62-.[>6\+8
MM!@J1AR>0Z&117(=$TZF6$[H7_0F*6U;A-8+X*)YTP($PMK*BK-G,;T$4,1`
M?!Y_"WE7YN9(:C<EX:&$XMNK--QW)J(C4;/9#'CGE#IH.B$]G&`/+[-U8U?U
MP5P)Q1_Q1=F;/QOV4.($!@J#XDN<".%)IK:LY#7,DF$B1];U<Q9+6C&>R_C8
MXFP<3SW-B([,Y7/MGV$,L;RNTI6[]D5P)^+1J-U5[R4VQ,@+VT/EV]<^Y5;%
MM=O(68R5AZHST`Z![;ZHY>D?-%&I')GP6AP\PNTV?M?MM=7EL'W25SJF0K=5
M%R+QNZ[JM=/MJ!V:H19[[<L@K8GSBOV,]/2JWI7Z9;H5MGM]GL\]7>/W\OFF
M?)Z77!\?1MZ6W;&AF'XHK3JE=UQZYY3>J=*5*U+@FAV8*[X<E9YHE;ZU;.7I
M"-MA9#TD74K8[@R49/QTH)9A+]3L[^.\U,=B<5F)?<UK3I_V,P4%6+F1A/$<
M;'U25QB9RZJ)L+9<YZ0T*5&HX#`*>S;PXHNBJY3=77T.>71_=8V1=;VGQQ:H
M#SH%0!\,2J/H*T`?]FRT$?4/KJ@^.;W+E%.%D;G4]DE(@()NFRSCK"]ZY6E[
MMV_J&B/KVOUJ=/B;]JFOXK-&RE(:JE0:N;=JS2K]L]NG0[4\?"+0!0Q>&M3*
M2+0-RZIVXO#D\+HY)]9'C\BI-2K<5\"A0KMZ8/W*3DN?3Z+]!`L1\8,#,D'(
MWV5`NM:H<+_?@[ZC_(6#_J&=\>[]L2N-W%NSX%P6-2F"`+!G!E)&1?H>]%1O
M(ZU.+<'7R*URHJHX&*WS,Q[V5+R4-%/3F&8JH`I'0B)[C-MXAV*#/;%E9O/[
M"I=P8$5;C<9=@&)Q%0]E]0,PKY?9=*>4^,<<]:5M/VLVU4+?_9S'7$N85@B`
M8,ZW9KG))DH%Y&X0'#6-ZDRX<2/OTRT(RRL4%5N12O)$B8J`[-9*7ZA4]9F\
M)HQX=3=4.(41'YQ-"/`//7?**(2_4#)$&SO>%$5/AX?\(GYF/XB'W""4OSX9
MP:F;<=C=/,8S0F)N;=B6=4Y:S$)D`C;TI7\MLYDJ&S2,S5/0`P.PK&.,RZ7P
MV2S+\*@%R.0-)I'1>?[6`%SK&PH=H1S\Q=A#;]!"\+BQ"KO-SRWL*Q4)10F2
M*\68_U3'H1\9\_/_FXYM&,3G8ISS?QOH-%'%0#]W]XLOK:*=S3S-%DUE5F]!
M]VAL2P\;'2OZO]\(K;NFMC2GSOGRV\)CML/)-OD;RBJ;5.(W\S3.45]5V(X?
M=/8'3YKO.,7Y;V>*#2XMS^]\(>+2D7=?&CFJ]9*C>_T53*=$ND*V92`<^5F=
M)O3[+^I5+8Q-7?S:5W][^<4WWA=__+<O<"I%1CD:.S#@X'N-X'7QZ6@<GG1:
M[HD"ZTA2!;L&,[MD(:VH/MN1"96;)'-.T$0G4A$I6;T/;*D&2:3(A/P2FX`:
M(M`9C943R[0%>"JC@I?9>@U(5A5]QQ04Q0P4[YM_@KQMG.03Q=P3UQMD9<F\
M`[L:Z]CM;JXXEE%>UAUX)*&7C]P&6MS):A(@-AK.:0D`VR\\"1D4209=:I2$
MTS'&EFPHA3RV()>ZZJ1<<XH";*L[4[L[^BQD^F,>6:V6FR7Q^)0[U-$J?]R!
MZIILXE[^^Q?>UW_^^U<OO6]??O$UAE;&)V);]?4W7WW^Q1__]LT7DM^4E%9`
MFV[F8IU;S,Y7L)AHNHIJM)>@56'AJ1:LHDR5_#O4DWN12']_7REGO:_KC8)Q
M*PB&4+Y:+5FEV7Q0U'EF-@>TR7")(M0]PM/'-RH2<>FNR'"UTD-)6)N?(K<;
M$;:^`?".KQ/OR1???//5-R.3^6B^5@9)LWB%86LHV%!^G4S_'^]/<PS3Q1XU
MHR=G3CO\S?&3WV-.2"`J:NY^_\1KF(RHQ=>_?](LM"-]M1I2P]C7DKS7325Y
M/DO2I??DRW@'!4W"7S(60$,ZD_8%`>>FW6[KFKH?7^?997R)]!4-P$A5:6I)
M5"$;/^QD7IZ<&1JM+;VYOLZ21KH?>BM:#G92@Z4^$\>^=)QFL+Z79VPNJ>XG
M<B^W4V+)_OS7OUK$0UD;_T1BJ]T?53/S=VR&7`W)9MH8!X6/T@BTE+A`T:93
MI64\Z;#3FIJR>L[.@3D>ZWC>V,,HU>>[DM@&&U>^?*4#NG%,HJ;12I::IB40
M_R>W:4?T46K;D2,T:;76^?Q&IRU3F$O.47@2IZ2F`$ZTEK'FZMJIKZYR<Q!9
MK]O`;\"_*4V**CIVH_TBQX."%!VGRV87;>[X1R00)9<08,%'!<&JQ/\UHH>K
M^=MVF]D%@69[B7EI>)EY+F&IV0S8]#K?T^OI'#@&F\'\@+W,2[W,K5[FTLN<
M)A?G>NR*@1Y_A!FQ?Z_6S2]A/=6XFY94Y8P_A"OX[DRZTWZNVD_=]I_A^1Z3
M7_C&1ELIT7G;N3L;N'R1WZ&$9<X)@8%3HDP.HW''./O)MGWW?@.5DR0W,,4F
MZ2+,S(\&=Q3?H5_B9).G7OA6^%1OM;FD'=/`&?339'%M;9^F53D-`JI`:N95
MTK`KYH6*>=/ID:5^TJ-S?+T^^=0,S@L"F?O?L_ALLIL`4RX6#?<X:=JP%G[?
M4!9.W)KSQ6MOL\`T26BA!POQ6H2HYE2^^F%CI6AMM/O/B;@;1^5>GP]-O,SM
M/CM;R`DH/[<@7[VKR\MZ?D[FA52;7M*>]6570%7]5![F[/>L)+;+C)+GJ("\
M[]UUZOF[HA.19I0%9GY)]%642J&9#"=LWI&A`CG_8F/5[@C&.]J(!)]_V#\Q
MX)RO**N$E7&+Y#B8R),S&?J2L_7D]+C3/^Z<H&U*CIX$%)?VZ[;W5\S<Y7M?
MY_$U>2]_C@F]:`J_Y:1>DO!1!>&G.+A83C).X/[@`Y#$`44I.$I^7NL`)Y38
M)AH<=WK'IY'OA2'T`Z[0](M+F*QCF!CX/IU<<&QJG4V#S4_)"Z'R[WXSN?C<
MK<)?Q7[]<9/D)*#$\UO-S6J&^8W(-]1;Q?C/!OA9X-A(9B7>%VW)"^0(8;DC
M5CX@\:*()3<V;-SY<I.B%3(RDCKX2YZP>>1G-%?<BDP3F:C*R6:9I9A,ZS;F
M7-DYNP[ER0WU!$&1)SM/\!,R+6RHUO:^ICY)=_/Y2FH@%\;N[M,,3S/QS3WE
M>0J')CL8"S<3O8+BP^3*GV&("PJS@*<J*S4#=<(4;7O?2'_3;$T?7JTW5ZQ2
M("M!R3\XG;!IO)W4:VAR<4UT8J7-<BE.E&[O<(U1%22.'U3"D[E572#?-)X@
MW].!X?$4P]D=%CN4TM0H#9CD\AIXGZG90(CD;VKPH@R,D]66P8KDS,5";!`#
M:T=RYI+:R]L3"D8D8_VHWNBTA_U7%*(#"-J;Y-P_50(O5>9PD6T_$I=?[,:9
M9ST/MOUPO.UW`ZL,*N)@`!=DZ3**E"\PAH!V?)(K_B2FPR:0"\P$H+M!CL$P
M'F\LEZ&^ZL*5F3<KRHA7Z(WN`#0T?H<X-BB"0AM2+1?2<Q<V0LZ*HB*B]+L-
MJ_<^12B1SYH8'?#709?F?N3#?T`/QW2OW0QQG.=FIOE#=K,2#056X*X?-EO%
M%>U6%NY"X8@+2]/"V=!5P>VN'R;(7T`-^>TF$L[#'D55-!K38SLNC.E:\6D!
MOFSP(G=5`#%T214H4RZI:%BCX,5K>6]TO"$#U6I9-+['L$*X\B(W[-B>G47X
M.3>M%:H]'FZ:!>!]%,3"V:'?@=?&B[4?YOZ=@(GU-`+NJ-]-S\\,4/?2,?R3
MPS^1-8_P5.:W';W:8CWXY]PND./40NN\I7OI60DL[N`IPT&8\D_.MQV!#GG;
ME<<]^A6&U`(UP^KT.WX_]&$'`*S[_:[?[S4+46"FZU1FJ$&\R/8"X`/%3HP,
M*V"OXA&"C_)BIIIGN!!J+;DQ+$=\<@-Z](._5*3-MV#,AR6G,FR*QU(,,YBP
MV/G-03S^J\?BW9^"BRO_GC'I%3FKRX,!\NL?V(HMF$R,7DEI0'0G\&\6%,;\
MCA'*[+:L`%&5Q$-W&7%!.RQ@:[>/Y<%7T(]WI$)V#*UR7_>3H^@P/5*C>I`@
M!?8(]ZU)L15Y(48@;-BB"W^PL3LTZ5'-[FLQH%0XTI0ACQ^>`K\G`?XEJ:^-
M%LAVUJ*W[?X;:Z**!%>>*L)I1PG#JE9$L8,4TJEF4CK\"Q-*@(?'4DC2*"XW
MF$#Q6>UWYH_./\>K;)-/DN-_O%Y@=(W%\71RK-/9_NXG_X6=SJ#7\W['6[[P
M&_8[T7#H>8.H,^QVPVXTP&>#;O0[K_/3/_WPWP:UN)[WNSS+UH?*/?3^-_KW
MS-,+38(*]+7^/%ON6.V'IV&?#Z;_\23+K[W_9`"I*MBA@I'WURR_3(`%_W8R
MNXWS.R,T(O\Y%5X"PQM-..J!2HQ,.7>A\-?Q>C)+83>FGCQ(*482"LHL'[].
M!Q_<).WU=NW#'7J(JNLDS[.<;]@U>4(]75-A.D=?;7**%C%?L,R*PAU#P?_)
M-NP03\[,TVRR04N56"4/GT[@41OX2Z^!,2I6WE_BE\E_1YAJ'>53,!ZR:R&1
M#PE=<&YYY!S3@KV73*`%4;K\467IK/%R8,I$M"Z\4GFER6:*M!&^Y3!I)>:"
MO5V;3KANEP.:;!9K%?7E9KZ`[ZJ9EA!3*.0!S#"YN(G_<2'O2(B.C^8+\^@4
MVU.5,;_46CMF,_OJ9EHFWC7QKYK,NB+%'1>^XCEJ5N^K_WPBU&I^-?*23P^6
M3B2^!4`7ROY'WE>7JPPS]])D.PU]\FX-_0GGE,1FZ/^>)PQW5\C[/Y$@VCR>
MJW%AB@KCR5[;W;CZ]&#IQX_GZI-W:^CA\6CZ`-\#7B);7B28S(?BF8U1TK?5
M2?"LT!JXRNCV^<-FGB>^I,N\W#&0Q@OTZ%R@"ZUH$]H*`Y`S-\=*PZQ9EV0U
M.XE3S&V.>HM[S$R^PCL=8L:[I?SEP`[6T%J9T^OQ!DCB]88_KX25M[ACT:N0
M?-+(A[A=J[&M*'2/AO(Y=IYV8;*E3/`3SFJL-.><M<M.`&V_`69*3S>B"HX_
M0B%5-NL@NPJF*'[]\HN7G_WIJ[^^!)3VW,>9UG66O`2;)95;9UB42D;M87B"
M<[!(@/,G$X"J):%1L$+?#`075^U.'`KY@-*<-J)VQ^,2"1Q?M)VV,4#U7@,K
M0N=EQ0)I/0(RC@("BH_<,W;U0<_^'-D>[!^X56<8ZH%3I4</_'YR0[C1#(P?
M'.BJ7AH2(G-QM&E/LQBPLU_=:;0EQA@"U&?3!(Q",#E+T!,E3GYX%(47`)DJ
ML?@J!3*U/9-?;S3V))^XSNR\FM^0E'_E!KRX7\%&CQ?WNJ5LD5R0V.#,7([&
MV`8'JN7TTACV(\<X"2NF52J2D?=]6-=-35(,D#%1S;GWIH]F$-+HQ1R#<9X5
M[J%"H3P)\_G@?&;?E`J:`_:9?=@N%M/]HS"JJ[/B@U(%G)4+-(4^,Y>JD&?G
MU,:TENG\FE`/:2:P)*59TVV]QC2^\WAQ$4-=ZZ;<7IXL.9WF"B#1^RY.:NL\
MG@"8`D^Z7@D/\'6.VFA\0@&X5H7H"?EFP=A[.D$$-?X.ZWQ_SW?W=153"N/&
M`/_A)3!I9*P03S"<`E94,#SF`P)55\],`XS^)0J0TK?4:O%FG9%P#`D.\@ZK
MFXQS\M+=,\')!*.P/U51XAITW802B(M*WVTQ,LEN`4%0&33[H@3#/N6C]8%[
M`SA8(C?H`Z"A:_YJQ5?+39KZETG\^@(0^&M\;L$H*7X1'E<^21I\EK'Y-6./
M[XO=[<6U#X._B%?8Q=5K_N35G&*/6'L7/^+C/VVZ6KU.T,F>?]K\@U-"_&>,
M&=V7;$V0K-8T)U!IS,44J.C&QDXKO(NU;\_?V5YV"=.'ME\[F,W=A8HBZP%V
M(9/IBT^0=>"RE%50KNVH"7JV[<G>7?BFM/DJ39=R;\`\N_Z+)LJN&"E0!NTC
M5EJ)D((]&NZ.CM#[7>+QRK+X%"Y3VA+-*[EBEB-8ZN#O.0;67>NHI*0_1S,^
M8'^@EX7W:"Q#DZD:)[]B-H20DC)-1Y_LCHY@.EY$8\R\N#MJN2WY\)J$%B1Y
M>!$&`(N78Q)>O.B@0'$,B[EKTX.C,]VC\=U1`$,7`TFH]RE\@3XS&L,=1W66
ME7C!@K[=4;#GT_RUL$6?YGYT`OUI>N!^&K]M/OU)Z=/T]=V++MQ'9]X=7!B)
MR)$/]<]Y=F"9,-+&W8NH!<=`SEZHOX/H:++),0X<AGPA!>3=4;JG)#R]>$7]
MQ<S.+1,8U"PA!R!]T1GS;\C#HQMH]A^;M0QI^Z+[R1:Z!#,PPIO16.[L684^
M!X_M<[ZGY&/Z3!%1H<^YU66\/LI5CZ7+GT(G`Z?+@729>DWP/,D`F^5G[.\@
M=[QF<HTK4=4-(V%Z$?W(H/<6/MUNM]66>\4M^&@]\R+TH=RY=_XC7`9P*65_
MQ%BVG;?X$)YV@J"Q/?(!UIIXVPT"%D1Y;$(D;I$LCO(:T.:+B!-O6TJ:^6IV
M484X)'@N&MQKG$!WB!@074CQ%ZJH&$BKLGR[#XOP%_E3OON10']%USAS*[SP
M]W_+JC+GT5$Z3$9:"E`,SJ+APTG!IPM6D5@X1[T>:^3!Q<;J10LOSHBUS),W
M%V.Q&<-F&,AU"QH'%%H(2BT@@R\^KKD(*U)ZAY#::``,^ZIRL]U&`)`VFS_2
M1+S%AR_L4@(7%-)U[J[_(ON7A0"OZ'&[2K-E,N6QMM/*T=KDS\?@P,UJFK?,
M5B^B!F)[WXK,#$C&1HAG7AGEG"DJ95.&7#<0"6;M!(B:D"(0=@FP*V=($#I,
MB%Y$J2)%1(,D]C."/)1$D+=@A[`%?@DN$(80:T##OO2$<$>4:^0!(/),JJ/K
MXXH9W&SIX+!058)_4X&[`CJ#CW1\[&F341K*\5]T&*=UJ)Y":H@FWPHZ`[AE
M?":]0?Z%ULU%9PUHNX30JM8Y_U#K'/!"Y]8ZJR6MHH9GBB>PN8]4-1`Q->JT
MG&5NV<N,K`[,4<M>9H[??6"5*?,2K;):9.G%HQ:9W:\.K#-NS/=?YLWR`RXR
M^@"YFU@MK;_V5TUT!?_^^SR[W*S6]3J9AG'(;X^=A^*TQ@;T2PQ+=0$<6?KC
M%##G.B$_66_=;@.%QO5B-A:S2%R,`=D>I0&LKK]Z#MP@7,.:DIT(YGF(+U?L
MU.`5G!J6%]XGGO7VHOG)I]!4^@DV1U;.2XQO5>A"O$9IQQJ[\N/TXBUUAQF1
M"ST;]F3D^R>C.-:\8JQYQ5AS&&LN8\UAK/E[CS7'L>;66/,'QIJ7QDJ!IG"D
MBLK2L$N`$><W#VYY#'J'YKSYC3X#W9-7/9^%<(-+E@R:!*QQ1KN2<;7E?8(;
M'/<U;A5DZU/#_#5P%,BEL=\(['G<'T>X/<)S]@-2VPSJ,:,'%V_MS86,(.\J
MY/E3V%7P%NX8C4/Y%/_)A1FD#QH>$(<7DY5F_%HQW=8W]U<%Y""1-63/0$MV
MU/6J;8E3?[E)+YVY/P)`1,0*K1_E8PUD<%9OIPSP&L@Z..X?.[Z"M+>R_72'
MI1IWE0IBN:.<ZFVI%6KFSIF#=+YXK3Z9XR=QJIW*U#?[PQ2D/HGS@.V/[9CV
M[`G0Z/CL\2?-5D1!E,XVR3U`BA%2OBM\K-W67<79J[D3^N:B.*6$V#"DZY%1
M0`'!.#IJM?MD0C,V1A+9&1`B\^(VV)P=3%_1`VC'66Q"]P(ZV2+].SIJ4'TG
M$84+NCIU1,6.#@D$0TWECU*9AQSI`:Y=8*KC[.@9J9X23!-CSP>G])#>X,8T
M4J21AT@6YSIMTDDIYVO%`_%]SN]2=4U?)_C'EM`"&]K2_#STO\VD@7YROL$?
MJ4>$E<5EJJK3?S94TR/0V"E;7ZSF=PDS)&2B9G$D)G<6+DA#%^;%*(X:R]1-
M(;08NCNJ`^Q3BIK&4=W'I2V/D.WCR"5B1&PF?5;Y\%VEZ+?1'JIVC=G=!?`-
M!VKTG1K(474:UJ>4J=.+L/A42D<-\Q4JS(CXS.!>E,\0EXSS1E:#+SHYG-]#
M^.>HG@L?#CR61NK(+S<='*SL=EYT,%O%BS`A/,M@N([GJ4*@W%,RPU&96J"'
MRBR';L5*)^CU!?.'B/NL;BB#1MR;:G):E)\E(H'#]D47.AZT^QOR"8;1A<?=
M5SOBFKKGBK/LYMH,$LNJA@)CX(@R1_8C;D`G].D0!\:[D:Z['(>NA,,:B)]5
M'6;][H@#$.%E9T0?$$F9C1)R+MUN:]<I=/]NLG]G9:,6QF98+*]+F#@#2.P1
M:)K%*V51*B13/@RQ0*GBFYML\LA=2%&9B.&8,KS_5K8EJK1^_FV)7ZG8EKG>
MEBU[6Z:X+5/<EJDZ-T6IV9>M7W9?ILB#6/W0&]/>3Y1;R=Z8K;T;DT_4W=1L
M3'N'[]V8LEMH7S)1/+@K]?:2#7%'9Y`'=Z79=Y7;LJK5QVU+J_N)Z?\[[4D,
M[/5"'*0R[QG>JAQ\.W%B6[.E`SJ<Z;BX\_CZ`L[)LH^QNJ]./J181!ZZJ;?Y
MD4U2C2R0`C1A7<I+(4J'-C[X='<T(F3+(*8S3>TN$-!K7D/7:EKB>:H*[#KR
M^+H7*+6WBI^3")A*JM,QZP1@VENZTG-V-H7%":RZS>>82.8-`$66-[A6LW0*
MHJG)-H97.C`M_CH[,#/KS)F7=?;@K$@->T[@(W=0%:<$>UPQ0ABBJE<U0#4]
M:K*@,1*AVQ,,,ZR:.*^>$'AX&%@`FGQS@[)3=YI47'=9#?F<OX7_;\N@HR4_
M,E-*XF=-%RMD.>*VV.WLCN`%'D,?`J^'9AJU&D='GVZ/,(`EXBU[F'M@B]`T
ME;96"2>B>J64OF=[\<GV8H2_H_&6HW)O<5(P*+?1^%"[P;OUHO5.O?CT0"^H
M(_;''[TG*=[]$0G;^>I!:,2^[H-(1&[QVD5V>;):9Q0+/L>@)0;C&:$F!^NZ
M*,(QGK+]%_Z+%\RI4.1[`+&;^72:DB'5;7W%H/`B_P0F%$-4JR;PP`S_#^%_
M+U)H(C61##L.2*4`;^FY]>@%2C%>L$UV57-0@W12G9+"`77B"<<(PC58S:=)
MZ3Q'AT%8/[&[1RG*42JI+)F+4CWA0^E%4ZF*CVC?(5L%M`V5@VL4[5I1-Z"P
MU[*LRVEH[*!>_"KAG8`2OJNSGVX6-O5/:A;SR!,\0IMIJX%-`A,"<U9H%/D3
M1Z*$8-8D+%K/N5Y>72VOK.8L19*F\^4*#9&L(S6"$J\#0).*ZG_D;U^@`$HE
MI[K?O5`QEEZ\V)>5ZN[HQ^V+8'M$HIV[%RCU>!'LCMZJ??7BQ5NI+4F'R/IO
M+=[$"]6]&B=C<K^`N3#HXR11X?17L>HNB9(!?W(PJ]&8[I\WJ#--3D^/_-<1
M"CD"]?+HB-[6O.L8N=J1I+TZIM(DDX?2@%$:]"#@M\^Y,&78?8'-CX.('ZG/
M'3?"ECPQ97<OL+$CT[$7)':IIEEDEZRSC/@[?R(I.Y!FL#DQ3,I1_.EW;]#*
M^_)X1Q='/EE94_!_FC).I'3T'?5\W-A^-_BQU7J[:Q[OCJS)/8JWK4LI,SFR
MLK=?^)<7,'<78_C`&=R.X^=Q<'GQ_!(GIQ$_;TQ:K1V%:H"737PS:1[#_.U<
MF+N2Q.:NB)85@"1K%%4>7=LJ2$KBJK5\5=P*JUC&'8TGX$##<L&4C@!\^D!^
M7PPTM*CLK")OY1$=-SJBG`!FM/K4]Z)35Q\)&A(F#TM3&*1F"WO'3ENDU:G#
M>:BCSAN=>NYJC'2_0]2IU-.`RHC/%^J7\)[.5RWVWQG;/EXSQ#;6J8=.03Q2
M%#F@.-"17*,2JCUXA;H8E)PB.P&;'`O;[`2K<T+&]"B\&)%F"DKBMX&/I[KZ
M@#53YRV26Q*;[Q_)L9:%>54GN[H<[;S?>V0E=A'GDW:B#19(E#TA2J-5U0`T
M'1MJX!SF%^#$O#!P<Z;,H31+XLS".<UN.E+'NI046ZZP_I'=QM/;[UDQD^!$
M`)ASLIGVJ=]KJK,1U.#`!T8I]:"4?5;:0@9G:Q)YA%@%P!*(-`,_H!NX4;N$
MMPG@(1KI99PK*-+^=A:UK;O;"![`-H*9PHOP^&1?]?*6JM.,'<GA?0;;*5F8
MC.\<)E*VFMK`"&RL9@UDF_AHS$C2B&:`6U'V1]F9CC6LJ:NJ92$%)9*IDAB\
MJ)MYX\U+8AIX/H9_",V'N.ND;9]^7]1S??9'D:,E@*_)I@I39U.AHQM4/Z=M
MG:*I4=5\`?91,G(YD@.P`5S]_L<?E6VF-J\<C>&CBPNZ/RN!XXMZ\^U;M9%F
M%;BS_.T7M%2R5NQ3Q$NCH1.GS#K4E\`TRUX[)U"E$"H8@Y!"8WLD_`3`*5PV
MT+J[25;BHN$@`9OM&0L0KI>NAN!]-#+B&])Z("XB.6_`UU+MB)&40LI'`,(]
M30C4]DC'`:I/X`K?=RU"@1B4+3^-X2)MKJ,6QC385.**H^3'8.,'JIFWK#6P
M!)JD&S]2TXU3IQ&4:GM_TUH0:II$[,-Z,3PH0?T(ZC?U]E3?,LRY_BQSAC?+
M]>[B?^T*/OL9EW!/VU5K^.Q1BUAS%]%=.FLK&CG93UO'K;U,LC#-EKU`SO(4
M%EJMH/$UAO6+K/5A/(KJ8D>12>O8M=;YT#K"=!W<BR*C=)?/6=U#"TFM[V^<
M"N!*X=%'-R@;LO!-48D>W(N8_QQ1^:Q"LXX+=J<6[.[`QJM;:Z*T#H]8FPI"
M@\XE&"9)D1J<$V2@CI!_(IGG@05L#_H'>>ZZ6AN;@,EHS]Z^M2=(,L<KG>J2
M7%3(YX`/#2Q)46X(E_-KN201'ET]1=V(]E1XM:\"B7'I:C26T-<-:8#"Z+-1
M5E%OCP[RB:1#$Z<88L]@G_!=B[X=;^>KI[YY&IBG!;4Q!S:3*,?0T+8WWI[0
M`0!X\`%R$G`^Z([U.KW:]OQMA,_[X^VP\'R`@]I%X]T`6]CU_-T)LK[A>&>7
MW$7RO#O>]0O/>^>6-('.JK"0$K$-N\<ZAQ-+91?^>!<%=R=T;:D?NS_>]8*[
MB*Y[MH'97?_'NT%PUZ,W`[5GAS_>G01W@[=:X>[,$L<'QZ!>///H):'47AA7
M0MWLU:V'Z@QGUU1X+-(O34N*F'7W5D06$;A"_.EJU>\M(RA`FU;YIIP,M2+*
M4UB,ME0XGIWAHN&*A?Y.*X*[XS"85FVG,/FQV]A&2;`-DZ:_BX)=R+.?B-P2
MWG;A;81ON\$N>GO73<QQRS!WH1_Y)14J'ZI^99--\Q>F;$7;U0H]FL>@.-FX
M)%%Q29J_TNDFT!9;4)YO-?!IAE)._"&I9)4=JVWV`^_([\I<*FA3D2]KO#CZ
MO9KVR'UDSQ/-3$0SXZZ!4:H226SW=1/-ZCF$4T?D"%UPN<UW%9WJ%9Y1P7Y%
MP4&I(&!)Q(FAV&?W:&L.#!BTA[0QG8[N8.ON,.!(B/&G4D"<\%\D%M<T_Z/R
M8+HXF)[6@W+\)#@LJUHP:16U^EAKH&OQT9AJ%2#$[_E]?U"]+7\3@&)A1GL;
M(J`4Y_^?"BC*PKO'(*U!!0&E"-&_'4#AO**;/-V]!_JF-+S,CR8K#TY8?EB'
MS_3J_M`?UD=R#*A$TBJ!;J$%["?TLE"U@/M5U6TTEL49,.,3UI')V0[KX]L`
MU@G_J2MRT+/(0`45**"I=O\6BUCC+\/OD.%76*=>_5P1B2%?`7\TX*NNO^L3
MKQ4&R&X!UN^-&WC3:Q[WY#GT?=>#)_`SK`?0N`I4:+I)@B[7[C),B=JD0&U2
MA]JD:!?<387@]*!`%PO`%[IO[WIB?=FK4_4^O.WAVSY^G^KWJ?Y`U1]"B0&6
M&`:[P=N[H=0?HMWPL)YCD4$>;(<Y%!E`Y[D1>`3O^[DA?!1Z*2<7`9FS8-=_
MBZ;-O=R'[N3G1!ZA5"\G\F@**GZP2XU&N;080MD(RX9UHJ5A'?L4YHY3`1\2
MJC>$/ZS&G?\;]D3XK[DG"!XC`(PP=_8$04XWMV"QFYL]D:L]0=7["@:M/4'U
M!ZH^`#\`O=D34G^8TIZ@C36`;3-,W3U!&ZN?6GL""O73RCV1XIY(>4^H/5JY
M)ZC12.W6$,JB(X[9$]@GC&3VWGN"R`3KKFUFPMX!T)(<_"1HN^$/^%`JYGVW
MP48.RPQ?BIW8B/>:@B@NH_ENH)_<P@Z?!91%A+5=LNHX`[B^-#S4F6:+.%UI
M2?6!T\L'&9?TGX\3AHV1L?ZRPR*Q11JO9N5!<5AO#)+0"*R4@KY]8_0H!\9.
M;)L]SM)ZGA7&;)@^66EKA,[H[,%5#>WR9QX:XT9K'*4U_=F&1IIS=RR=/0/(
M-ZFB.-!9`<+>\>GM&796;39@H9O2OW",J%FZVCG8R4H7R"X%368O$/SXA6%Y
M?>&4TW$HLJB0)48"YY%HI7L-MR*K$GM`I:1CO3&=JHDY-V:Z'B!(;1T,R`X7
M`'"HI4OK`OM`'[D;C`%1VU8O$>)\6^_61;1*ZMR[H?4XQ!;&4-:N#,@9RKOT
M!>G`W0!)!:+5'J)[HBN$UVT<2YI,-:DF0>6CD2X"!%IC%.&!SR]52Q0UVH-2
M\&"&5=;^$VP`(6>@`69`HR_&7BC\ZSH&!7KM0A8>BP$3S*H$3!51C/6N"P#5
M++H(%8YL.&-)$:<](/S`^5C/TVE2-2.'3[$E+Z?P>``[F0*.^^%QKS'34G\R
M)%0U;^;3"PHC=&8NQ^T>SS&>./7DT!/C',6K47@HQ].*HKUR49KB,8I%N^.&
M_GA`XVL^U]Y2&E_EL)PY'W0ZLN9P`D5\QKM?FZ/+;0N5ZAAAU[(=`8J4!NV(
MS$J:`>,XBLC.+J%)BM/(02_H9MQM8`UH#8;!3TS4"ZN']H'%9&EIP%V+:C5A
M<S20C>$[8FE0$JS.*;E="1@WJU*4MW0E/!4\EO<O`1?&7HOS^7J&89B8NHB-
M5;)8;?+$-DZ;SF_8P8W3G1RUCGSO*(!_DO6D77-S!W/+U.C$#WN;IWXT/!YN
MGMJB?WYBB?V;VMRP5'O@5AT4ZG$XQ'6<HNF19]X\I]A,Z$WT]*QB]U2&<TI]
M`/)9/E^\QI+D3$KU,/8F1=G"$9)Y*OOD7>@,PQ)LTDHXC&;<[*;G'&XVY&2#
M,8+QEV)"X46\3+9D/$5ADH]&XZ.VF[]XHO,7JZ-/(:`%J7&L81H;,C,&,0DR
M#ZB#:N]S]F4,!V(NQWR%FVXT#H0C*+3*^B"+:*/<1Q1H6XY>`W71T(L;&TFC
MK<C.\5QHM%7L*K)@HW':DCYP$_)I:\UJWNUHG*N>%ANIZJJSC+?'#3UV+ERR
M'[528?\L$UV5)GO":;+=)-G6["'0M$K@(D-Y<&J;AY>W$@P?M=ZT8%:GWV&A
M'O-1!4[VM/"4SB?6T_GDZ3LN<[)=YS$:=U.LS;%S^_LG\"1O62.A<:1G3P0^
MYM<+5!2KV&R/A@]7KYB]>P.TB.G!37KVN(WYP?:B6@O^#2K:D9R%\PFZ<*GB
M'=LN@.;C+LDS9@@PPKKT%HIA-ZQ/.G78:TK7DFC^%J%ZIE*7<I'+G7?TW?(F
M/*)>V4L<I&-R'W1&.D(`OFV%U(D<?A4%P\>!/`Y46#.G9TO.T,7.ETG*2G!<
M0&P?DT3S;TN_8ZB>+OG-=&G>%.R,@6E`P_;-4O)U6*/%6$L&;8T+:.R,G4E,
MU$DJ7R(KI6KL;T=XD<(@3L?\H_OE>?9&'(TOL^E.&#"AT?)INQ@"@UM-'`<<
M%#@:GP)QYQ1JL,Z8R^QB"706F!ZKF&$M"C-0&MQ9823:\$(B+MOA%KDU]61L
M[5?[:_I]`2EP5DOIN'1YXQ,88G\X!"06)$[!W!5Y!\PH:]FAHJ6PKR+G:-Y"
M&V;[R.;RE>8WFJ8?ERE6S%5_8+-,9A<3^:*^:Y8DOGL*CG#*CC[ICI"=Z:H=
M34+;JA4SF-TG^U;B^WVTU;2ZR#70T'\^@:63JA9(^?%*)5S`N3&Y&'R3B0':
MORY:[OI6EAQ_FD`C?,E33Z&2BKTH3)>VS_5GZJS$AU+_*HWS!'NCG:"I6W1J
MQ=6EDG!!I?</MO`].C_!VOL4I@GKXPW_+J96,SJ+G*J9\>IGY96T>BX=0W:4
M=P,PI"/>V\_A\DP]U59QNA1AQY;TEKV:,_(D'V&HZS4`A13]M'TJ[5FMR06B
M5886#32N),58);G/Q3H)/CM+XC>[BWVUNONJ99F*6-IH]S-^_CQ3LX@IBT7`
MR9-HE^8G!ZJDV6V>K`#&MXTB?#0Q[\"^(O@R<E]60$ZYD(8QLE:L;@2A18./
M@B=5%K]0UTN,=X%Q\SCS5"=,$?7$+E:C/&=U/5%XU]*HB-X3J*E`L>T36]Q`
M'ZDNH#Y&1EFXN`U<R6-\]+3Y''^X-K^3JZ?'JAJ449>X6VZQ#$[DTT#>\G'K
M,DN1,Z(W#FQCI1ELBO8`$`8@>-S:,F><8`C>69XGD9Z2IVYR8V-7R&$+K.#!
M*!UM#X?Z"<.ULGBO+GX21E$_ZI]8E<CO(%[788]'_]^/0;O[%GB<29H`Y4!?
MNIL$NB#A>1%EC#LC^M7^]"Z6**#G$;EVXD/OZ)`/>[;`..,8)`=W]9=_>LED
M_^A3WO)MA%&B%=:]$/TC%<4!SL6(4$3TA;6QKXM-FF+45`F)4!1T`WK!`S4*
M_'C"H;W%_'(T1I]F*'VF1.$7K^C%N7S%&?416D'X^1K#!_IDF4!+##BV<=0F
M6TW/J"45SF+__B/7V37+IRAX<2:'A"HU*QAR10`+%O2I.W:R-GI)9$]T[4_>
M&'UK.="RWD=6-&7%XA`N4M7I9B0_8_MA%5@<)DC$>]3]-QIG\15M+@$$)R[T
M$7E<6=W3=&"?/@/%>X3P.*NBQZ<VI37PS'+O;\*E"6=:Y6#7U1*FD>BQ&I;,
M21&1?1_`W&R434S+K2U@/Y>DY-8CAM>4CDU5G9&0P3#0Q0K!"1`.I459[S@T
M.886Q%\,OB%=B-&E>LW^E:I;UU!_DZ(P4+!`L5W=++.U:PG8JEA="L9W@5FP
M5`4,&E-H0[AI'I(2<I`A)?-:3TE+:!\/_,!^?3XV$VVU$"M>C>L;_@^JFW>%
MRO05>C,:&VZO97T\,`TA3M='0<")ZMAK"V#D\!NY0A$^<:[6.>YQ3"HRXH/.
M-/EDO+K)7B<CI^6.]M=W#G4:T12"6K`8&`]ZXCA[I$.O;S';%\N)U;2[,JSX
M=7*9;3E#)0*6DE1ZNW'';QBVN678YJ:OTH99/+;->FM>VCJ1!!8O'5BSCCD]
MX+.-1NKOFNL+OY'3K\&@Z`N0S^_@/(N:$M6WH-ON+]?^"?W;V%9TDN2GTG30
M@U+<?!I$<NV:G7C;<>H#V5%UMG8OJ>;6'F.ABXHW7ZFV-L\;88M%!>GQIME$
M9F#I;3Q,@91Z>1":@;_;EY!'L#ZGOM=I]V^M$3MM!N%R+>TZ3W'NJ'6[7N6*
MMTP+>]Y;;:E)-0*=3SMFM'F+'SZ'59BULXNF[SQJ]^EA4R*THC@?Y:2:@7:-
M[A%Z82)>K_;`+[8%D`?_NG`&8-`*.W#1/%/="NB>P6\?\%EP8JU>V*$O-&E^
MI])[]1)[`$W32S6R*JAYW&1Q2Z4I?,1L87M`*49C^(>C<EGQ@EE!25.X+BHJ
M$DSUBQN#HS@"^5^?.4M,7@@JIB4%[<YUOIH_)+?$.'S/GZA[\Q6F&T?1XT+E
M'J,&5D\DW"FW@SD%59!3%612I1DL10E`PGKQVQA#N[UG#,;?)R]$`X%ES39K
M#!-"V>.Q7*`B0TA(?G*U\24ROP0"P0AD(WG%H6PQYF=3A^DWT1^U4,P45F^L
MPKH^!^UHYS_RNP"OM<<2A_&W^X-!9:`$%S-19>`)OW]+-P?F(RW/!T=-^6G3
M@>$N4V>$$BBS8CK4&WLZ5'V>CM3,1OK09*14R$Q%:LU$6IH(3!B#L;SWP(>$
M;U*I9=AZZY\%%!9,/`@27,C,@@T/97`HS4)5X.N'9L&'?812,W0A>R^X\*P&
M+'<P,Q&^F:;S=X.C0XU+B[[YSGDEW/%DZEEXM6_Z[7EX?XB$57CQM!2YJ+A0
M4(17R%J<TEXGR2H4+K6&$70H+@U'1T:'`W&T/,?<YJ]V1S@UYSH<E8Z@C&%V
MX%FY[QQ6X:F8T/E3E<U<LM`15W[YR9A(L$,%+N.IU/8:K"2:K[Q%<@V'IS=)
M\XGFUQO;%T\Q?,)3#)T!5_!/VAPW+NT81:C;A1(83`<+MK`*Q8^D1UBCA76M
MF;)-$^0TI8WVU-`>,RZW+@RR-$0<G[RV,M'@T%$WEJ!A2[R@8C0+CQAYX'[T
M)TT$&3CP<>^"3]87^J3S`ZG-=.8<XG0N7OT@@3PPO!0_@@MZ['D</8J?YFNK
M+'JIC.7"*HO"GK%<2&GSO0ND\?R:J#V_-TN@!$L_G(\*2S@:6R\=?:=:V_GD
MJ2@[T1K`#7T_4Z]FZ^*KVZ=:15I\-56OII;>$`_T/_XX-KD8.2W+V[=CE8&1
M5P"V61NJPS_%8-?M4WQJKU:*P>"P&/)@%#H0*G.[<#&FINSR_^__"^5F%!1M
MEMU2MK-+X)>VP)6['5TE-_,+;WS&;4VR-%N@W&'$]Z*BOV!E.EYR\_.K*U:V
M7K(>^')$RDW@&B_&FU5R,9=8A>9IFO'CJ_D9/W&Z*W7&]-$1_(IL[X(Z=.:4
M=5Y95;CO;EGUU;$]FC'V@9.'<C8]'NL9/-]>R(2@Y`XSM3FMX?LQ%Z52SAR-
MU5R=,0G2;=LMQ.EMO%M=X/29CFNHH)R=*N><7<U^KEAS-6>JG//1&F<JEF!_
M&$=\/0<21DPV9UU'HZMG"HS)4VP20X.S>$U""<:`6_$_]W<7-]F;Q(>W%V@X
M0!?9@A^L;_E^/<L3?G*5;<A2R\CJ*UT$`?N]D@;.&^U^R>Q43-YUF7R,AV9)
M&F_'QMGJ(LH6574<!?64C6]"R6GY83)556`(IHIN)(C0@;>@[#\NVL\@@C'?
MQK&?CR.K$?,%#-9Q;W+=4\!]5B5.T40"`Q=1:DQ9&1\3W:J8_-[M#$@&IYBN
MR5Q0KW?6=P$83/->RU+26K.,M1PC6]/5.UV@::Q,K?8KJM'SP+2QUUI7-XT&
MN[JXN:&&BG:\DI:V[!GE#$8%92YUM^(%@IB)1^'"U?]ZL")[7M-S<RO?;_?W
M@Q<O(R(%.ZZG;BSWS:+GYY2%SRL4PU>I;X,#F=9S#Q"5G*=CZR8?FY73$R7%
M9,[;T:NMU;2Y+E1`@V>[OF-G;#T/K!WBW.1!0".R)L$%[-0IP,]R583[4,B6
M8FT"%>=586GRS/T-8.E9BSOR6]A"^U$JR^8I2YJIV@%^&M5BEL`^TF;_Q@%`
M"_8]+SP>V/;QS8\8^3$8^3<%0@^A3]'SDJO$S(0VU+E#/,Z2=)-P\C(O7@%W
M6L+?'U'M+X%J*Y`M.0PI3$L(5O`LO2`$RU>(8N6*D"PO+3_!#LC+*Y1TC&NS
M.H=`M5!)V#D>:A6<DUC#LGIQ79)J)9\D^NK@,1`NSDLUA:AZC5G==6(ZX!'U
M6+^F5WJ6SBN=F5[IN3O\WL(CU25HB2N<H*P/!'=6;\8"+59M_5XV[B.<IJP&
M33X>`H\6JA*#[F,60H5WLON25K36>G1KC$ZMYJ!S=8VJ3)]=ER[[18NFI^SA
M53_W=\XL%=V][!DI.'[5BIY?A8:<#K#!Y2,<PNQ*[39VVWAZE4=D.7X5OJZ=
MP-SGY@&O"SN4.7/+7ZWXKJ"=BF\BCM9N9US;>6>^*LBOY)!VD"(7-YT)HEC:
M;WMVFN+TT/;HO%3(VFRE5X#>W*_NVRB>P#8<*62O%#<"-I56EVYQZ:V]O;>E
M[;UU!A78I=T"O/_=XF.G'X%3M&(OC>T'BICRYE4&K4,GSC;CW\)N91;:V;_X
M=9LC<K<->4A;E7VG"Q4!E&L6K!$;*#'QRE!H0DP6WC&+J!ZKJ,+V=Q,5R=0>
MA,H7JR!89^TIRZ%^)J+["]%1RZ)C,T'1`INO?J2I_VHT]4/+8&S*;)IMN0*]
MCP3U(T$M[!)VW*\DFQB8"2&]<1N<_I-)YL^U5ZHHKV5?9XLO'TMM_P7)[+/J
MX^WF)HTWZRI2RV^(ULHE$EOLC+HEBBLW2IQ8S`E00T@V39TW-GBNA;,W2WZL
MM[2%S%O:!UN[ZGAK%QT+%D>2$&(,11>/[Y'I\%I;S>3C='*QSI.;6*/8G?/1
MG?K,*Z=>ZKO-``A@^DV[JF\7:%H17;*U,VY&$(5Y(2.)5];DGC?<#P:%[M!\
M[=Q&QSNGA;$S,FMV]>YU2CN3ST#8ZK8?*SVS9X/;]YWFFU9*")R1DKS;<(,?
M8?2-\083K(9]4%Z_XB7Q$6[_N7!;@5W96X4@5^D$+'4-T*UU=N.3Y2V",%T@
M`/,%@2Y=$N".:SK>!3YC7T2\0M[@K*8?CDUP2-83/&K@%.>KIMNS7)J8][`#
M'!T/N+0LMNK_>4-7EW"XUGN!%E,B..T4FJ#-9<8F"7FL`@Q.I@3O/OWY\=;^
MU-C2$ZA2HJ"24X"I&4CX2MVT:5BQ^J4ZE(BCY=;9F=>H!V/_5?V8,,+.:I:9
M"EW%W]G]/S?UF'%62Z+@!O4?C="-O]32GLAHH,X:'V-IV$X:UM=,IYHU[_=5
MQ8C1L?NPMZ#L$S.T?27II6]ZT81BAA6_S&[30X3@-[^=J&UT/_F7V%8>!8*S
M]Q:MRMC;L\,>,W&'=N'>UEN/;?W0?C7$U6MYE@CGXR[^:;NXBBPF4S@MQ7L,
M&$CD`"5X$^,%;6*ZX$V,ER3=XRL4[@%;!P`AM4I0RKG6'V'JH%NPE-/Z>4%I
M;9Y;DK13]Q7OK8HZUK$^D#CQ=O?-!TG@9GTF'=^9EZFIIW@?_4XE^]I:']3O
M^70O)?C\;+[><9\1Q`<"M]'Q<!ID=#ZV/LM;P+3L[ZR/GKO-<4<";J5LGJ"[
M028)N@-VC/X]E>3`;)+%\!G<=-/DQ^(,,7=6AZPT3>+V7I%JQ`(/9=(@\@0S
M>4$61"6@T=(?E.(R))0F&"?$L]9O;`&$3D3U+O/EJKD/TE7>CWNWXP?;C?\K
M]^`C"-/#V_1QC12!42N-/F[GQVWG\A1^L/WL*?EI85<_;F4_R,:O(,67Z%Q9
MO?'I%6U[OL)]+U>X-$TM2'%C"+_2]=3>8KFU>56T"N,I-]7&]@-A.V?("^I^
M6"BEQN)P4]LZK)GRE`X&Y_\Q+&B'\R)#SW+3M)@4537>>H?&6Z9Q6^]G!<EP
M;A6[B!RBK0>T)A/AT:DCR(P!TA3*"?[4N3[>&G?_3!),%[C0C!(Z6`TW,4MD
M$0S-Q)O]:.P?[ZP.%+-<.A/KZF+VDRJJLX=Q-`"+'?@5`.V>(T4!E.6`:2#:
M`=S<A6[4EXT;-LP+26H&=C4LI0PGHL<?O0Y"9JT2,O$HZT*G3QH7=:I]%*Q^
M(-50&>2=%=#18N!(@`.V]4*/`^P]X"P:FL<!=146S@!3)Z^K)-SXAD":+A":
M^8*`F=@L5>(\%W%SM94!KH(NVK"CTHC?W">=]ND;BADE%\KSUBG5XJA/?C#0
MO)3J69'',AU5^DN,Q8^<CJXQMKH?5,%I*6JO-LVU6K=;0?SZZ%887LP$>F.O
MP#'97T$M*E+UIK+%@<7MM'MN41Q4J6`5^=9?!>B"N8ZBON%Q=%/\+@C##B=Z
MA9M!Y^V=W2V;T]$0Y@4?[H\2"!?_OOSL\V^^^M;[TU??>%]_\]7G7WS[[9__
M^F_>Y__^V3??>B__Z\^??S$J5/OZLV^_]<*1]Z?/O_K+7[[X_"46?_FG+[W&
MMU#GZZ;WY[]"6U]^]O+/7_VUJF8T\C[_YHO/N-J_?^']VU_^Y^M__]#C?/;,
M#2'J+?,$(R9A4#=ZJV.IFRM8IODDH;<2D`3J)&2U#(^AAY]I-[QEGKV9DZ,G
M.3U/T&,XWR&L`AB@/]_*N\=81JOVS=4]SM_+V1SW6HHVX2M`R2N?PLY1\05:
M<'BWL012A]H<TX8<B[$`ME1[IDS)R;X<H]GZWN5F[=UBC-XT]::9M\K:Y"WX
M90Q@B7'JY2.[;",?F2^64,5TS8NOUN3"++WSO0P^D=_.5_C!S6*)7JS0,6QM
M"1@(QG4;H^\GAI/)-FU)14OA\K#1B^L-X$-*1UL(@08SEL%Z7/O8\YOX-5ZN
M<PH9OYZO4Y@07J@+])/']6`K+(DGZ..FFR]\.W*DKZ)^`MGR[=!=(^%9-.G3
M';N@X'7%(/'HO9GE\PO<U*,Q_GNFG^%W1V/\UWW&9=65>9?D0`-&8_HQ3[7L
MCZ/-T*5Y*T`U&LN%>0,CT"_--729AD13'R^R!<5`I9#'M`@4$F0!2Y+NO'N:
M]WL&(4\M`L73*O]!K<Q'@,+08G4,T?N:(O!MTI2K4L`?M7R5C3SS=@C;W(9J
M(*9:-<]9[W)UV+(9?A;]G#TN!.`/RXX]=X%C-(X&G;`]C,Y450GBV!UX:L,#
M7"_AHP(E>X9,8_;BZ72.(`4[FXHC.Z-K(GQ5U:::M_E\C>%HX5^#%)A&5-<R
M53%'-0!#K.,^<J6:9P,YQ9FLJ)PGTPT50*R084P=(!MK-_%!`;%)'@O_ED'%
MEP33_M1*1FT\W3GPH!.?36X`D[XA.#LSEQA2?IK0YB)&0\>P.UB6`ECBR!EV
M`8HG%S!@7UFU$>&Y-R^)FYS,$EB5*8[['N<)0SS=^X#3XORU\(=P2_G/`=>)
M-^@]H@33$&PU\\4S.>XQ#VH5PB#H<0YH/0.<^?WW]*9>]_#=)J5E6S&.TI/&
M_OPX//\FOC[C>1M7[=$SCZJ6,"?7X3CE9U;,<IB_5;*99G)7>W:/U8OY,S+?
M"A5=%7/.CDE'<6/OI25O!L^2O(U!B^6J_=1[[E&<5U6($2?-)4[8?'6QNHG3
M%&9KB9.5;"=)O@3BD&<WWKWI^[W@8S>FMWQFX\N%Z:5RI=H;I5EJ9,6"3M!L
M*60FI+IT,6"V5#.'9^F=%7ZNLIU""&JIAG,LY0G8/1,B0$PN.4\ZAV!(QB8R
MO$=!!9C\,(FQG]FD2CT7TH,1!C"R`*I+[M7-/9#ME1=?KC!T":T/DH<YH$A$
M'92\)KOREFF,^$?:LXB6;E-WVC!"'&MD;25I4&4,Q=I;3*4KN+5C^6.4_UDQ
MN/_4?L")$"@B#:$;=Z-.YZM)GJR3JKW*.])"2S]M&W[<">^_$Q#&&(X5\U6$
M>\5L5<&^S8B5]H#FQ,ZJH-GAR$P)S6E9/)EY:[-B+FM6#<DU/5!\,R&PTT0&
M:,OE#CB&B1OMVL/\&"JU(+>C<I/,=(CPF?M"ARQN3)T7-076V]T97V!&"KJ@
MN,XKH$IK&#_L?(X&K+F%,Y<SMLY`O'FOLOS#GTOY?W""@;,-]8<V'<;`A=,.
M@.T*7D]5%@]+$L1B%N@8OJ!47-[)"!XXP5ZPCG'.K*IS6EUG,GG@6V&GLJ*)
M[%I9*:RLA-ET#WPIVEN)/U19J5O=O?GU?"W)7ZIJ]2IKJ8#PE57ZE54N80LB
M_[YZ/5]6=W!@UZM)L!O\^V_^$Y[WY0R/O&F:W2('JH/@7"<+V.;KA,[%&E9T
M$]:_P/TE<+R^W#%T+3,F"H6BC[C5G<(++J"^8&K\=^&^V"#=FSNXM6[PVLQ#
MX8^EHYX*`X7;0D>-F]_`<?WB&H-P7KUXR@%@X[C)%^OFN*8X^-4K5/RMPM'X
MR1.\B(`?7N?>"PS_/(?:6SQU%&.8KT?>;AJOXU=4`@/!TP$A_.13J.\]?_%4
MX3#W3]JC'TX$)!B$0D!O;BCHWNK3!A4(PN;(B<#VY7RUHC.'6MLG0)GE)78Y
MCL_XLW9CG^QI[&66P8ETL;.PRK[FXG@TYM'".>9U(H'+8&KI]#$J5*(ZQ1!E
M,.D4#O7C@GR(!>'91Q_Z3Q&IT+AU^^<D\5%GSMD\O?)H0CVZ?A7"W#1VA2I!
MX4$0GC>/&Q5M!^5G6-8T'SVJ^>@=FH_LYKOG"A2M2O@F?%[1G*G7VU<OVEMO
MM=S!4&3.GLM\MZ07S>.HU9`!N^]Z^(X:P&T#C9Q)I$\.#TUK#U@_]#;+=>99
ML\B".HKC^"9.-1SK[@F,6G/$16R@U5\8%]OGUE=+)$`P'MW\[L&6HCT]C=/E
MS&RW[O-&H]`Z]/6Y.QP$E6?E3>AY0;'N^?/&0P/'QJI;:Q5;"TH]V5?UN%'J
M<:FF/4WP(=I1';J^V5@W=_KZX;G$9M1,1H\;>D7W@W+?J4_J[DR^I1Z=(^)S
MQG9L.J(*W^FR#7O%*[]U9[KGMF3/%RY,]]S&5X5)LF;'0_TD3%CH@&_7@*_I
M7V"-ZWFA8"O<`]OZ4]Z^;T7F6Q7P'13!MGE<F-'",A6F#<"\W-5B[Z'1[IG=
MIUZY3]URGZSJC>Y!($ZS2:S$JSP[4/:FA$(TBM+4Q_O4TX")5<Y'5EOXX$PE
MJ5"K#[16ZAJ05E6(ZA/2;9B!ZI<P*]N6&9I^WK1?1/M>A.?.9Q1JMLGIXYD9
MZGER97$N*H@EOH%)WB1G^I%J^<SXP],2G)G\K?GUY6*^,@]43\T3FDO3@%X2
M4P+&:M_LK-)ZHL_/K"X(.%C/>'N?6S5Q#Y_;S<(.<^[OG.*[XE=D\L^IE)Z;
MT9A"D)Z929<'A]F[`MF3W$M%?@XS/0F$C>Q/8KY*Y*9RE'G(`KPC1VAHZ5C0
M7)&SZ[H<W5\S#&.:;:YG7IY<)7F"4@,N^D0G4C)])#$A\\=CY_BBTTL*'^'^
M6;4*7+:=EM+1A;"$CR4=G-,+E63?)*C?3#`0[2K;Y!.8^%F6:DL5YZBH3IW_
MVX&ZR&8[9QB3)G@Q)5WS6>UW'_]^VA]*2U;'#)_'_WB]B)?+9'$\G1Q/MYC/
ME!3Y/_4;8:<SZ/6\W]'VZA1^O:C;B8:>-X@ZPVXTZ/<BSPL'8;?[.Z_S(0;X
MT-]FM8YSS_M=GF7K0^4>>O\;_7OF60M-@J'&I.E]GBUW[+D:GI[V??QWX/W'
MDRR_]OZ30:2J8(<*1MY?L_PRR=?>MY/9;9S?4:O&1`5^*1A)=N5-)P1^2DV$
MF3B]K^/U9)8F;Y+4ZXJHZFN%1^,I84YL9N5U.OC@)FFOMVL?[N:+U5I=`]7(
M<KZ)%U-H8D+]7%-A5H=O<K1%`1S'V0!)7`<%_R?;H.WWE(7%TVRRP7S9L5*&
M3R?PJ`V,BM=`8=G*^TO\,OGO*&E2Y<\SS%*S'M$-SRKIBJDMI:U"*7@\$:FS
MC/R"Z':CXY^RU_"]\YSU:W.,<3+=3%@[/9W`9`'UH3C>WI//YSGT]"K%CLWB
M=?/)64V+W!O99/TD[`Z>^&&X>>J[P02?FL"D3YMDDF?%/D+M-VJ%,+^;+N7/
MGIYS_NA6NX_^<4_991W%22:E,XRE4QG&""W^HJH`L6Q0'^7C0OBK,V\;C<F!
MT-N&&!ZRJX)*4HC.,V\7CG?=,2:HT+5VD81`"IT(J%%P%W*\4WS7==YU@[MH
M;RS4$$WG(_RG6QGQU,R4'07/FJJ@W:?<IBTVG7T:/#ACC@-":-R(J./Z3F:$
M!QMINTJ9R[$;D\],)5LBAAP0I:LL=%7)0)+FHNUPJ(,AH7UQE`==G'1C`>S=
M=:P@HV'NWT6Y'78T2OV[+D</[:7C72\?[R+H1L^)#`J%MA'VKD?Q/WMNV,\>
M!O@,Z1\,U-G!5<"[+M[U]D?K!"R5QI>H)>SXH1_Y7;_'V<`D]+W9/2\Q*(K7
M6/VPF5\#,%3LGN&^W5,E])`_.TSG4RM.I]IG"F1FDHX]0(`HP</>4&2E2&2#
MC408HQ"=#T3H?.=@8F$QOA=#7%54L&Y5T5Y%?##<C^.['BSE8^)]A2I^4<\)
M6B3`WJ,P6P+8;KS*,&V5`U2>^[MN,29E6(Q$68R;!36@-52,/B9`5IBVVR8T
M%?3"BD?5M>)>=3'654\"7/5RNU+/"6(5F=!5<`W_A'L#5!U"(^+9K9?/6KAR
M]"EK[=1MOQQE2J]-O[`VVR@`'+7M!H!YMCU$WML^['"]4HR">GK!#L8^C"0&
M4Q^6&O$6NI]%_JY7$58)<;9$4@+$K2WP`7^WVRI"4D^'1>H78B$9U"&(P^\[
MJ$.3W0S.6#C8VRQ'7YG\=0EU`'/[Q._XAB;@I&%<8MEUM7*K?\$@*I2!%6!J
M-5\Y;3YI//&'FZ<%RW7`'6AL[R1QM7.XVOC&+J2I4Q7N*<<X*Y&BB!9L%MLN
M;BZ)(M<H``_\Z6JOJ-M@`P4)="(3;B\,>D63_%;ON+OAR'J\16GI(UKZ$+:P
ME5^VPC<#8*#;V`+AWH9)$[@"V+T"$37*O@4ON_`RPI?=8!>]5?0]SB=%(*@$
M@&^(]]V[5LV?NE96BN.??Z44P:??KM[(L(N9]IMU:I76*?AUKI.UIU8KMGG'
MC/&P2F@@NUDG%ZLE'B,:_>.>V:+=8XLI=A;T$V`#>L`&O!$?K`97?]IR,U@_
M;3Z:P*NE<[-FRV)$-C(EMLPC;(I<4G16VX4!8$'NPO[9%F*$'"QR307^]4$0
M_[M8;GDHIJG@C'I/?(#)]T4]P!<5IBZ(#DV3F2"<B$ASD<C4*L!KT40188G0
MO9;866L6C$NQ&7PUU/P;S.Q:96'[28#SZ?L`3FGWOPL`Y1;\-&[)-[S9^N>`
M$!$T/`^_3M9/C-?@[?3I&?XS1B=3A*$>8C>`".U_1V<F%M,6YHE1C37!KY[X
MT-3[@F$%XZVY[6QIN2%B*E3;U?&9<1:LN47''!_(<VO06)D-5QGZ<)`!_D,6
MF.3DR"R<VURA'7<^6/A>>=@.&VY-0Q#*SRW<K;?/F>?0!4.N(XZ%Y;;2#$+>
M;_O.T&;S$?%Q9]<PG.7G->(\J\L/JLH3KSF&CC/]ZA$+,AA/DCE@LFO8$NV>
MVA$[X$SH;!K"-;"PNT&*Y]3R(+HXB!X/@GR-O<LX+Q?K8[$!%R/G32I6P57Z
M@P-LQ<^\8\Y_THY!-/WH#[__]K)VU[_J]K(8Y,ABD",.&U?87JVP]2O;7KD@
MB![CA\'X*LVRW(/-%?RJ]I;97)(E',!X-?,:E[#)Z+)*:`K,S>D#S,T[,72A
M9JIY<AR6I4BR%79Z@)/1\3OV<#,.%9YLT'&/9-,5O%SWX>$>YN58N/FX(XJK
MD0[]L`ZKUJO[0W]8'R'8'9D#C'A5NE5PG6&5I:R6?4I9%#@PB`Z8Y0GKX^T0
M_E\G&2/]4Y=ET1*EA@1X9+%#\8"*X5E9D%O>RT/:R\@]]?Q=KWZN&*GAN1)3
M#/BJZ^_ZY\QX16,\S?3&#;SI-8][*,R&LT\=-@P\@)]A/8"6L3<!3IRU:^["
ME*/9T#DI#4@J:D+<H#@)MU,]-=$'[OI4;$#%1`8RY')#E*4.Z[EI<I!CV7ZN
MFX2^W_5R'YK,SZ4V'<Y(#AN0/$JW&M9S$=>6I%.5&]4?'B"#AT&V_PX@6^2G
M?Y,`2[Q,[C+V+0VQ+A7AB':_%H#-+5","&BZ-M#T<@%9"PK[5&Q@H!`@E0$V
M)8"UH7M`T-VWH)M`-D603<^YND`LE8RL[1+6E9+AO0#6HBY_6TR3'"A2^:0(
M1\635KO7;SXW!\9&][@'*V0_:Y:IT%`.CQU?3HV!@>3R`?H`3=I'C2SQ0H1P
M%KH:(N)32G0'R>X>DH.)BQ=0TPB(]/S\^VXY2VAP%9L9!MJ%<;K"4DL+N7V4
MW-+PEH9_,YR=YBBA_\P)NH*Q0ZQ>F36*"L]DEXF@.M(1N=O]&:R4%2')<XA]
MI*E]867:T>81YZD2!U1:C8\K\<B5,`NAML)/G7H))?3,^S9&3]C<6^^6";GV
MYWHM_@"3^#J@!5)RIH(:H==A0F=6I-TWGF`N9Z9=//7J1`\NSX+"`C\]LZ['
M[2$_JQURP=3EH;T9VM>KCY<))J'/D<04/C(U;2K(+SO62UK@;8<5U[N.5A4!
M/TSKJ+].$D$H"D2T)UC,U6%[J'5'2@;D2N33N^YXU^$E]@C_"UUH;($`=M(F
M/&ALNW1I>!VD5*2RX[<IO,Z;>!GE<HG,3[MM:`F%5BG2DVJUM,*=&FR^(D,5
M$D%2A*M+S&Z&5BGS;)%,#X`0U/W'ZU\4CE:S^$TR)4>^,_M&S_\IJQ?;)WWE
M\'?.*FY3]A/G^#ZR7XW&SCLRQ"Q'L.)#N:G%H<,81>BXU4S><N*!`&X(MHHG
M<(26)D$)29EW#=0DM_N72?Q:4$2<WQ!7$/OX\&(:YXQ_(KK]QV;=M(ZI;"<%
M5<@F"$O4C!4*ZV256!:5FWA&YO:[_F6A_:#R`Y1\P6F?V`1>IG9_/GG*D:+W
MRFL_VE7^K_NKMO]<3^#_J^P#V'[BWV'[SS",NAVT_X1BO4XO@NNP'PV''^T_
M?XD_($V\T+\RV\_>;]CR$_Z^5CZG^$GU\"7ZMZ#)2+S`1HD=_!9MN[P_H%_`
M%^)MX'UUF<Y_V"2U&KFYSZ=(ZJ_F&&7JR<O/O_WV#__]U9,S?D=.0^*>\7RY
M!M(LOC3[K=+@K^%YL*[X=^J+I9K\1O`;#MO1"1`*\7GPO%?A<7<`C9\WO,U3
MIZ%F@ZM@56DJDOMHR+^]SIZFR/KE`CB)IP\UI>^'>YHB^S@D<ZJI5T'_'.J\
M"D[P!WY/^3;LR&_O?$]3Q)68YK"I`==1383R*U^(.ON:,A%1GLH`/9GF_;][
MFK*%6]14V.4%C'I=_AUR$]VH1[^]P6!/4Y;MHB=-<=5(-3F0ID*^[U$LSGUS
MY38521/JMR]-=?BW%^UKZFI^O:<I`0K55'3"`^YU]H'HUFZ(IEVJA#V&HW#`
M38>G)]+DOFDW0A;55$_VS8FLV"G_AAUN*NSO74'#2A]NRCN5WG7W3GMV<Q,+
MMRX;1S9(MR>_W!NO+_?#?4U9?+_T2H``J+%4E5Z=<%-AM&^`)I"O.\#!L-U7
MO;`&&D;#]MY>F8QEJE<G[]G4QFT+FZ(!];OM4.:(YF[8:>,G@`-I=_=-.QXP
M#/JS\)6`*NR<XN^>IC"(MH5([:9Z[]@4'LO=IA1J]P0!*QQO?O?U"D_2_\CF
M"X.098["DP(B#M7`]S1%7@%.K]0<]02>9"]ZLJUA;??A=E(K5S85OF-3Y&OP
M](,T16IMMU>R@FH#"6(&]"E-[=LX5VF<%WHE7^^>%N9,@>P^U*<-S$U3O4(3
MBBK+B@X.XG:SBG93H=O$P],N!WVKJ8$[1WTU,(6O]LT5-F6MXD]MREK%0TW)
MR@[V37M1_`X;1VU;A9C5BDJ3W7W;>3I?S0K;^;UY!C8>>?H!FOK'9EV`]O=N
M"J?=:NXG#5`D($\_3%/.M+>%PH1")L*VNF>H[^ZE.&]*J"\4>-*<L0*.H<(8
M>YI:9'`:`GA?&VA7R"6JQE?]?7L0V(_""NI>%2G-0[U"SX#"`$]<U->5IKH*
MV1Q",E;/L"GU]6Z!H]$#/]C48FJ`0>W!TMY3<W<(1*VIQVDOX'+%NO7D$_U]
M/`.?)*9YMM1'`/GZ_M\#=)`,F#0P>#*@_;\'0+30U/OVBO+/.4W)J4&O9(EW
MV#?M6>EH6>)D3EQ.)MS+BU)6O*=V4^^$&?0?4.?-]#JQ>]4^X5X<^-W3%)TF
M6'\K30D<J5^O7?J%IDCP/AJO4#(11L>3;(6_\'RS3'(D.*-Q][@G]YB";S0.
MC\,3U!]9$F.*";/Z88-!ZH%-6$D`AQHK&>1&_,Q4]`BC,E1/*#`<)L+03]+L
M]B(&V`3FV(2=4%+G-<7QEH?E&`DT31)A;[O:W5R>?11`_^)_A^2_VU](_@LG
M<O'_[P[Z+/^%JX_RWU_BC^2_VU^'_/=?6.0;+P^*?/>+>C^4I/>CJ/>CJ/>C
MJ/>CJ/>CJ/>CJ/>CJ/>CJ/>CJ+>JJ8^BWH^BWI\BZE7DX:.H]Z.H]Z.H]]<K
MZA6A:N=7*_3]*-S]^/>+_.V7_]*J9>G/'?\UZG9[PX&._SJ(>GANCX;]C_+?
M7^+OF6<M]#O)@']*4-??CI3W[[9X&CB+X,O/_B?`Z>!<R//5)$F!F"399N7Q
M/*XXXC\,ZN6WH9<L)AF@O6LJ_N])_&:.OLQ`1CG9%&=+W,Y7:\J=B!/G>^G\
M=4)VPAN4)G^938$6^-YG7WZKO@!-H8O';;S:Z4<?*)3LDV_G&%`2G95B#D*"
MZ_3#)ELG>QR*PCX%.?/MJ)CHRV)%")_-KX!H8#Z(RHBG',F)7'!JZ&V#,3S:
M_5=69E$EZ3L71V??"F\9P%1?T"<X?+P0NIJ'[JMTY#Z.*%@F%QK/Q(4_V&&\
M^7)D3'R&'D14U43ST'YJE%I6'`(G\WQR(5Z!#>46V#R3$!SLA[-)+W7&&A7O
M@1VD[#XYG3$NY](7[2J^ORLEWT0)`T)Q\57B2RTVL%)?&L$@!H$L.CLWRP$*
MG_PQVUQ6@\B*8(2`>ID"4SWU&LN4H+I9"HL8L1_:?K#!F".D.GBJW)Y]%Y),
M@;$5)56D+!SCA:41E)A`VB#H0M=64[N%SJL4U--.G,GEFY40:T5BU:!7X7V(
M82]#":[5BB12\1G!^*[W*P=S<DUS7O9,I,!';0%R1ROL@WWU)/8+U6/"\XML
M(!JD_:YZC!5[2P^NJIR.9&,/YF?8B=Z3]6V2ODF\C3>-5[.*V*.`F\/H@!_W
M(#SI=`N^W*V2+[>EW[)R0),W8;5WMA,NUHXRN\\GF_HQ:[F!5\(QQR1@_^S;
M1P0^.NR,K2=MEB>(L(!A`=KH`9SMF3T,^MS%V?@X?T[4VWB),T`YYA\7_=;2
M'SXR_NTM[`DO1C;)D!1@=8!)!0;U1DA*(<`&G*EMK^;^_I`:G6X'EO;DD?$8
M]T73*/H<NU6M]:MXP:Z_A1<:"96?UW:=,9*/R`K+""M<BOY1$6"W8P*YUC!\
M"S34P2`N3@#7-IR[.`1#=X"AD`U9EF`(1-:VG993J[OA2CWDL+D@A1$K]%]"
M[/>"NP[,IW?73\=W'2HZV%.TJXH.N.C=Z;@=O<)X+EW_KG?NWW7.K>@%,&LP
M*1XFT![?]?(?[TX!_;ZE($:P9<9;/)HTEIS/9I5,D/-?SV^250/6<Q>ADW_C
MEB[PDQB&A\XRE#W'HS/-THYCTVFW?\2QG+ZE"`"KS25]'=I:-Z'P=]\U"GUH
M4L0:CM&$,<$I,%)`(7!TY34LLE3N<N7N6XI_PY6[J7G6\7[OF<@"M$=F>(ZB
M3!,4^:T<88!BUISN#[+T<V^W\%]CNP5[MIN*D=QQMM]/WVW!_MT6_$IV6_H+
M[K9\SVY+?\IN2RMV6_XS[;8G+^<)VD_`'C#[#&GIS<K:9\7-$W&$Y<))R7`A
MO>-3*^>(54SE:>$HH9'%>JC4+<YN<X`-N4;XCR'.V$GYELD4!12MSC-@Q;1@
M#D;B3!WWK<02O&6M(!@F"'GNAMR;,5=#4H)7V]#?=L\Y$)H54;[5V]A#;*E:
M-<X/8T^2-4?G)N^,]/%D7\$2ZT12^8LXG[03XI4`4NQ''%WC$4'*5<07(X&'
M2O@`5W@^4;!#`5Y$WG,@N$O8@;6V%FPOV)2".%&6C':?U>X!K#_'>W%1LM5R
MQRP_VKG8(5%A>>M6)%0Y8>%2=^KNVXXY?]UU$/W44XSV4Q_3`;J#9^I:(1.-
M"CR,S31-#$V#HI+I-6Q7_%>BJE:#:;>A(U!IBQB1&R#H8)!^SG%1E0*#9DD-
M8L!O)=`,13`:8F"@``#4#[B1G(/JXZF?+X,&!]K/`YH]B36)Z5NZKZC;/H[@
MG.C(.#P^J904`*WHI6/<(T!S]-HT6TYB%%6ZE67<C[[:-AXN.<80[%(001X4
MM#:@P#?]L8$1^!!0!_@8`,5&PL,-\G&`36*4PNX9AA3$YC!@X*"%`0&[K?9`
M8C,UMC[TI&EE!NIB8+Z4L_Z,J.+6Q]W=\Z%[YU2E#@TY=8909T!U!JI.G2H-
M5*6*L[BD`4'U63*5O8D)/7[O/,%PL2H=R)".[I?9;4I\`!&T1@-7PY\A^:(K
MH)@VB2/Z1>2$/Z>C&J;(TZ#$YUV:&9C@GMPC:J6TV:H/<YTZ_5L*"%QUUCS1
MF!?OAG6S5^^&]3%&^MN>I!B#,I4U/QEW*F9Y2)\\X:_1&.S$1:LT6V(P)KQM
MIX`!.W4_1CCW_[%9^T9UWE1)G#C\+[VH`<MY,<FSU:K!6[YE-=P^Q>V4SF_F
MZXOI?+7&]IJRA</V"?))OM3J(D.VCU8/_9,21G:P\7MAXI-#1+L]+(L--.:E
MY!JVHI7BZU4&TO:*0%&K$'CI.Q92%A%J:!"JC4\Y'8!!``_'G"XM=+1OG;$&
M+V\%8HX$#`/-070M!,OHV,&_?1<[=RS^HW;7`3"&_]=9-MLG%B+RM[USB0M?
MCJ5*;3<E2%B7D1Q/2]]%IH!=*V-9.Y@EJ@.]!][`>8@"O5KQ(6*E`A/1IR$J
M;*3C>07M"JF3(=P2ZNOGWCE5'.X?LS2%8Z6.0$<L+OP7+Y;(XMK<[9.CBMB]
M]DU@[1Y[[U@VY';X282I^`88;%;!3>?7\_7J4-!#*XW::2?@PU"_L[$V+8R0
M8'HTMOIR#&6J.0K8:3!+!DP[#642R8G/!,O:I?``U,$XOR:%292.K0,A@AD'
M[!5JN\-0B)$I(6*>4L*>@9MMJ8:<!I:"%P'2<A63K]M_1?W1$?DD<F^2IO/E
M"H[[R;H1I3[0ZU[J=S#[F?,F]X''Z0$)00X=X]9U<[<N$.U!ZO<KZ@YS?Y#[
M?55W,-[A$?(0FQWQ5D*JCDJ@MQR',:'`OPD>_^1Y81=QO%Z`CYL86#P)Q&CM
M!G-F$0QR8F,0>MUQE2&G<BLE<N?08@G?3G)K578A!53N4'Y*)*5R-\0$9C\"
MQ5^M+M;)`G-Y"Q;$=2&L!OB+J#%J0Q"CA'XHB(%I)8S3TI90*2!J<`A]^]:*
M$.B4DCQQ./3V@$&`QG0.>+>CYX&'R4]DG*F-,+L50P7\H5*VZ51\@'&B*J@^
MT0>O=FC>$Z"7V!O,<$U`$/K$7?GM4PJ>69H%+#C'D/C[FL"Y008+6NIIKL.=
M(]U&M8P^:@`[KJ`A#-6=D-9(LJ6$82%X/!33)#;2L;C#D"(LEPDLY1P-0R:Q
M;U0F)D+JKJR^Q,_XIP`A?@APLB>WT;=*?;MBC;_1\2N4O=I<%E$V\S;#!P02
MU@M-G+R'5+1>=>*GFF4=\,ZV`4[ZS#VZECT*T!JLBL1.'\_.JO66)0:HM+DJ
MA2/5RLB:Q7CMY[084@N"I[V*&O0?<C/2^;QT2]0_3N?QS5/?=C*JD+[62.JI
MR[O0K!\W*1"\7:Y#\<]O8NA<;#[GP^'1_B)O7GC+6RZ>I_:P*@<EU@<SBEZ-
MX917LPS04O+#)DY73N3;]Y=7]_M/_,%[IWG[%<;"YF0P58E@W'(D\V8RWM,9
M`Q1^=@-GX^;@M&%<KKNG7&#*[0FT[682E+#;@ATJHZ'39"`SCR*B'IUH#IY-
M#F23L9/.',@F4PF)7\-R9E-W?[5+^ZMS0*51R-=HMHE>1_/HU%"7=/\NY'C]
M*6P_#W/KPEK"2T$0O-,>@3<^$Z-?+UYSR.DM)K;T%&G`4\AJ5]HS8M"C]XS9
M7U5H1>V&&)\B"CXSER9<]RLMF%.YB$T@<#)QL4ZGR/*/@[#?0?2X]`8=;[-8
MSU-TU1QY=Z^FY^.[#J9AQNR^WG8%A#29>D/8K-Y.;DQCAW(M8U.H,!$&Q:-6
M852![FLSS];Q.IER-<KK&V`M+!?H4?KFLE0!6%DHS_\6:NVOA%^1ONSIBDYO
MD5"P=3M[$*XUC<^[G][7-%>![L^=<_@YI7^[\&^W`[#HDP-L!>S\"9/;SS/K
M\+?<+"9K8B2>>'^?Y]>`0KV&9%RRM\[Q3TH^]$!F5#<O8EA"0H5,3&[V3<F-
M\=@\3`]ML"=?SC(B5%YCO<D7&/'U)KF.FV;*8'**^RM$.\L0#=>*QA1Z4JP7
M:DZZ="[VGEEBIWY%L6J"52W;MR7=B*&TIYZO"8UM7]6S"FAQCI-!6H5?5R'9
M.T&F4HHYAR<RF@N/NS.5I:0GPFPCQSKN-C#AS::IM3^>T":3-YICK/>K1<5T
M>$2A*UU0_EDMHW'/H6$3I2K*+Z.YIQP>+TKE@-XH(;%*/BU_(N;1N#&_L7/0
M66K7;JFG%"S>4DS_G:?$Y.<#D&Q%VK?(\!CZ[/]&,1K[[)(&#><3FHL8-LAC
M9MK62CR:;90_H*2>=`.X4$.]G!A<_X14#$,=6W^0!DYL?=08-,>N'IFEXZA'
M'K`>N36C2Y1L#M+1>,LA\_$`%/O<F@F:'[:=J/F>MLXKAN0_V3/.4V><#+QP
MB-\-8!RGX]T09>4M'.]I:SL<WY+H?(3`-DBY7W@HNRSU*RAT[-FC`OF7#03-
MR:\*Y_QA?DUG%T"^B/DGRL+?]Y+UQ.5AOGKB1YTB)L:#EXV-?3MI!'PPWJPS
M6MQDNE^I'"#^PG^$NP,\0_!6QM)0#9""]\FGGLGP.T)3R<5U(I9C:$\I*0<-
MEF#,,)!]?P+X7`D:>HBX,SB5T"1<$"C!ID(,<,'/:.[YLE8]M543^]7L1I#Y
MG[_]RAN<=H<6(K_.D^3U9J]N/T3SN,-(_0,A["I\K96;70L=%W&VB[%M?*UL
M$6F*F6"6\77$^+HGZ89S6U!9B:]9YLYYI_K(QF[[6+=[2+5':/3GP]4%5-M/
MSMX)4]M]_"=@Z:`:38M66NEQ.QI3TTH.'5F>BZ9;[XZF'X^D'X,,*U!T4(VC
M/Q"&+O6I@F[\=`S]Y69%TKU%M@8&.5LD'NQY@".\;Y;5C$\6@#K""C%<5:;T
M[C'N6-0UA+:"3SA:$DOJLP]K$\8;VGH>^33`&7M`>K.NOZ5<@-TQ;$Z=4,O4
M;K)*;!"81\9$(&0VX!0F'!LG\?=VZ&]/L<4A)8BE#IWN:YD%YD-_AS4<]EM$
M8L9LS#!(=ST[`Z;LQKN!UJ_+B>@9G2FDU:&I?6(V_BFA]32^KE6(4_^VW&-#
M6<KF-R@[OL25^9?:PT&5))7#TQS,6?F`J>0^2\E]AI)&7%1E6EDIDW`+*O%@
MP7@29=ZH_&+/&0++#O&,G8`L(`-X^9"],8FJT,;RD0:6OT6[2<PK%DQ5AK$9
M&4XJBY(/;CB9J^QE.AW:K\!P$L6^MXO'[K#A`SOL-[5M*DS\[5U#&+/#><S>
M8]NTWLDN^9^_;=[%N/\G;YMWL>Y_]+;Y):W[G_PAGKS&7;."0\'DM?CHJ*W#
MALCZ<.+#:25^H^R32T<5E3@0K>[LG149.6^EK/NP"HZT2W:*P(@/<7!N0$-?
MU`2<N[HX%M>)*A"+S8P*T#?&.2VQ_CTHR8U@R9JMTX[H^!M%2PU)&"A/:H_0
M`FHAX/LH``O9*D,RXJS(Z!Q9&9]K979.]#"%N:G0IQ?5BH^68'I/_I+=>ND.
M7=C7\W2*`MT?-O-KF%3D5$O99`?"JB+L6/$1_>AX6(">LC:M\J1KP=2!]0V/
M!XW!)J")\L/CWHR,.4HPJ%JXF4^5:$%?CML]RV)=P<D;#16M@I>>>5BS[-;<
MHKUR48+$,>*=[KBA/QY0)YO/467!PU,PD@,/G=N)ZP58E,4OD`B1IZ(J"+J"
M]LS3),498OQ'-^-N8]=-`RC5/),GRMC6^:B==1XXY@SC!P!PP%V+:C4!.R%'
M$/`=I=BF!*FDE0"$:5<";L2J%.4M72G*Q5VCE(3[T&YR91>VMR2O0%OY'`!(
MG_N%13AUY1MBSN-.<K\PR=L(W;K1N3LB:HM6A22-=I)F]WCFE7>!$4`#Z94$
MZ[T]FU(=4J)$'UWNNHEE4YS8LF/8NX>2E5>Z&E2D@W;TZL',2@[]$[7I.IGT
M1VWZSZ=-?SB!^#]/7[XG__C/"W`?S3?PR`U7`BX>XIS0WW7/+9?&?RV+C"=_
MR(%RE7S0HT['8C\.L:XE6!`NZRD9AA^0N%?Z[Y>LU[5F+!S+'I^=%4B-\6>+
MT")?6#R;0;'`S[D=:Q>[KL.P$#@Y)458*D9U+`$V[F_(55M<-.H2R"-)N\3-
MSEL9=,UILLKQ)C2"<YN0,=WJ.M3]D'.<PA;_'D]FR6NO\7F<9XL*)C/JA(]<
MY5E]I`?K%#4EFXB"^!(/B,CM;VZNTF3K72;(\\X7:(N93&T^M`IX9@(\0X*>
MBD`RE?`3U37/0CH885J8DZ@S<T?+6E5*+2ON4=2;C$5_%N&I0<M^#?PADL`J
M#6C:-IRT;*(+AR4%T_8[.-)'3>%E]VU\/.BZAZ25\'55.)C,0O7^>W`&JWC"
MTNY3<Z+F3Y_#G(,3'!O"R(+W.@"\/;&%*=3:+R/+X2-;T,4I-[O8N^M8KFQA
M[@._>VX]B5(?V&8Z[0+OB%S\CF3OJ5K"-O0*"FTC=IHC$XC4X<Y18D'R!^*B
M[SHD6R"Y'''AFK%VCWNK*IE"M6\'46PM2O`:N`%)^]DLBQ5FF\4U^5`!&H<]
ML[E)XTU)K!!UHL>)%1YY,.202\B5:^N=[H8I8JC==0Y+)+HM1R(A;D$,`>AZ
M6C0-_N>((DSH(JM0[YWE%:1=T^?^/15LDLRJKY\DYE@>BKI4\.I6<\_V0+:T
MM&5OK0\A`SDP&Z6)X`U4F(M'\2BRAR[W".9*GH11I_N><K</L!6*PCEU_AUW
M/^Z#GWD?/$X6&'QH0>#/O`G,X2^^O@;6WA5(5QH61YU>V976-CYZM'FUNP[&
MLECS">Y::`L"$@_1.WU`JUO5U<.!54;<M<1YA;0RY>TD.A]QN^6CZD6V:&PQ
MG/>V7]A[&[+08--%6QQ.;J@1ZN/)S`&%2\-=5#!ZVO55A:LTRXQM=DM]OK9O
MBR@F'GEX=6D,)=5N<+7O3A-]P_LK^554MR"-W&6JJPX2I:7G7UV188YJ5AI9
M''(<F;X#Y/5_:<ACW^:'8:U_`-;>%=!Z%8#6%_O:*D#KC2DPA$@3$.14`Y-D
MGL+Q",\EP10.BH\`*VUH2^N*&.P`*"F#+['W$B-.EB7`>71*04GWUN[M!T3\
M[D/`V-\'C%C9!DB-";3=56G!3YP%/W47?%BUX!U[P3$RPQ`#<J#?\/:$I2ZG
MC&,Z8T(0@S$L"\7_#,E\"\V?.K1J`W]W0MZG:M400V3[5FI07*FA+9EY>-)/
M["4;JB4#W+1&W?W^>J?EQ1K6E>$=57YHO3K%]2K4?PB'B!-EM9>#X!+MD0E@
MGWB-19;?H$?:!!@[=!V=KW?-$HYYYGU.5JQ>XQ^OFR/ORWB:D)/-^C:C9E;H
MOSY)LQ4YLL\7WG=?E_#2X&%7B8<=(6RS&^(:9$]'CH30CF?KLH[,7ZH][XI6
M6R&>?9L%*RTQS4+V05.-5>UQGE8`:VEJW/LN=]X7-S>Q]S7&$2_-#UK58L@K
MY$=1$!R14>!S(NE/6R1::#;]FN>]<^@!+>CUVKV2<19'Z9`(0N:8>C!NAZ$4
MBBM&:!7C6X)1OCZKF><*4_>/!Z]L<T>Y%LF?59D8<_K2)0J#US-?"(-5VPPM
ML`Q0K^;-IA"Q@AVQU<VBH#,:&LL7TPF_.S`2T%S+/AVC83<@!P4U&FR:<@C4
M\3B8AW&%U.VA3'R[#YW^[CO/#N)`L-ZU(W\P(3-4;%\(CV*,K\:#9L0HP+1*
M&49G%J=7*$T4V3>:#Q\*=8![H1#&H.>'31-4N**]9[5R,)1!Y4H-"RMU4K%2
M.NK$E!?FQ#J6#_6A?%!:KI8LEXJ8\D8;.=OKU3VX7GT.B4&1G8A<`4%C\\\^
MQTMXQ'HA(_CP>F%LB(/K)4J(A]8+W0,*ZW5"VM?B>EGMT7J%77?!PE[EBH5]
M>\FHXF#?HH5]LVKAH"HN15C>9;1LK8%>N;#[?DL7HAJ(P^R$/1^^C\L7`LT(
M![SANCYT\)%;KNN'O4<L(GPH['^090S[?C@H+F0X\,/N@TM9(+!,64]-D`>R
MTJL9"@(L&TMV&W#82Y8K$E!W]+.P1<]J0C9/4:K;J3(R8J-JO<:#31!90K-0
MQ_\EX>6!UBK%%Z=[C/A.L7[36+J$0B#D=9BCP+FI[?+#R'GMUM;V?6;.\P9'
MYK@+@52PK5YTW&5K/8R+D8_O3O-*20:>+>8Y&P+J.J1XXJ^^Q:@:.N3'?/'Z
M(/NG8FCX!(D^0T<5B_('!,KU0R?*L%-PDAYN#L:\-<#D^%=],.\HD=KI$+>N
M<Y1E%GEB&=&'/Z*4[H0U>T;)UR6[R4AL[HGG)D]FM+J_&["])!K>BW'+\,>[
MD^!N8)G@:^\K,G8D@\YYEK^#*];GF#[[.D>.FAE%6[Q97(EPC^>5=\B?MJ2%
MZFV>'M)#J>2:YO"OTM?9%DH5'K(]4U#3Z#Z+I!C/JY!#3CA'&\-W<W?AM\CN
ML`L'F50JPR3+0PX#3)7LD\2F"<7/EHJX/3`2126']R7X0"!X:]<GOI,]A[SV
M*?0_V(5-:#=5J*VQC=(Z!0.V%6&Y?Q=2E,<HE2B/6`K^:3%C`=5Z6*WG5.M!
MM3X'E%35L!3\HZI5Z:C)F`NV>6,78><$9-T`;GOBM]E&6!SEE?FM=O>5PVLK
M(#AG'2308U@XV8,#FG_4UN;0C_HXTK#`4;A@ZNMCRFU!6))X/>S"F;D<PX8L
MCH)V)FU!6]P.WQ1[:5VY;#?M8?1)I`[UIC-GK%(<T#_&MEF9-ION:"4CI1-0
MD7"J=A\95?R\^P^.H1PUP9@'ZIA:AS8?%;(V'C<247KM4K"OL!V*>I#VV"T?
M?I4,W^Q#W`P;GPP[]$>;S*39.[A]NC'2?!,=Z[1/.]79MK15M:VG[%]VG305
M.R<SVM9]V!6R%^$:A7SJP1:O*_9'7AUPJR+.,>R:WU>=7J0!Q-K2P(D*N/6L
M%&EKY5#BL&[+<SG%X'97=F]S*:.0O*"GM"7HV6A1NQ.T=L#=<O)3/8&=8(S5
MH*H\`2MR7'R53E?K'8JC"_$2,9G2U`/6I3IF(N^>2$Q=/D9._!@YL?DQ<N+'
MR(G_`I$3/1:%V'<]'55Q&X;`-*$Y%$D76"`=TBU>/""%]FHJX"+_]NS`B_S;
M?4P`1I(GE*,PEFOUJ!9;N['$X+V#-_+!L_+(J6D(V5M9D>]\0T4F-][WDWJ)
M@(A-B38AP;A81K'I.W<V_=@6J4=US,9J#(^'A'K!`:/.7%9-,4^-V]:F:;@<
MD3]I=36PC%G6M,\KF5A'VRQ<!=_5'FQ\BG(?Z/#.S#V9F%^'L)J%PVKJ-&0<
MF6#VZ'4KHB&U(MA>E2$J`RE8A?C:)%)E+`7P(#B*L9(Y_'6J&$8^W3C'+<=W
M'EA*/G51]_@`]8C3TZ&CTS[!=WMHR^JJA77=<J`-($:(OE%DTSXE)!+"X8K<
M:OQ^8]</=KVFCKRA\`QC'8UM+*S<.QZ^8N@2O%Q-:SC-09'1/HGLM1-(K+*:
M*2/5$Q>I&F1*"PBTPND4'2?VKV:N8V[T\U9XW+76<X<5'\/09_EJ<W4UW\*Q
M+AFG?CX285L;"64[&=M*\?("X(3#VL#&X,AP1JX6DE2MG7PZ[&-61KP<5386
MKS'3[]I:5/0K&_:UZQ)'HON9`0R+M;70;P_\E*F52FS!=C=#8K1FI$Y'8G'(
MBFT(AV04?HH?]!O+&LW2OBC[M!(!&2#]X"P4%895!7)1\K5Q,A?\V=NL4,$\
M)[TR6KW`F)')YY0&G'-8DY0_R\,TRY'=H[!&4I!3ZWA7ED8;WZ35)Y3>$XH8
MQ4=\5KB2-I;3*?*A_"FI8/<;UQR*)SPL^F,X*@KXQ-X84V6%JRS@W<G)6"QE
M-CY&IKT[.1VSPRT\"*;-PAJ?G`100AU7'![7)1ZV2Z+R2#2N08[809]W6JIT
MWWH8&)V>VX24'1:"\PDO;AQ13C53JE/26/BP)=R2RY-2$$$V?Q]0[B54G^*I
M"^Y.)!S,J2)L"HD&[9/^%(7+E`#M-,#0.Y;DPCZ8L?4)*F.CONUE(OEGT)*(
M!)%W/8M:G9SX,/?G&&Z@XBD:+;1/7FVC%EJ_PE/XCY+&T--A"^G*R2D\/3UG
M+N#DU:XG1PLJHY2,#C6VC@::-*_*>S?2=B?LM-G^$?H$D'+R5AG+:8[;DJ^C
M<3[07_R';/53UPG6MI.Q#))4RR18IV^)J4OB'EVJ.?&H0_RU5NF'^I;YY:BC
M$HV&)NV%BHW9&4N(1I5G6`E<PC$[)HOA&&D5*U!<Q/EIA+,V7+&6JEBX0#:]
MS;#RH^;!E"[`14<=/PI]@(`3-SQ"1<XM$\'41GXO9TD5YB/AS'[4UV^_8WQT
MPWLR9N3,6SH?1U21_85L-"C[\5._H)_550.KD!,R;&^^KH.IMLI\O4*AN!<H
M!+&K<E%/S?'V%6$S9H"4&XXN1CW811A@3-=L6]G8$'.<<_IK:[BN430S4"W'
M6S%*;3:;@B<T:3HURQ@U^L(R*N;,<KEBCRO'5=+I`7V2OW=+E(GIS=6\=B76
M:)()Y]*?4":<>=$)&U>8-.D<88QWO*]9$]_-E6/M8G9"DFUJ9?I29R`]\;",
MH5`?>\_WS):G76OFR8T+@Y,F4PJ<*`_PL.OFHYTV/\_23'8;<"6?)].Y.<I^
M'2_BFP3X%WCS;[-X@9=P>LN3Q61W2+>G0N4^4C[JO:/2X:#KV:]8Y:=VZPR8
MV-EL;(9JJP/?6Q_X7@K!CQK!"HW@O[I*<$\JCGTI5;R].55@C`^D5*E8X0=R
MJE3K*_M:7_E8G<L'1"F_82WF@RC'U7"Z*DY+Q_D()>>O3\M9I>+\5<,^L"SO
MH-7<IZVMR#HDM/Z_A-(3<?_/#+#APM#SXI8;2,[PQ\>[IP.L*Q8@U9Q)6>O>
M6BI-9+A>G?O9!EUCD$=CY`5LVF3FQ^ER%OL8\0"_>U;3I<;M(;8(5V?$-=\&
M>&Y.6U8:8EVVQ=L)/Q2.Q>Y:*0X#;7#-!7I$K!YAG$WG?_3BP=]H3'7WE>5"
M72H4[B\DT8TXKM$@0$O<$Q)^(;6-E\F6BHZWW93B^=J/ABF'(%&&9:C3'(Q1
M7$:%)%]BWPU.Z*DM/&!C4MCI:J:=@L@#2H_U)]4!Z;@+$\P')%RJ,0K-+O(8
M"!AL2IH:FN$NF?[#21]C'L#Q'^EKVE)?"R+=+@,WX5YJ\#G-&6]/>AX5GTOY
MKO4\LLKWBL^E?-]ZWK7*#XK/:RJKL'G>L\J?%)]C6F`<G?+WXSM,#@)8V@P9
MSN]-0E3W]N-[[^B[>+G,L^T1O.CE][6[J'LP=H%*YEN[Z]D"F2X4[#D%^Y+!
MMW8W&-J/H>#`*8BI?D^0=[,VXGC7"W#+T`U0'LE)2C+2BP0C-Z1^E**&ES7K
M3;)([)*NNPVPM.OU/[&:&\&T].V-CF'(D4-"'@ZEVA@YLER"4+PHRQG^8-"_
MA__PQ.>1P&<0W/7?ZE[U28V/O1KF_DG>#`+]BA[0JY/4'Z;0X2%:5NH.#X:?
M.@.&+@^&OO.HT"75[ZIB:FRJVX/A[^$_T^T^VF.NELED'J<7NH\#P.D]H'X_
M8I2/GNE;U"WU+>H^JF]5Q8I]B[J_A_],WT(T+=5]@@-!R/-&2]ZTI64FK$5%
ME,#Y8L'H^-7Y63EUKK?,@=\5BZ"+^6(UGR82`K'J#7N:UJI>G:!<OBBIT!\/
MQ_JR-PZ9D4(B4J/1&POQZ@INZ9'G[@&V"\&I(;AK4@@^#*XJ6T]N>,-9G+GM
MR^>9+T=`XTPWSCRGXZ&^ZXJBB+C*>MZ2/N(YJQ5^PLQ+OYX&FF`Z@S,C\HQ)
M.S9CRG!+IB'309*TZ(_W]WS\!.I`A\M?[U9_O6]_O6M__<3^>D^^/IVO9LQ9
M-/IU8($22GML.NE?P8/(/.AJVPDU[R3AL=LAEHK3)QNVY-)M)K0<'<HMG-1]
MP`)^>V`J]/PIM:!;;#8PS'W3]>9WQ$W)=IW'%\;>SJNAKRD99*3LL0#\*3`)
M.0?91Z^"FK@^6&'EB2O=A5'1`0$8!J#&ISI,F1PLT6,PI,#NQ)QBT"5H;&78
M4](`!246$%,?D_N#RZ`>M+``=`18?C"LXEC_"LQ7;'C6O\ZO$PIILY=KE80>
M+;+"OP!.])T2-KG\J0)D&5&KAEPA8PM2J?F;@J=GH3JQPW[50\>8;[Z@YL[,
MI3IC6!QH2W.)>Z7(NGK!U=WV=>Z62_6*I8J-EV)627@+B7#0T:ZL.LX"<>)H
M39>[1U>8OML@VOBW01>%P`4NO$JDJ0-CJ$U6J8K1@D^]@;"8P>.*V2M\T&'X
M*M[5*/8H>7>CB*AWIB*(#BBTJ%I!^ZA"*A^^AA(V[S0KL$Z>571<X*H0^8Y9
M0(#>-O4*!L[;]NJB`@(L<->KE[FY,Y4@KY^VVXRA=V'=X<`\,1AHP`=;H<-I
M:<<21K`V4P7+J'BJ`;)3\#']@5[]4VM@\`$2>0$?5P]">W::XH>B6B?>1[6N
M:&B_FK-0>@-9535P9SGU0PGPBV'1$5]2T',*VW4W',--JX$"E62YTE:D05=O
MM0`W`8;W\50:OX8HG_LIRMS8OPI;S\=WPY:.W:O?X_?VO:J0#X@E:"D>M!WF
M3@.U4"E-I`+!5G2>8!VG39<DVR^32$#"I4K\S7)%BZ"AB(8IH%0#ZF;=:5JF
M5)][FD$ZD#C-7%4V8_?H<8018S%T*)D.DTA,5`D/=FBK6!,S=(<HGHQWIXKH
MG0`DGQ)%[`3PHD`1.R2Y.4`1.SXG1T8*2'*:3G.?D*97+]+!*MKW;YLXCQ>6
M.N9S(7HHW/T:WEUOXD-JF`CC;O8^D,B4A*\B<S34K"A$+;Y_2`191<@LTW/M
M+.UB9<2,'4O6&5$JNXZRUVJ'U?FI<9+1HJA3(>BM61N+32,0B@B].+U!<8SR
M:.B/J=^<-T6?!G0=URK;'0&V[V3]801U@@CJ!(.+$``C2R<9>;!]2_!_DNJP
M(+W&]C38GC1]-/,X>4N,W8D3:O"9MUIN\MH'5H^5)=C1N_N^_8S*KM^Z(@OM
M2X!$?E1D/4*19?!':1TZRI1/V?'8A*A#.="0#B)8*6)$H5J;1.BZOC)AQ^I,
MR'[-"@3O$>H#<8FJ4K-]4(JQ5\GV"(+P,RO@*M$7F:<[&KAWU+XYWB51M1-A
M]R>HV(:D8GNT`NWW[ZT^"P]HSW0H+$V;#56[&P*OV\\Y"I:R..R,PY8:0K=?
M29FK(+V\;S49M0UH3ITG&..7(Q,HSHXE1FKU*$E$Z5,G^*E38S;SF]_A*@$B
M'*U<$8RC)13N<Y^N\.MDE2DW_B*:0._AZ*=G3:T4EU2*()0V2'%1=3J9.0HA
M?7Q3;UPWQKIV):F[O%@AT">%4-WX7;7#Q?2N'-R3Q![I&(W;MAW\KYX2$[KK
MU#'3I59(.>R55D>Y3)<ZR6J48JD'S6D4]8VF],"$'Y>VSI7EL:BJ]KROW8G!
MVIW$$NLJ4U_@>C!3J(3[&7+62,QG,$RM=!@F'R5;VYV5K*%JQ"9QLM$>FE+J
M<>V3\-!N[]2-L$?+>2P93X%WPMPJ1=X)-0(8VT+9WUXZSI*+S!;O^AVA_8KN
M,\'7V@#;DZ3J*-RIT^G7U)_:=P7?O$,'5SRV\I&58O;D/LSGN?::?N"X:I\_
M+=FK=\A=05Z0)76%;_1?')%K*0](U\X#TCN0!R2*(L$314M<]\PX[%='<JOR
M&7@'6W\KLJ?.M-RS[HE%J#O$K&\;\*-,[:Y'KG'1<9>,3)G0=].QD_M)!P*6
M`)]P1N0XY:B+!](^Q#W#%%^%\21K^YFA\62#7V9(^GM=TO:XZQAB7X@-JX/;
M4<`J%C>;:TKW1D-_8])6&"<'4_#<<F88-LQS/^AV9(I/RH^94-MIC]W(971*
M'(Z[G)7V-NCJJ3Y-7<2"[@$]Y1[`<SHT'%*D9O0DI1G%@[,R=H1WAR<-93)-
M-N37(7*4/Q7J0%48S!.=_.E481GH!K))<7ZS=X>''1X>RJ2"'H?Q!G:`GW75
M,^TG:^<#9L5-YXR\9$F#0P(J**4D5+6"B,I)\"+O(O*(?2BK2[4#;!5[\$TR
MF2^3?0Q"]XEOX5W$`;`]F+0RUT#4X&E3A"9A)-(EH[5!8O=N[(5G?Q%*%(*D
M'39,JN8Z');#E9CH1YJ!<$W=WXF1.*3VH.W[\S,3MN>2\`_FT4]A&1J<08N#
MI#/KX#@I\%F+L:O#2$02PI2748YDY6(;9G1=EB,L\1P?DH_`":L7?+TLJ:6)
MO7!2=2P]+=0,.R;4N7<W`*(SD',+G&5<7S`,5`>HNG#ZK"%?@#F"4&R&>!&X
MT.YQ7]\*8W&2^H"&<BU6.^5C)E$=6YK:[A#90;EY>-Q3K50<509U*S]>AT)9
M$')LV]&#`2N)'`M#-<?SM%9DPZ*?QH:%E5Q8H;K-A-G*(R.7M<SPK&/%:4%N
MBPJ&`0.AY+7?GA9]AY6XEG5O)ZEE;@1+<)I"WZ#3IV**5)#5JDG:A@#()VC<
MLEE?T.'/4CQ;[DI>^Q0133J_F:\O8%[6FO]4Z.\$O45\H&"5U55J8J\G3B46
M.PDXE,^1#^GQ2QZPKF<7C`D?L!^KHA]_1ME@G@':NJZ@'YARX+`/5_NDQ#3N
M#X3@H/1A8YH!>S*_TRSDB7EB4D,/W=30G$I(E6L:1J-S1IK$$W(6SM8-CHW'
M-YKM@L(2%["F+TW2.EQ![:&ENV(+>M5JDBVJE<NN(L*#Q?LRXM&LKXMV^@W=
M$S4/`_>1!(5`E<>`Y#G%W#`;-0V#<8BG]U=\9,EMR8Z6="D)F'#`Q!=3-'1R
M^^RIV.B1.)Z&ZJ[VXX\<BO"&95<86&0TOLGRA'W.'Q7'M!`4N$:",)U9.B0I
M<TDRUFZC1A;1VB#Y[CL)1Z-D8LK"H!RR0B/ZCAMI1V6:<Z+J("6M9/"M:`I_
M5]&F70^Y,-S3;$GHB%/YN#@*I<@RQCM_/PYHEJ.#.1NN6]IPO:H-URWD8B_N
MM1[OM2X>RFBG=56TAU]\IX6E$47%K:.300B7I[='+[=5DLP*_;"!%;V`-@&0
M-'_X0)H8`D#N*W%FG7%C&Z*+9E.RUJLN2H1#6]F"-+K3=G*E<P9UAQ#A%TS0
MI8=RE#T2[__;(KX$_)VL%_,*O-^OP/N!'1GG</J/GQ/?"VY#QOUA?`^%%13J
MRY\+WVO]AA.$QT+Y!N/KOA@D-2@^+&']LD97U(L(TD(%_5E@@NR$)JFE&J4=
M(&L:_(L3@`+ZKU0V,8?]4]!_4*W%TC2Y2`!D21X52.?71P%,8O4'*<`OLO>J
M*(#92"X%$-&?WBZ]TG8IT@`Q>]BC(:HF`EA'B`!N,8(O:PXE$95-!E)#!O)`
M*`#1@I]*!AP2\(YL_^D[!6ZH3D*Y+YJW*]GIE)8P#*N@,NP\P)B@Q@\Y$S@P
MBX48PJ8RZQ+HK`8BBT%D&'(Y2"LS0:W,YU%&C5L4$.KP+R;^@(I,8//=@FNZ
ML&R<R$(E3#JQSP;;$X[HJ8(<:LXE#`NLRYYXI"VVD0P[&W_7#79('B44:8/O
MCT,*0PKC<Z0H=]WZ^*XKN/.-$WL4%<I=$FR0G..$<X:X4G@W5^50#QUJW(H_
M5H^<Y`+KI=*1O=D7/[1;I^BA54%`NW4*'ZJC@/8P::Q;F[R*T%*V5!E.21Q$
ME.L.Q[MA+MFHG$!S1KR`2@C):=QT1-M]FI!.148'AZ+56=N/4<),!%)%WEC:
M716!%-%[0>)MQR)]A(W_Q_/!Q_/!@X3AP7/!Z8<]%7P0]*_0(K$E[XW^7>3O
MHOY`QX8I,GF"_7DM&?M;3+:VCIR:M$U[F/&'J()#%-0I2#,S0/Q\TP7B9@X$
MYB.:<!+LNA2<SY`%>E0B"^]'%=Q4Q5;F5H/U(R$)Z(";`DF`WV'ZJR<)5G!5
M0Q5"5DU_"*I`7K<EFH`^H=44@1,2_EIIPL<3PV_HQ/`(P=$?,8F]MDKY^QPH
M!<>FVN<*&&$`B\[F:<M2\SIVK0\<+6S+-#+M>!J4HRU7!K,0PU8KT/V#<=_8
MIM5RU.O4W;>6U279.';J9&=99_>T#BI=2V0"M>HM'3U.<PXST]-D>@VKAO\J
M]74U\'8;>COHW*@NT!?4#$;F5-!^#ARAE6B:)<"_Q-E2.QOM[.4Z:+#N@8S[
MVAQQKHF*OE?<;1^'@/EN=UV@!2=[K$P1V5.V-;UJS:#=W1A<87*E9P77\4#O
M;?:`=@R"G<#6/D<U)O6X:J_8&.-K#O<Q``($9Y-VM%'*%#$'DN"W0`=P(G9=
M?S=H[7I`*%OM@:0<IS#2>;,B$`1&AAQ1M*^MC\I?H$C;WCE5J4-#3IVA=BD<
MJ#IU76G@9!$N9@(N:])KU:ITDX#V&>=K0TM)<A=H-'#M_%DS"/BJTVS:C@/D
MU]^`@<D7)<1F+VU6<7;"31NY7("3EV6R4:=YME38ND/SO\<>L:ZM$FV\:8G[
MB'69LA:ZG:(U85WTV*B$MKY65E\[57.T)!2=-]8L=[?2DO!9S6-)MFL,;0RA
MF6-[M>UQB%C/MHY!WZ(H;U'8'+&N.$57.>7'K\J1N2')9=LQFC*3.?VN)]8<
MY\9A7Q?4H2(M%M,,Y5P^L=<"N\:X?`W+NM[DP!FZ]QY%TD0OS(Z-R0,G_V%%
MGEW*R4RV5]M3A0;)2U#Y!A8,J!['P!PXVQ1D7AS`^;T(6"G-L$.T"/D<=PM1
M645(@&0+:L-\S\P+3<>:A)-$V0_[YWK$V7,?ERN7"))]7"FEISV0F;:&Y(K\
MQ%52V(Z_1;&_FX^6@E>;=`&`O5MN5G6'P#5-9EL+BPM"Z.9B#PC+'1W*.FNS
MN:06*"`SC$52PG#BQ.6J#Y0P'W&=.`T"0H=--LNRUQ?99MU0UKCH49IFY%"*
M[RI9A;YKI]HSK,)='XY'?47"QK,*%RC*AM&O6WBL@+P`N`\A+\8XMM]!&>#8
MGB_0[D7/**<V.2P\C*>V=&HFXV<*;XU/3\E.S-N#@T(;!_T3T$GTLZ(3P1LO
M,9,B1HS7:46F"<5IU=E%TNPZHPCR)=0Q%,OK_;BC/;3?54A-%(]X>^L31WM[
MRR(`X&RU,X#5A)XJ&*VDD=RN)C%L$V81=W*#RZ9$*V-TUN2TF)SAG+.=PV=N
MV7HZ(@V985Q%TH>&:_M3FY<SFINS)I^Q%`+A9">L[2P*5XPT0$$E=J@OJ:O/
M](DK4S8NQIE+IJ=!8&I8T:;39_B/NHM[L]AES%O\#L`[FU78\5/2]G6R@(V8
M;5:DL52TYW_BQ6*^\KV_+>:3;)IXG[.%?^Y]"7?YH@A,74Z:^JO-YE[SHN=P
M_G_>>+"3Z`+G>1+-I9"]_:F=OOWI.;)=I:/0QQSQ%3GB;W^)]/#+7RBO>F5:
M]=N/&=4?FU%]-I_-1^-WV8V/W8\U=[:?)]ME3#EN+J[BR3K#;>`]GRV72R)$
MA"*7R7J^OKA+\NS,NO9&8\_%I15)+?])N<,_)@Y_I\3A1?3\F(SVP,$_O(4*
MYD+E+23^-0]MH6XYD'%/M"SN%K+:BZ?3=5:`4"].5YG7L(!8DW_<<1QJYATK
M1J9FU89YYGV38.ZHQ,N35;;))\D*&DNS"<5!@@\A@Z\JTN'W,DT>Y5%4P>MZ
M3SY+@0%90-O09CK)LUO#KF2+Q#A"`SL%#]+28;D;5IF,'U8,/I#EO>"I,T"!
M./&KJ-8YI<@9&&&W;ZM<@%P-E`XJLHBF<^PL[GK>]-KH3B&14T58F3QR\+E;
M()"V1.ZN1QGA=<H;DQ!>.:SU[1!:6`^6CP#-(!1D0@=6)$,EO[?%5D8N5--G
M'\!1`5H)]@*XJUFH4N9)G8?*,91L6=;5O"K)[X&#T1_BF95O<6)%17H)E`/X
MQ&D).L@3]9WBQ_\D7W;G`%41Y\+A(^DL;[,I')+RXE8E_%&%QMI911$&$[?:
M<RJ-640,QX]]J@?S99=;+/G%'W!KTQ6:Y3/:S^77-F@X`RVXK%6\JRE/'_>=
M5>VTXI7VHK/6Q40)MSR$PH[#89JJ86CZ;W<RC`K/#SG7$381USKTJ0O0XX1/
MT$1+28476<$]<<L1H@%,<WJN/<;QT3#UH?8YIF!&%1![XJE`:21<8S=<$<AL
M3\F73L*F.RYW8F?ENHTAHK)DQ_;)QL0=LN"5SOEXMN;VSI6C7W7%;G7-B&MR
M7"92H]`@J.NG<H?.@0-V#I3788BW\&^@<V,Y[H$NN>X7*;CK'"@!\]!%T&GH
MI-`0.4H56F(,AP@\LC.&/1"WX-T=YIP&'N,RMS=T02$FRKY\P:2)['*JG+#'
MOSV%)$P,T;"W)^TO!?0,>_N"H-A.:B4?M4<R'IKS^-S)WDOIQ6[CU6XRR[T&
M7C1KSU`P,K^:HRB+]7E('(FM\!K_>%U*0=:+/J;W_9C>]V-ZWX_I?3^F]SV8
MWA<=C(C?.)6@`>-=Q#R+$K"?DI1N-PAV0V_LH9W@J00GL0C/4-,=K6IR-$V=
M*A,&*\>O"9:Q/S98==B,"GU.Y>GV6YB&=&[K?W4"WR5GL81Y2U'NN_,FV6(=
MSQ<K0$[7,*5;`#/<.)<[D=M[_Q[G<1K?7&:;58GR=#]&W/D8<4?!_O^.B#MT
M!K/5RZ%)I.M5!-X1N8Y*KAMJVB212CA@7YDG[=B!^1X5/:<2%>@@SBXJR%>[
M&\5O%C=U#S9U.^Q2_'Q[8Y\>#TWTK59$QAX'R[@:X`*WN3^=MU>5S[LL,W>$
M9]L>X&NAEJ0VQC"RJ/(($+?#OM1",UNK"WN2=<>2S@6.N:?0#K"6G5=W??\.
MHP?#2NA'0_^N2X]"_2@$1HL>1?I1U[]#!0LNYP4W;VMB3]5-ET7K<M<7Y3W?
M#3D?1I6@ZC%GC/])%AXL\&66FA6/^<'*:]RLXINF!R3@\QEP`@F=*4;>W]`T
M"%TB)FL\W5#2^%F6S^^0/J0<?+P8F\T*Q^;#U-K!V;P26*DLK84P2]XSH$73
M>(EB7NKHD_]YXAW,^M9#89CW#FG?=`C86E$`1I<FW<ITQ\G?SKPJ*9@E$S"U
MB;E6<9&1N:I5)FZS95=V/CF="\BK21Z+WOZ,<AW$FC4*`=DO6*+;[>-A:8MQ
M49$\D8U.3;*S]0&YPNUT-Z:<:+"'*']:`\-28\*P9JLUW36/ISM41CL9T0KR
M.R<KFONND!K-FF=;UE;Y4DO!JKXV*#PEX;4DQ_!J=YU')2RC!=IU/MU%+3>9
ME;?KC,;%IY@I6.+J='1J*S$+Y51C.M1.EWPT,`T3'+VZ%&FGGWLU*QA/GWPM
ML,0@Y4P3E`#>Y+A*,;D5Y;C*_0B3F46``]YZI+4T_@\=29YEQ:;6&;"TH[A7
MLU)%W76LKW0JNTEJT0>Z6BKE=+C3=$/`FS[]7GIT*#M7A<OLNR;GPI1E>Y)S
M#4B+7'LH7U6OGJKT%"/HKNK;V.S0?=FJ['11/3M=%$W&.V=Y:E9EU/#<=H"9
MZ19R/>U-]521T\)M;(#Y(1)'1G=5#B[J".BTL4I%5HPA';`H6Q0GR`"<5DP6
M-70#C<))[$2IG)'V82@J3#`P+*3%4.KH8E:,?4<DG&Z8J3JEP*C[@WI5$"GH
MLZ:<?T#N:^'H_\0<KD3/!D_\4M+Q)9Q;%A62-KL0DS$O*(8(K-816FI!T>CU
MSL<DD(RW<V!8#I'D`D7&@/I=-:$UR7O0=5I3/D$HOK.XJ7<Q?JLXC8J8P>5`
M\:NKG>_!A&5O.-E-E6QS^,0?D+T&>SZ@2HWM.=Y#\5HVK%I=H('GF?Q:=OQX
MR]M=GSU>D2VHX@;.R3!,.[:L5O4S^K=L5X4UX(VEH5OQ\6QE61?CXG(G?&Q%
M^0%BAPA]?N+9;8[XZ6AL/^0`W%4G9.M(S&=D_(1EDE6WK:7%_-<]-5M-\,F1
M6M"V477WDT.K>M'?WT3H,O;2)_F8P[342(@;D29*!6:16U),#?EVX._(I*E?
MU_=D,`GPC1Z0`2JP!@%@%+*]PF,^__*!$F,>\J_R_3&^^Z)]XI`T@[%R0V5K
M*DPRAM=U=)1Q%-3+8IAZ5V;A'(W%&YA/SV&U*%-IO$[';*=*J3#&E'%E3'DQ
M3IK')Z@!MR4'=*.1F\@15LP)2#:6]H"!6,5T"<WAG44NYDEDQTJ0'CJQ#[K:
M<NC4^/J>`(-Z%]7'@"94-@(3R_LT,EO6+/ZI.=Z7PO;LE]+6W>0#EIBVF$5@
M;QLX512`3+6@*5RI"=A8I0-ZE!@KB&ZBS2!0;-I%*ZUMM^FCJ%ORT6)^%6TJ
MP3Y%@[JMTA-GUK(Y?=WZ4+]N?6E`7QH&`)'PJ6$`^T&^-2Q]ZZ3B4^\49U$A
M\[_=I'#P]AK3;'.)0N1LW?3BR219K*VC)MVSH%'A/'3S!*;P!G"U7`%54<\(
M:2I'4"=B;\DWO\_6P7Y1\!!V+,F#A!N@MED*H6[I2\1E%LQ>[1Z8#C2M8US3
M)NB6CXO^$H>0/:!!*]A$J(I&M*F?G!H'W8B#WANTR>ZXDG[H$^-]TL*M/<*'
MK/&!TF@7XQ=*0(\IS1R1"\`JQ`>D/FE%.)0`\=C*.(>B"2@':=-;.<;A-[`V
M87X\8?;03DGLZ@EWU1PW:&9!J<VB-*O*\N;S;+FC*N48#?WPB1]UBOP7KJ+-
M@SF,`7(&MLQHG_PI0+8._RF(H,J\&50#^N!]\JDE>AIY$Q*KB(LWSC(+0]T<
M53`Y`QUTW\I+)6[0KEC*LV5)Y,%#EWO$0[8'@I&2H<\5&LD8,R$_37T49E@>
M%D/+:LA+'1D#:M=JN6.FW'>-,/:ET_E@.<`LS2F;5BO"Z6K=\MS859OXH6G:
MLM/M?.#T8&V-?/8E"',4ND`,82`S3'!%JMQ_D21B)#7O)Q^3B!U((J;XL5\D
M\U2_S%W"[@C;H9MY2OA>O65@KSPB`97=9/NT.@%5_R<DH#JA!%2/THP_+D55
MP1SJG9)4B34`R4'*B:HJTVYROOB*A"?9-<D6,.B$>R9>[6Y*=*XG*M:MHV#=
M;\-3R8&429=XQ"F:I#WCMEVAV^P/9VR-+2N*V;D2)@#@-&;!(9\SI;XR02QM
MHE5%]+^!"8"">3*MH/J#CU3_GTWUZ=$'2E[A(II#^2O^5R6P>)\,%H"$'Y7"
M0KBCCSDL/E@."R1_D97$HOL;36+QRZ>PP)G[8#DLWD.<\>3?8<:).C6^C"=Y
MMFCN$?;WAY*IM"AVB`K6#N]*>"GHA/9*)V&?8#QE3U00OHLQB*$!E2S&U^EF
M%60Y1J/9K/8Q&7$^7\_,&`?ADZK^:J$U.G)MEF?J0E$/"G@GL@H2EC(3R=NP
M7V0P2*Q*@M2:J#.B\S$+#K0:HJ4_I9"_>0)8%!%G5)X5PONV:@(?+F$>K+14
M?>UXQ!/CSN0!INW)'Y/K/$G>VZ=]T'GB]RHR6.XU@6%-1VCYI+-1#'$D#]C"
MO!M_TJE@3,[(]!&803A&G?QDMJ0<:0*Z[ZE($P6)(8:7@'F-)S";\KBD%!KT
MJF6`Q<U8DM8%3LXN])NN5,(YA*MD1[H-RX%AY#B%5G;D*,*"A9TIV6(/M8AD
M`%C,9!0_MR5T'%C1.J.6@UJ270#ZQ(I#;<,)4KG4D3WEB46$<*$NJJ+T%;R$
MJ\^FKO?6&TU_]R@O7$<N.\N!1!,KIR9[H\-EVM-S,,0@XW_=?T>JV#P<]D]!
MXY?S29Z9G8V!3W3$D\F-]_VF7H*_/H?ZL\YDC_2P>$20/ZL(T5="?4^MR'^!
M]=A2*K)1)CEK6=?DO64%O@C4'.-SQ=@2P)LZG[BJ1O.B2M^X-]!@.<Z@J`:M
MJ(/=BC!#[D%!!:/FV$S*P(FUU$,2-*M(+CF9&=A;5U./<I`S<^ZJ>&>%,;;`
MLX>8DC6LKJ[/#IU8DQBQ%"FQIQ+T2@M#\CX2VRFN1$(MI1@4Q1G)T4/QX;4S
M,ZJ#"J(0%.R;A:%FFLYQ9-#0D1/Y(QVVKH4>1;;WP;[#E.+CE8-N55`^86$Q
M?)VQ1A8K$SJ%%?&(;0U-&<P55E!1,-(Q01*S\BE''.P[T0/[.GI@WXTXZ&^C
M>EX5/;`RGP<,?J'R>7@%XVJT$WZ+46A19Z=X<I9M#K3/RL'@?-&^\%9ENYY:
ML7;7B<]76=LRY"F%]^N91,%[X_MI]MYIJ$3IG$/#$'CJJ6XV45=-UWG/&E>5
MN;*5#7A0PLY.0-:7L_G*6T/_KI-\):%95YJ]+:!L8B&0/WN=LM*Q`E^?/@9=
M/Q#<[A&6)=X#N6,,>@RL-`SV`Q.6UTW!H.+32?0YF[<@2_A(WHDHR9538^Q<
ME(%3?'6,JVM<],T.-P@YL$3+Q31N6I,C?K%=COA(*$>CQ=P):5.,G&>2_7`@
M2!VC3GFT%&/4D9,%F8'`IQQW01:K#)%C'>@)>2`&=4E7X48AP,U=S3(-+,1H
MH3GM'FI!52$"H@Y4=\"(O_H@%^?Q=1XO9YI?MJVG2H".,8C#7RPHQ5#'I>"3
M_;[P%&BCT!M/DCGZ)!7BQ+#NH?E@#`L5KJ(ZFD6-';N*H2R\7T4H"\>LT06=
MO5$N3GZ>*!</>8M\#76SJ9?'\Q5'7<'SN'@A'U13#(9/?#RQOKG`$UN2-X8;
M%KT_VA1/FU&<F<NQ>RCN'_<XU)4V%3FK31-LZN)VE@%47:;QY#5L].5\BR-7
M[:AP90\97!283A/CG1LQ>2S(DN2-,AQ18@N[;.TN)%[.,:@HV3U4KL%+TCH"
M4<]CV(C56]X5W72C0:7H!J!?=D1XO/HA7T?-5[@-8`-MSLD[0%Q2]5L]%E)>
MS\[9%$[SV#V*U&#D-GC5+1BD2KS"_1:C]GEM]1CST2_2Y`9@*LYW4._-G!Q1
MWVEV!M6SHP$O2<_PG[&"JD!B&JES3FW;13B`$C*;`A@)1FIB<+_(%HUM%\ER
MMV45W5G005=L?/O*.*K[[8%)OR)M[M7-B3$@*>8LH]TJ^>#R$3D-)%$!![LK
MEAT4R_9)R(XXN,LPT$5J[/1#6_K@%0O2&.I7U73/66Z,*#E?+#=P(JD]\SX)
M`I$K3;UO/,!!RSR[!$"(U_,)8&@H\@Q8K4FZF28H'%DEWA(HY4V"RGO$6ZM9
M/E^\AJJK#+A'P!IKX"+)'<"+I6'T@#)_T`&"G6N8]"7<K>(WB;?Q/9TBWO<<
MMR+?,SXZOE>S+;Q]RVG)UR(`E"KDID1V<Q,S5<;:K*_WM*4,40?YHKYBI8@G
M]L183<GOO<LD?FVNH#K:`WBLY\K5Q6+*5]J_!9O(?"]>)MN+#,W@U9;(X^E\
M`RN:I=/V9C0&8HQ7N@\C$RG%O.&1C>RX0QXW\!1:>%IHXJG5QM-B(T_M5M#5
MR_9\/QK_?*M2<Y:EM"BUG[@JM<*RU!ZS+B//.VK#C!!Q;\/EF7C9P[1@Q$+U
MAF[0BK6&(E3,\(+R<NWE1Q[=WZZ3JWCA_66^F"Z`4PC[[4ZW'9Z>AGH;!*L4
MJF3`HJ!APT@@`4-Y##:MEIG!9@O=7.4M_SR5<(ARQW6>VI6>8JVGJMJH4.\9
MC@M-9UA2;;FPTG8-OO$N<YBK)\R-5;HT5E@+D,LAX*O(ZD9+/NS+;^"^;KK.
MA2BW[Y&S^GMJO;W'!+>R==Z>8KOMO:2UW]Z#ZF_O7?3?7ED!;COC/:#I]AZO
MZO8J==UFB$6=MU?;H^F^58IN[Y`*V_L@.FSR7WA0<^V]E^K:>S_=M?>NRFOO
MH/8:YK=C*:][NID/IKWV?K+ZVOM)^FO/">`TE`A.7H4:#9V].V.5?NGV./(=
MS-"DM&O`V$.I%K3%Z(.?=NEI8#_%UB(IS`\YGT[8Z4EAZZD.XAY2OJ-.Q#]=
M_H&CJHAL'A'=O8/_H?4C3%2G"_^1\;6.V.T1JT5\#K!:DQL;R9+7]T197?M>
MLIZT2U98G1#U'R>'Q`S>!S:Y^N5MJ0QC:OC2W_WF_Z;9Y)@TK,?3R7&G<[FY
M7K77V_4'_0;`WZ#7\WY'_$2G\.MYX2#L>=X@Z@R[T3#JPG4(%^'OO,X'[<6>
M/X!#@';O=WF6'1SU0^]_HW_//+/HP'#]9;Y:(\?U_>M%=KNH8P@@/"91K-WI
M)"!(05]8.G.'[2YP7%B\%_S'W_X2`-\X@%,32>J!4B0FDA!6IQ9U@W8;T(#=
M?MM[B:D[L&`-^&WO>OXF66"=189G.CCO;5(,PIM/@<GU_GSE[;*-A[JMUW0U
MPW,:ARR**801U)Q.F`E>X?=\;\EQA2>S9/(::ZZ\%,;MHU84CH;SE0Z%)-,`
MITNHZ/W7?#VCGEYE*5`3%$83'J#!`J._RFX2)#,4L#C=D(LK)IN&`RBYRF<3
M(-C`J"8_;)+%.MUY#2"C%'`##<71=(1E5U-O"U,'XYM3/.(9S/%E`E-`C>3)
M,@542=Q[ISE"IGB^[IQT.G"QRCI]=2%/MNK)EIZL)Y>=`?^FZF(K%]),S8LJ
MAZH&:759C:XX,"`3;U1_;[&E&5I56;-RDP%QJ,$W)_.H=W)"%]W^21<NUNK)
MFI_4O"X#1':=+9+76GZ?)#<KTM_SX8"_@SV&<PZF$T*HNA?QWST0!>I,C`S7
M?`T`A?84EP`_T'Z/V]?B`O9@7V9I3'V]`H9E!:T"Q":P9D@/IY/+.<XKALM(
M,;T%C([:A^]CR&OX#V#URR]>?O:GK_[Z$J@6.0[(;/F<F6:^OHF7*RH[C6]B
M.(_]4ZB)@_]A!TYFU[\P_N]UNOTNXG\HUNL,>P/$__#W$?__$G_//+/HM6=`
M`1J3IJ>][#Q`Z7WO/YYD^;7WGXL8^.\%%3(H'@5Q@)-QMTTG)?)`A;]64=SC
M*:,41"1`=O#!38(?]N$.R,1:7=-&X1N,I?U,&-`U%:8=>+7)<:\!_H6[&]JH
M]*W_`0(`*'3*N!B`>T.28MK(1`?@47N=;+W&(DFF*^\O\<ODOZ.D"95KUD18
M-$RUP42,D<T*+8'PUM#$%;##B35T(!=?9D!+:WE"AFRJ(NYWK`Q,*I$]^0S@
MH=IS\Z=#W].T$I'\.EY/9BE@H=3K><\?\U>K1?W@L[_]&]%E[[-EBO%CUPZF
M$]Q),?K7F8>$PXO77M];KM^A/]U']Z=K^J.$4%\;*2VCUM56=0%6G\X)@!HM
MN:QWG\(9(P;B_?J"S0'OW98_F\(9P[O'+`)LW'BOLP7DV35\[89/-;2>V<V2
MCW9`;IVOH';UC*A*!A2>%@HPQ9HT#PH4\NG6>Q.G&]H&MWFVN&Z_P[1%CYTV
MKZO9*QG<#=HF>_?DW7&!Q/3B>@.]6=VW>6O*NM[$KP'DB-@"A_,Z<:=QD4QF
M\WODX!3;,1?*W+ZY`JK;P4EYW78JR>?G'&GE_NQ>,8?$2U&`2?:4<VI]SE'$
M$IYF(<Z858$VNG>3K%9``'UOEBV3JTV:[IS:"R2]N(271/87R/G$"Y(-;E9(
MPIT.IJG>:ZO--?RLF5?Z;#$%A+/ROIW,;N/+6L6H:+L;;I@Y"L.UOLO2AH_>
M$1U8VK\Z<$OA>Z#'R1G![72+MH<P=@!9:YHIJ*KUEZ53A7T>[NFC.N?VM!L&
M7W[V/[)U]7+>H^#S7F_<=GMM8Q"[?]\DF&QRJF$VN<GR'0U0GG#8('E>7)TY
M@E2<4JJY*;!2%'QV)8S6K7?2;H<#%^($NTPG;^94RYM/8>-B#&T"I3]^_O>7
M+__L[8'2>TLUQZ,C<D*8?E^5S5,]#]4S\&VRAOG*-\D%RCMTX;57V?'-8DY$
M]5[K`)X>[,D?LT5]S;9&Q+DFWCT9G-SOZ2^''.(^4$Y4\]?`_0Q-(($8ZLUT
MBYRMLZ/^EN;SUY1'=-:LU<*A`1"!9.`6F%O7"/C^]1P89ECJ>X7$W%'\-;DM
MX#8#)U=D;H^CYX=.Q?@*>VL(FYF($BZ2";Z7W7)!6^J>/^M.Z5S8"$".\]7,
M:Q""F`%,(+%"05C3*?]?3!ER.@[0@=9F/RH0SC2F=E?K'3)2G*3UNSB!N>P6
MY_(F7NP\.,DL8.\SH632!Z]8O^7.8V.ZS=/Y]?H2,3G%BM_.U3VN551L'P!Q
MHLM.,KIN$(S`2WR87:9S.-V-+P'1.)^"Q01,C.$EI?2$CC7(@MW$B(SAMED8
M/,=VA&].X7=-_!CPEGFVS.<`N07TSQWL=I;H&WN7>(WH]&30%'9E/94&G"I?
MPA+9ZE_"?*N4CX?PD&C>)(=!PDEU.TF`U7"1Z14P!IM\E?BR3QK?),LLKX+[
MBE5%E--0"8E8,:E6=[U;)K?(R.;-<H>_6`0T;U_<!-,8X`).TX#R8)RSW7+&
M$A`M*777H(P.N"L.P"SB1?8F2]>\.,`]K;-;V.1NO7]#X0G1\]L;[UZ;/MZ7
M>XN%S'"X"\CC`_7>U\T&Z^>)?%VEU(VKJSF:D\>8Q*D$)M80O$\_;5.%3S_U
M`3!M-`0,#[`1.^\/V0:V<L6\*BF(AV:7"EZG<`+(I(7_BC'W$W(&-[!85;V@
MFGHV&=D`8..J>I]5E,?)B5VRY5ET"[C5H!L6Z.--]H;P/AY,$#\!ERL2:UZ$
MQM.FNPQ_FF\3B7(^0?K./#'L_<UB!FCV_\&-;E'MEYN%].R>]<.6@O.>M\AD
M$@ZC$ZC6J23V:!&+0R9T#*P7`PJ`U8*\UU?`$"^)@2SB(L15*^0JC^U]]`>8
MSZGW33Q'KJF)]ANE>60)77R-0L0U\3CWRQ1NH*E[!09)=7,/-78_N4'&JL1J
ME`IJ,4[8=K',9TL^4BV1[V/]L\MD$G>C-247Z]OY)+EW,<W5?(O03?"R6&0[
MO/E>L==7\WH`G&>[DGX!SUXG2>K]=+M<)9MI1I,"GP34PR\;.G"[VV^GD\Y,
MU:)>\-G7WSA4G(%%&]@Q4SI93PA[Y@RVA?,9U=@01X2SHM$NGW2K1D-@24XV
MR=5]D,)I1`O:\'LB2(;=(2HDIQ'L%XPV[+5[:-*S1D$#P'/8JR#2/"BD8H#:
MYTAY&',UII/T\L2'+Z89_,SE=D[W;A-_V,S3Z=H68D/W5ABA`*-J8U?S+'71
M$&UMXB4L@05/SKVU/9@?MM<3]N*@N")_P,Y_H=#8MT1E/T>B"V/83HC"VQ]7
MF.4>\.Q*5@2K&&9)2791A.%496$XG[]@OT_U>N,;$AI0:W)$<:HRMJ$AVUP9
M(1FGX)]QNJ:;21G4Z&@:P^=O31,P'WTS']\DTSGR-GJ^SH!1FB;,+2D*O!)&
MT]UX$]@":WV2Y@;$1*;0/3AB8D&["/+WM&4-T^*15-XEIB^S[#7*',1$$0%:
M'Z]Q*FC:X,8%4"(N-'&K+)UC\FH^\;$T'F$5A1;(BA*&<LDW'JIM%A0/?OF"
M*.<M4DRX3C;0YP0.T,(XNO,R54PO\M^PX3`[!""O>(*]PB/<RN>ADAP$=MEW
M__>O33APAA;B,!M$'1X(3):I4L%TAL30S[>63B!PNY$LB:M<`[._SN>3E0@V
MXJLK($:K@FI"]]"=_WBA#ADCM_'M<K.8K&'F1]Z?,!;^#,U'B<W`*LK1X(<-
M,`BK0LU\@_.(I`RO*?<)-H-B!YE/EAN0NZKOS3:+:_)B<6?Y.H_11(RX[0RV
MTF6&]BG?_:7XL10_YM,5?LHG/EX]F].SO=]VVC+]>.RW-5(:*1:`6!=$4,O-
M6DG>?+Z#AM0E-7]?:$P`?03;B2PTIV6Z2!VZSV'=X_5%ML`GUM\^E+&"`</R
MV>=JZ.$U'+4-#VH83/=XEZ2)Q@#,(E_.K\ELF*U*@:515L4K&]'1^<G@9.$"
MA">E28)M\4<XVR6I]S+>+%%"ENG5E.,8PY'+*/T)R=YZLQ`!&6U#\8-FM16T
MW:P$$9I;A>C)M>4JW<"@Q+>3.F\8Q60Z<UKY.HUW>,P3(Q>M2)O%RT0I9YFY
M6XV8I3;98MV5@6YZ/?8/37+?X_[PPQA57N03<8N2RG9Q21$AHXL!GY?@J]<;
M]*^`[0]E%9OPO3S,UG6<4Z>)[W6%.J(>4@^3@I#XA^7.^^PY\$2K99)2(AS6
M,=1JT4GPIR_^X*XEVY72K$UN3OIM8,)*:`!W'+%`O/6\_QB50Y93`%:R(FE:
MV;[LAN9K1(3(Z6Q7R]2<UC5J\1I__H_RFNN/6STQ.(#:^"\7YWE6_'<=2F.0
M^WT.Z]Y/_0&&=6^?:H=*MSI&??OQKA_<#=ZV0RB30YG\W`IEQBDLV8EE;W=E
MKFX*?7O`MS<=;\,Z_(-I#J)ZJHP:D6.95#34+?AKW%AYO+$]C,0ZWG8III53
M>\X.X99_23XRAG>M;=ALY<$M^S<69^?@WS.CI$;@)E3#,W$U7S\(6?^_D3!^
MRM#+^VO6]DX>G.4Y8&Z4D.+GF&W.V?3>K:AQ,^;[,(996`4@V>P#+`>[)"I4
MGRL$Y+O8R)P;1?8QT50$=S?BH(-2ZNA]Y.GA,/CK5W\/2&O)QV,T`'D:=4;[
M"(BB#9[W"8M9/O5:ZA*ITZ=>$`2?.D\J#N'TE>X(4'A!U,S'ZGES7YVP-_+^
M.%^A9A7(,WHWQO.<CC]8<WX-Z_#]2=VIC=H/P%,[/B%N";W="&>(IY[3DU/W
MC/4G7+^G87^$'\;BLB"I.REPJK!=W,GKM"H-D14EHK39@5=_?!OU/8V@W%4?
M&:&[WZ6^]UV=Y47?O?%2YIU309`%>4_^&J:6)QC+D[T0R:2NU*33H=DR>JIY
M`P,T`H5[E$&I8QU%C=4?@N+WT[6(,K,/.Y\UH,#3P+%QX:T0!*]0N55UW"*-
MA3HY%Z05JJ%5<C.?9&E!(FWD3WC0L\YL&XPQ0^R[>UZDZ75E&1:+Y#:]`A:*
M]AK`];WG^FX8'X="_A7`QD>?P)YRVCH:C;M67L%[<XZRT52[!$^6''_DV7)\
MOV`DP&?APED$$*J@+3QZ4Q%B'*Q5LF65_\4'KK\OO,82CG"KV7&^6:V`^<;#
MX%*=HUR<\)]X-).-^>2_GI"ZUGOR]R>V0./)RR<UDM"HSRKQYESD]BN2E)"`
M82$@"P]7ZFV%D!P/.DBU4;!>7&!14*VFD["#^-V=E,GJAQ/&^I,?YNHJE6?\
MP92>5XA?Y@L\$E^FZD`[5S6IXKRRIF+7]0I(WW0?C/IB]4,9+\!8OTWG+Y/_
M#EC=\OV?ZZ3>KA0.973V-?-Q#\=J-C6_5]*H/$N]$J2S<3E`BF#NL%[1_+)H
M\'!U2=)I8/\OLP7P^ZRP;/J*8A:D7?A5EGBQ2MQ48Y.VE0O]C@*1SEC./L.'
M.:K4XM4F9Q.`^R4\]9$5<H5!\"8\[@[P;=LF[PLVCHM+(J5V!8HBF86@]\7*
MF@R?;2S(4([TG"37HH&>%2&/Q?FX?&@">.L#)EZ+L(HD];!`0(+)81GX+@(4
M,H-$_D!O'G6FT$<K;^![0X;=09UT0"+A_T8D=>BWH4T)]?RV^YQ'4?G0G-^C
M=]<D1@&Y5$FS[#4N5T9FJB@].CUMGYX6%,1_6TR%\@$:?S//-MJ.@R9-!'0X
M3FI<Q@J02''W7<G'FNQ0!4QP#J`6.C"B0$V4-&F<7Z,M4G&=M(+448*C,.>&
M5.>O@G9T3DL4#MO126$0#O$6#)+ZM`0*+:Q<=3,&2L.M#5W*D[564A2V"4$+
M[R\V$B[!!(DJ8=!Q>AOO5B3B3<C(9R%?)U1XLYG,O,N<3ZA.&VO1L>5"PL-V
M6`&_DG\;H,,.2,8KU&9IK4L46)('+.$E<W@KI0N7?`D54B:7FN#H7__=]U[_
M%QRHX?<&?A/X_?L;K_%W(-D`Z*]WAU1GV,!W=8"?[][\N'@+/\GBFM?BN_];
MI9:VZ_G^/WSX1\K[?I5J5I6'(\TMF>?@62/.=^1&@M4JAOA'L3A"H?3%5Q=K
M%-0*>L(GG\N31WSMLS=4[;/;BK(\]\MD`BR@.QW"3;[^,7Y;4>][W_O^>QYR
MO:[6RP@9F;(6VZVP1[@2'6<!WA7F5,PH#3DN34*FGO`!#FCZNRM]]ZP%O1-N
M8U\[WWWV!4G[L"N?V5UQZM6B2!FG]8UTSZ1P6EFIGD0;M&4GS2HUJRB^]$&W
M<=JT#BS?3?]1%!KQYU!%H*55(JGBCUU)/]&4T*+M+M46&>(DC>'SDPMJX&+%
MBBY8XVFB@0V9#YQ%_4':\=;XC2Z#$</%=;PDY/FYT!(YF_^-80@1PA[@,(B&
MA&VVAK>`#R=%-L12$0+'JUC7S02%MDKC6SC%3U830I[P\3A%_XIUPD)V5GL4
MD#$9""EQ8H$#(N-[1<V9R8^5KSX/^KO5Y,?O_K_,W7BL(F.<"OW]?EZ':NE\
MO4X3M0%1=D@J;3W?C@@7^);YA;(WVG\683,T`,N,(OM<;Y0B@_8X^[P)4A?)
M<)'@[RXNL_4ZN[FG=+EXSR$?[KW+N]LVWN-1"KB`V]D<X`K=5V`.G#;(5M2;
MWP!Q7:UD?3`@P17J)>"^64"6/$RTI[*4&IY8"I"''I#T.84%PH.]"`*S1<&4
M9O^LB$\)SH%R]4:I`D_$BD]9?(-LMA(1.XT8^;)2B]))4K@]&"G9VJ[V6"RQ
MR0[IRD0@BKH)7@?]]5413\F1UB+*-#_7W,-+8*.*`^53[B*#[L(>R=4<NBN^
M;YZJ/NA4-*?1O3I.%R]H`T]?>1XIH)_.\_6NQ-7A5-YD"++,]/X9[2_(,!9E
M6,#I*3Z8)12WR-/($"F9'IIVZ.WSY7R!IO0L%-)Z'&>Z+=OCOH6<2*+*ZES2
M$;'-()M":\[0TX;(TS(4AOC-3OMTT&^*:H_W"49)0:W@!@V5-DLH1*QRT9BR
M\;5@E-PR*/G/%/AB[P\QN@:D0"Z!Y?D2V+*[9N$@0DXZ.-=PQ$$G`@<[%7A/
MR@?F:H[A(TH?^_VXSI2-3H5I&B]1AKH6WIK8;Y^%_.[VQP]]_[0.;,:G=>8S
MOO^DWO;4&ITJH^!^)4'XEAL`<)K#)PNBQ04Q]]<9PXI0#/0X,+9:<JY9T;F$
ME$VO8Q=16'^U\,3TQMJE2J.]GGB7:;QX+>FE;>A!P*B@\K/-#1H^KH$^,5>`
M?`HW@5)W/E`"82/45K*XM0Q&S(R01Y75A%H3.-'"KJ/7KIR23LHL8[VZ2C"V
MC[2FO1WQTP^2YI?[5X)E,T`HV"22B/^?C:6($L^X!?Z/@H!A8<Z-^-G#"2#7
MPZN"N@(MK2YSM$(HV8!4("Z#KC<J@9M2!?BV2453=6E@`:6U"$!/R>P?X.Q&
MR3W%C?,+@'RV\R0SS0(RLPT^*>DG$68Z&>7S-TJ&X-3Y/TF>$5^S9!6A\(4L
M;1EZ#:0P*,WXS\5F/:NC.2)Z<0C>=%I2@45$N]?<"V/(+[-D$)OB2$)XEMZQ
M70)M-H:8N7N<O,RV@'L;QM:@N0>:%(N.-4COR8)>99$@#+O=D*Q(=*JL]"S.
M^\K2(;/8-DM?QTO"T6*`,=(37/`A0%/=^J)NV>TJ"L76P=4\@X+=+Q;7!H.B
M'8JV_5),.#ESV6U,'?X-CJ4JL*)%@$NBO`QJ81`H,C20@Q89X]CG<=OHL'IQ
MXZ+5A+0G]14BUC.LQ!139&600+#,2//B!K]6?\[N'8;1H^CQ]&%9EL?UDMMY
MN`'%Z6#\(LU#,7;P&B2<H3"Q:&(E",\-L&ZWQ7*GTAPC\UM%WQ6[>J\/+A=4
M[_[0LMI[[M^5L0HQ:0H_L;2S@$"+$APZF;F00"OI#<U*:L@E`:,<6`ASJ2B#
MRCB&[HS[>_GXC5Q'\834KEP'_!8=Q@!CK6)M)C)+XC<["B:UCV$L-.^EDXLU
MXC5UD!.]QZH,`E8C2J2MK=+%]K$AHFPY2I)?8Q$E,.5J[NU?Y6[@DZG%<_!I
MV6ZC\:W^Y)]])[8+^FK2$J2>'1W$>T7NWFH?GA>[)!B0K=?N$CAZD1="FKV)
M7ZMS]X')DNK&'`@+FC-/@:\1%*P-@92^F>7/2I)`PR$Q#P;/`W*VDI']HX"4
MQ!K1HKO*YI6(*YE1%N"LB!51X<R'P36:&2TW.9ZV5B)K7`N\,-.>6T,(S1!,
M-\Q`Q70/C@93FXCLF7S6=VG9F$)=MOU?=45C[;._L!YDD4E0]NBJWRX,\S$'
MU>UPU!D96Z)D\0\2[L'%=9W7E\WLM,<,WA2DV\#*6TW\633I#%Q3;J[=;DO4
M`V*^I>F*UAABV"SX2@%-G#I@D]MHGQPWF*,O&'ZJ]N$8*2SI/)]L;JY2V.3R
M>;3,*$!=3(14V6?P]VTA.]DN/.<8R,JOX:8H#[&]<`S=U#`E3&`&W"H9*J_S
M-/@_]2*Q$HSLV*CQ0%AOKT0*@&\YT<I#]=>S+%]P"XH;5&V(HK@H3S4TB`[P
M@L$R<1C1/M((>[E][BC9+^C>3">76EJ"LAXB!-9(7F8W0$+_'B]F<>'PH`S1
M!&CQN^2FS)E[*H#(DB#;]O(4]*[7<;3(_"QZXC6^@T6O4AR@IQA;3K/)LC:D
M5*;RVQOM3"8K_A<DU/$UQB94*VY!!7:?Z07!P$U\#;U9\OFX@`[$VEJ'6"*&
M&X@#"LH$>"J&__]^3T#Z_WROB+4:@G3OB\6T_2\0K.EG^'/B?ZS_&?$_PJ@W
M&*CX'V&OS_$_^H./\3]^B;]GWOIC_(^D61WQ0[DO"-I?ZW,L'3HM(<W/'[SC
M$=$[UO_\Z!UK*WI'^R=$Y9!3QR\>G>-1,U&8EI\:&4';6[Q[9(0_S9$5FA6:
M2R:ORV9&RD1'2+CVH'5E5B6G_I*C>&P6Y_:FN#$JQZ6^S#Z)MG\BTFISX'$J
M_X%<F-8(4(:-V"R#=19,89DKF);U^[I=KR>L&5^CA[@U:]K]&HY+QVC%4E75
M]2Q>QNB2)Q)_VH]5'?VY?(,=Y\T''"O7']RQ\MV](L79%@-LLYW$AJ+S9DL+
MK(SOV2HIZ&%8P1Q/YJRLMMQXLG3*1GXD&,9P**[3(/D(*LA3'"/70%0@+WPY
M>:4%'Q<<%@6Z0W<_Q^]-";ZT`\YFA4II)[T%J=>^PQ`8F+I@6@7)`K2%4>#F
M_#=@CH/_P'C=V>0U''!6+I[7B,W[NR;!'>_Q2`W&&07??O%UT7X>"2<;*TDD
M`A:/64](,=%@X:V+!2ALB+)\:]8<V^8_B3VN%7Y'6^5J]T,ZZ\\1JV+,C[+Y
MJR5NLC9OT0R6!7A<V!7CQ3?S=$=&X`7#K?O'9<W49.P2XT:ORTB"H&$UR>=+
M";UPA1!->YT$0K=E*!!EC<E[[C4H;#)`YS<HS.R5K1BU3H2#"UXK4X:BE]0]
MAABW(O/Z=IKT9M'@2CJ";7ZNLB5PV"S%(-)Y%+7$9;O*A%5[`*?S.T0S0#)@
MAZXNXYQ0__\D"]_[KPS^^6L\SV/?^PO]ZRJ)8+J^3IB]N6<ZJ$(`WV,\E@7)
M_@%0[O7CJ@/MGV#+IRP^^1(OOJ+0FBD<-Z?S"?GW5>'I'%8/^8R*=X9!QC;-
M.OGL?UQ8@VF2+"O4+99T5#2A#1W<\]Y:EGL&X7NS:H5!OK2B3MX2PK)LU<AX
M3)LT=E`0P>E3DFF;F$RMWA?O\EA6U6N\G,5SCU.?3'9-U]2+"]O+1^N$T_''
MK&#4)&;5CE2%&+]Y"A!Q2U^CX*M*[XK9$7(EDRYB?<M"1::-F#]T;(O?P"XA
M\F_;&!N!5M5*HJO.-2YUQ4N*"T(Q6%57:250N05$CEU$,5<T&MIX2MS2#9]4
M-&4V?7C<\^&?R/>ZQ[TJ](^V1'EV&8L[\O4BOD2V<KV85Y0&Q#A?)@)WKF:>
M7Q4$UR3P+:RBA:$4L0E]+V+#A"X&T9[ML4$D<WTF5PV,W232V&U.32J+_/5V
MKN[WB(VG)IDRN^W@ODYP#8&&DA1?F0\Z]5D46-^7<WFO:>-J=X/J6W(*DL`=
M*2"1_TBNKO)DAUZB:]CXNUQ)O`H23R(FIL=%EISTKX(U$:=I:P2,T8<QDA+A
M+34ZK,(^<Z7!\M$02_%4#5P'+>5L,@O-EA<%U$EQV:/N$UY%#J-@+`E5>U1?
M?8>J=+M/"NXS&SA[3F)%!QRZ[]->0-8P)M/TE5;/T(98%4D;\3'95D((4$+=
M[X,Z1\1E6QQ,+B8&#A1:/AP.GQ3C62C;4H[V:]F7-K[[MNGCV'9LYZV%KHDH
M)(KV<&0AFTY-4"!;C>>8=G[+5D:609R:-V3,2/W/J$NY$SS*`$S+DW&OT_/*
M(Y3VB59G+[N"8Q%9,/18V96D[Q7`1BXATB\=$4C[BC@ON,][3FVV]9'8$-A?
MQEF+^5A`"EPT/R(!K>?:I>E!L.;7-W$*;`V(:E1T/X29JW2715=SB=)%YG5H
MPO%:BQW8<M@ZB]%0M0JPBD``UT?A(Z[*AK+N/%68=OV1;(LYJ=YTZGTUNS$(
M\,M9IM&&?<)VM^;7VFKSAK;2?]79ENS+.IK0+7%KO(&=B*!L&7$I!#-Y[:O=
MS#>7,89#QQFQ&'S]T$6!F<8[>ZR\Q!Q+C<$4KE1\$O-O3Q<;-AQ2>:K3M!+;
MR4QQ1';EJ<G?);IGVU2]=*1Y[#%$T59B5CY(_)08#2S1$,>*_0M0>_U1E?#Q
M[^/?Q[^/?Q__/OY]_/OX]_'OX]_'OX]_'_\^_GW\^_CW\>\W\O?_!W?2H#\`
#F`,`
`
end
end-of-input

uudecode <<'end-of-input'
begin 644 xy.tar.gz
M'XL(`)+**3(``^V<2X]DR77?N;Z?(KD00"Z&$^^'=B1M&EQ0("1*EB%I$4].
MP<.J=G4W.8.AOKM__ZS,SJH4+1G0PC!0ES/#SJK,>T]$G/-_G(CL_?3XZ>/7
MG[[_L.S7'S[W;Q_&U]]]_^'\W_;IX8,U/_NPVX_^<Y<U)H5P^M%)E[G[_U-(
MQIO3*1F7(W^.X72RR8;PHY/Y3S[W_^KZ_/%3>SZ=?O3\]/3IWWO??_3[_T^O
MO_KQK\B`WVG]O[(_,W]]^L?_\?/?_?JWUIR,X;6QQU^=?O?-P\<3_[33YKVG
MN3Z.YX</GQZ>'D_CZ?&/Z_G3FJ?]_/2'TW/[T^FW3Q\__=WY#7ST=.K?G_[Q
M^Z\^?/ST]//YU)<]/7]^?'QX_/V)3S^O/SY\U&V\]Z>G??KYMVW.A\?3?_N&
M>[P\Y&?<Y,/GYP]/']=?GUI_^N/ZZL/3\_G9?*`]/S_]Z2OR]./Q'P^$/\Z'
M\>G4U^\?'H^O]?9?/^ZG4WWY\?S\X?HKAJ2P?G+YY$\9\CZ^_ING3P]CG7[R
MRZ</WS\__/Z;3Z=__LDO__FG)UMK//WMT\>/I]\\/3VOGS*L-I\>O_W^Y6._
M^OSMMW_3_K!^<@WH<KM?M3\\?/N]?G.Z_.K^D_]]G9_RD]^L^?#Y#_>__?6G
M1K7^_/'WWRZ*Z?RCAX^_>OANS=\^?!K?G#X]?UXO/_[[Q[F>OWUX7"S-PWGJ
MOG(YW?V.11[_\W$Q"NO+^7>G]3COQ\*<O8[XRV!^VQY>)O\:RG4Q3O;V^C?M
MT_/#=_]T,II4WFAN?_J7O_"@7_SBZ;L?3E_%Z%[^<_GW7^_>^O>/#__K\_KU
M?SD%'R+_OOSTOSZ.IZDT<S$I3=KWAR$6%^,/]O3`H+\[K>^8I:]_]OCTB4^0
M9)_^E?Q^/I0'YO3U-/K1^97EE?WRRO'*?7GE>>6_O`J\"E]>15[%+Z\2K]*7
M5YE7^<NKPJORY57E5;T]7<'85]&<P[G%8Q60O45D%9*]Q605E+U%9166O<5E
M%9B]1685FKW%9A6<O45G%9Z]Q><4G[O%YQ2?>S5?YPF[Q><4G[O%YQ2?N\7G
M%)^[Q><4G[O%YQ2?N\7G%)^[Q><4G[O%YQ6?O\7G%9^_Q><5GW^UHN<EO<7G
M%9^_Q><5G[_%YQ6?O\7G%9^_Q><5G[_%YQ6?O\47%%^XQ1<47[C%%Q1?N,47
M%%]XE7/GI+O%%Q1?N,47%%^XQ1<47[C%%Q1?N,47%%^XQ1<57[S%%Q5?O,47
M%5^\Q1<57[S%%Q5??%45Y[*XQ1<57[S%%Q5?O,47%5^\Q1<57[S%EQ1?NL67
M%%^ZQ9<47[K%EQ1?NL67%%^ZQ9<47WI5M^?"O<67%%^ZQ9<47[K%EQ1?NL67
M%5^^Q9<57[[%EQ5?OL67%5^^Q9<57[[%EQ5?OL67%5]^A2QG:+G%EQ5?OL67
M%5^^Q5<47[G%5Q1?N<57%%^YQ5<47[G%5Q1?N<57%%^YQ5<47[G%5Q1?>85]
M9_"[Q5<47[G%5Q5?O<57%5^]Q5<57[W%5Q5?O<57%5^]Q5<57[W%5Q5?O<57
M%5^]Q5<57WV%SF=X?HW/+P#]"J'-&:+-*XPV9Y`VKU#:G&':O,)I<P9J\PJI
MS1FJS2NL-F>P-J_0VISAVKS":W,&;/,*L<T9LLVKF%](Y0VKO-#*JYA?B.4U
ML[Q0RVMN>2&7U^SR0B^O^>6%8%XSS`O%O.:8%Y)YS3(O-/.*9^R9:.PKIK%G
MJK'N-1>^D.&KF,]T8U_QC3T3CGW%./9,.?85Y]@SZ=A7K&//M&,OO/-:@9S&
MY^?G]?CI+"*13.>W?_W;YX<_MD_K+XC+/_]P$S`?)#K>RIFO?OS#Z2,Z">ER
MN?%^0.&=Q8K>^<WZ[O+K#T\?[C_\YZ]^>/.3?W/S/__[-_\_W_DOJZQ??/MY
M_4/C/Q__Z5]>?O*;A\=?K?;I\_/Z0<K"IOL;?6@?/_[IZ7F"ZY#@^4??KL=?
M_\-%.+J+./OZE]^TY[\[AX,B=?]V&B5)8)&O?GRJ/>XV33>SCVIBCR/M:/S&
M38XUNF_&^62"\;ZVLE/.[O`=!=3X33=CMY5[7CYGN\RH.P`N*>\:RNXE=;MW
MB&4?L[>438DPVY^_.LX*XLWC#1RTV_8QN;!"VWV&Y5M(!:R>=JV0MB_&VE[R
M$?RNNQN;"H7KPO;!U&*3:[EOH"J[FN+.J>Y=7#;>QG5X!M*W=QBH\^.#>_/X
MO?W&1,WADNN]\#Q;38^NN3+VBJ4EGR'YUE%F!Z'D8GKH*2^W3(1M6J^[^N&\
MJXLQKI7#S+WO-?A9L@<W\6O8N</+XWDV$_'E\6NMNG;,9J=45R[%&U/2',:5
MYJ(?)?KD=VES]'7L7M/R)B,*8S0VUI'X9"PE;&<B"V)SKJQ#*\!ZG7[.H[?-
M.KP\.KU=]Y6K*[NE%MNNI0=3\LC&;&,U%7G,,*?9(U66\@@\S&8WS60B2PR+
M=Y91[&BV-E_-&*/:.,URIM5FN,$1!F386+KX\GB8$3%T>[QOT;)\1-R:&VG-
M7:O3@.IJ;:<VW-+/6IVD738LK^_&Y+Q:68/);J:4Q/)GIK".18:4D.;JNS7>
M_/),V.OMD'/((Y0`S/).9K.$WFSHJZ3:W&ID_4B&(5ESM-9!+=)PYSR-+9.T
MYN:!K,QS>)MF*S5OAXG=>6RSVL$=?%]H@LMBBUW>/'^9[0(%U%<(I>>^1FF4
M572)V./FX8/[8"J2.PI/<I16JXL:M';TD'>.%LF:"WDTQO(V5VHU,>C$XAUI
MQ37\-"U=G@_FO\ZVO2=/9AA,OK54(O&FX3-W5@D'BL;7M.?VJ1REU=X<0PBL
MD4UV]]C,]KV/Z`&)-LBQDI-WHS>C*C/'&(4_OSP[2Y_>JIRI=G4O$C/7GC<E
MWJ,)?2)0":.ZP>I2A*:T=OCF'55>D\AFA3E&<JKVYB/L[*T/:V`D``UG>V/J
MW1&8H>X`1I\NZ::AOT4YXTNL?+0.WVW2Q\BDMD(A@_<<=H!%C@1C')3>"IUE
MCK&,MBA$GX$>ZHO$3!E76,&-83:)%,E"ZCS8E5OQ;EZG_NW2&S<W=;K3#J.G
MWIA50&6G%5;R(Y7%XI)2U`,P1P(EE']UAE7)K5*,`_PA9#]`G<$3BT_DPN[9
MK3IM.W(M>S@'?%Q@[FWF[\HGNH*=)(YQ%,*((7?NQK`*(`4^>\N*9]((/"US
MI18&T0`U=0)`VTXW>]9OZEJ1<F,N2HFL4CA,"HD$8B`7F,MO8:X,MP=BT1"V
MG0FTS6&G8%/WOI`[!1#+=8J%CC`3R.NP2LW;9L>"2&`5\<G>=A5*<5L'J+**
MIL4^UF&8RGT!^&SN:AXR\S62=%`$^K7%9.+:!:OL=ET\AY&:5,JP1XI`_DIK
M>?"`"0.;8G<NF+UX/,@;1VW9P0\=O.^`_0%L0@G,RF7B$?AO'N_]2M9T6TM9
MED2NG4PQ)C"'R_'+`+PP(S6O>KB!0MT54Y(22Y,`^<[XX#SR/R_^-%B3X%8$
M=+0XXP#N;:8&V[@@7GH[\:ED'T`]&RBEB-W<(8P6:\;9&-SIHI[X/079CD82
M0R4Q\^0:<V=Q*T#AR#E+?'@+('<84'L'$!>P/@#1U?85[>K;H0\R2!AMHX.H
M,S%ZE_>PL8?6ENTP'8#$CP//7LDEXY`?E9&['?>.+L0,F`XPQLZ6*U3,3<A"
MY\QH4&N#]\G>+VAW1^W30V[`$S@**RT\`P#6NS.@2^\-Q&EIB,NG/9@(N-_,
MUMLLLP5FWPZE9>IX,..8_E`BA=D*Z.FHTR/4N8C+]<O*OQT]@PC,+=QN`_J"
MS\(;;LR)L&#]0%C2.6[;9@>^6(@,*R!L<LNCK$G!#[`,R*C#-&RL3P'RW=UR
M!PCS\#Z#S9GRO>"=>[/P($@F,58-4#/<L2SDO;I)H%]+"XJ@#(0?%8WD2.U2
M&A,=6P!&)PEGF*XY6H;]AQC![I)5^3"&M?LPDURX5)SWZFW<'JUTM^B6-"$6
M_C.D(,WD(>01\HSTKXO14(M'05A%B1YRO8([:#5`&LK)<\H?D8A(@!@CC,_#
M(UJDNPO$I;?+W7-#84.&+%2<\&R9/E/M.20;64IR!;'`O>8^&'SM%#CI/J86
M<=:^06#6>@WT4"X5OJK@3`;J^ICM0#9LE%^;%X*)=]G>E)4.F500K\D&&"J!
M&NBSB'(:<#SHS3*8!,+6T?JP"7"98]51O-^V5$?X"6)P\PR1/IKD@9=D4CI\
M\,R#M>TR^NS4\+D]GC*1KI"@FPN?`4"Y7=`X&ZYAV2ET?FRXBSVH]M$@(31J
MZ"%L.\1GEL1#^C`=U0%3$8Y(&ZY"5*\C(82(%B&VO;EP7(EO9\"!,R8CGP5'
M@5SC':PC.404.2*T`"%P-%<0.Q42<U$<`8'%P`#DD1WLVE#AD*L=2/X`RI@0
M(GD3$&0[A^"1GY=Z*V^A#G3+RD^$`L$#D>C;%&!/P*H!NBNF3II!==!U::L8
M`\8#WK'#38;"DLBE5M$2*Z4(:5`3#KU1T2.H[P']7Z#&OC4Q4#>EZ>O9)X2X
M.H0^5N_&!Z0D#(J`21[M7JLY$"JR4?@,B($":?QZH2E6H3[SL)1%`KJ6@7Q0
M^YB/`_5C,V!0VQ7J[NA]R*5A(I;CP0Y=)RT_&&X"WL@ZR^+Y$F:H\8!:$'I%
M4Z1,A1,"(50/$?*8+AT"/N]"=$AP9J`<FRF*4/@787OGX5CW2#8[*A!]YR11
M*AQIJ3DL!`:G5E$<,.P/*AKGD)4<%&7R.!=^G"1H.^K0N0GG&Y[&:"%XBN-P
M9DJ'V+PN6!?>8AW2!>%BR>`UJ30PLMG.5+#L27K>NBCU`*NY`\\(-J$IT!Z4
M`;3#S&%HFD$\IXHBG.08CR86#_F&<,#;,5R2SL<[68<WQJ9!34P9-<NC^\3*
M3E\JSI*$[&B8OEGT@QS0_`00L:/L@;I@#0(0?<^".EL,D-[BA-8T>Q3!P;U@
M1$C@8I[#6P^'[`>_<&2X/$NQ6D$ZF0-Z=2B6Y42YSA8!VW`(1D:`<3$UW6$>
M",2R+B0)\AM30>EC["I9*MK%3A\UREBA4BZ@D]ZN^^I2%#5EC"#)S@(./%%@
MUD#=@0-?P761#AKLJ.(WZGU3Y=2]`Q<QO*@^Q`0+@!I%ISGYN+JQ2:6.`R@H
M<^(LKM+NSLY1*AG.X)D,C7ELF%?$C'5(=COR62'!0C4U$3QV`R#"J0^*;B/D
M^-VHYUX&DV<[`,2<\T'<9\C8&1128U(@Y@O>W8E:UI.,X_XHFK5Q<S`0I:Q^
M!6;9XA:P`QW6L?$PJ!%/:F(<RXH8(&2TJ^'L6CN2H@"8M6-E$7F\!+$/5BE?
M99VZI&^&'L@JED]RR*&]/>I[DIQ4C3/0T`3>$7^8-9RX`9V0%_Q,_WBL`\Y;
M8.)LEN`',1&GGK7+/0F.YS&`8,FO?=56UM^Y=R0ORK\7;MY[3!70K1,V01&B
M,,EWSUAQ;$CD,G:<ZB,,0$+P+,ZM8V^\7;&D)N7F@$Z)319;WN6"<NG>0RUR
M8"S0SJ#JHP%&&Y7L\:JX2C!HF^8VW)CDA1,+B8\T!8ZA4)!TT-!NP(4(?WG2
M;_`;9##BS\XC87Z;L/DZZ?X>Y5#/!@-9#8(-51<W\[JA"M8B&1Q]*1CA.+C7
M,IU9WE,,!O=W!"@9`7^V/2/4-0S@S"(P=RR\-VT?;CD,6`<1+RAW-_J$@2$1
M=C+JCK3BW/85@P#ZC+P:QH'<`\^1AP<&PW09"2BA!J;6F&D3`JL+YL'7&<C<
M1+B4;TU!?3HD>1QR-Q>DNS.P*%9J9TEH`<4PS<`6=@0$DF!!4`OSU#"F;5:H
MF@\U6(/*"CS6+JDYQHJST9M1_F`2I0$(@,WP]=&9>=+&Q0O%Q;<)CXYBUG70
M!3&_DWJ3'9<`E*-49Z#R,VIAX+(,@(VTM^KLS5S)N0&@KY5'X%D4!Y-OF3R3
MD8",B77#\SHTXVAF^`O0ICL;!VZ:C%A,>*#MD4_5\@.<`I6!60_8WRW$WBQD
M[;XQWBW'%(`7T!E2E,^-`#"2#K7'H)E')!Z",S+Z20DB#:]=RISNI!5DC&,@
MV8B]8,]AD$3YD@`E#"@M(7P8)TL*TN$Q9#YP<M3A&`#ZYO8(F(WPYI\=&$J2
ML%*^&7<`WHG9<B%?D*Z^13KFRU`VV/W&72D"$#]9+Z&Q#60M(A`+A#$/1TTB
M6[KT$XA$4D6/;&89,(0CVX@$GNA+%'=T*$47H9G=OT@;X^YT]?#H\611O\'&
ML&7ET'8D'W\DO=3;-1L-%?O!#+=1\<M8-X"VLB0X*=P6B]4("XHQA+3\7(OQ
M1QA6:8)!M;E<D>XMP^_8$.2LL.L=;`2P?0=0PL)&4[!>YM!F#"5H>42[(O,.
MIF+@<02HY[74GUT0-'["0LFLI)V6HF$)=S]P1VA4U,:+C[N>J@BW"/*%?.\"
M@[::V+4:0!/J9V%&D01G9E!8,4,WB!K<G@UXU4YQJ^5J7/6L`U*_H8XAYZCL
M&&%MC!/:!_N[42#]6`!%`(3\96+<W;9!1C,'L-58UQM+:U`UI!7V9Y:&60B=
M]-RDU*CH1]RC4QL<F**2IWA`!HFT6F4CGAMN95`"8:"#T2W'8N4\#!PNDMO7
M-PW%/;`3F/,@_8@,P*B!0)B-L&+/ZH9IJ\`X3*L[L&]((E)C\2"<;[8#;]AX
M1Q=XGG,&V16P@(#_LHV4-`@XRLOW:TG&N^Z"7\OR<-P"`B%/JA%'JFC0>&XE
MI!=**Q2+JCB`DVPDNIR%[%#AU?)Q1RD!)Q`A*UDMHLMZ%#]NI'OR`CBJ$.6%
MC%)\8[)7).W)[XF<2*-#2SE32I1Y3PQ_301]8:P+,WX47)=COG#]8Y`.:IBS
MR/@EV]6^K\BUB-#:NZ\QQTZ6B"]`5.[;6>H5#Z""=(92E]'21XP=1,#R9Z%2
M:-B1#9_*#E,H?H_H61L4-7J\HTEAH%'!7]2M`HUJO%"D!SE*P<%>%PE0[P0G
M+.9A$0`1J>"T:5(1G5L&AZG;BW1,&:%7+*!&)OB9ES"+*F*QD<1(6^RMGV,@
M;0,.V,KY@48;\D#VK"2$B^8*1N&MRT;JD;H8*4C<.L0/T"#IS7Q'0(ID3V,'
M$CG,H\0IDAP`%#R_)MZT-B8:O:V^JU?G,_LNH>"ZJLX<9"35L$B],<,7K_F6
MB+6_`0IN-75X@.5^?M2(IV.2X5T<!"@)X)(/QZHE-O7W**FEN@]8WH!N`8E\
MHLPI@CC0C&/*IVC#3#J]DHK[P@5ZO'D-.X`5TQ`');73I/:#G&Z,#;V:<^E]
M:UNDN6".B@GU2$G4-7!#9>A]5`[$QXQ#G-0)(,:S^,`@X`L)^+OF?59_)/A@
MY.<@6PMUF3PS0F]O%WN#PYU0936*7=U.O,Q0JP?%Z_$B:OQ3Z.A>ZK(3RD3G
MB9"8'X;,]&`9<,07EW7G[C$ER,L$ZC/++2/2+9@C>B$9!@J6XDX!OJL!>PMF
M!N0?F41UK@$S0ABI!G6KJ9.&0'*[,FKPC_?4X]RWL"S59<7C6WN[\!"2C%B6
MEY!9..`.4LW>^J:>,J@.]H4%^QJ645MHZ/(&$Y:A/@I*=VG_P>-WBX/>!U8!
M<I(Y.F+)YBKZTMV&50+6,1*VN:0JQN\PX=K]2>@YA(17BR:GB)D\>#[5@:%V
MI('9&/>XB/O<`6T!HXD`'58W-:/@5M8Z.HN99$<O:%/,/=I4K##IJ0Z2[4A4
MDG-R[X)M]/@![#K%!A>-`Z";">?<;*PX'Q;)K5%(C`'P!N1/L\2'+$%&$7!9
M_<")5'`]NBO:W(F^G+N%%#'YH8IJU4/)ZLMGK'Z7CW&FC3W6PEU'!.:,*+"&
MD/1XH.(!>N@'P1Z&\5:V9T#(V<6*2##'R$E@7]*UTLR=ZD/P-P,N(V]1<B'/
MKB(S(T-41.Y\12[C01SZF1IO%K\(\^)L81U-%@DVA?GZ0U1[D&0$B,A4XS:I
MRLWAZ.:O2/-6]FWL0<W1P;TL+*O0YI!JR$"ZVL+X'K_4E$PS'6+@AL]$2F00
MQ<J5`ZWD62`36FA8?&J(_-Q@!&NTCZ)>]F7J[[P.0PW:.C%4'6G+`HC:G85X
MFJU,NOH(`V\GO8O)#XC;A<,@][4U1"UTY#60ZE@!W<>XJ-D+C`2-FN`'TS`H
M5Z=9[Z45:8QC*TIPQ^V6>F'P&WX9(\8DH%B=E&0Z<&((ZKWDA@2^31I?)LE6
M(!IQG'@XSV)VL4A^!W^H6(L:7!=N#V_S;F,K-K(PQEC@5VJ.[*%>8#/M!I=.
M)>.\*RX8:04#P3B@S71Q^=AG%N)38R,6)GT@!T;9)F@7L4.3`Z/)[QRH<+5:
M=WM&&W,.<B>F(!"NR8XT,<IZER$YY`9.;15UVH_A-I."O9%J2?!S5/>P`^9,
MD?,6V.OJ'D)7<''0[FINVKB^+/M=$SU7=,+<,/+RZF"P\%YCG\@[E)H@0=O;
MVG`^9)_G1&%1<W;V)"VS\?,`)L;;F87X)QNJI`:N6,<AQ/UYUOK%Y[A[O-F0
M<]@"SA1`*(_-(AKM@.SS(&Q!4..%&09OQ^I;%#@+#K24QHRE#LW,B:P%['>M
M"=#>R$Y?L%FY,;$=B78!^GK70$\\-#O6GND-=F9KU*H".I%-O++#+:FT[#PT
M!XEF"2H0E#=E;!%.!7SDD=C,QB+%9*NZ,B1*=ZT<$^#+:(]P-13F3MQ-M6E@
M4L1!(CO)6#*0<18J%C#"]P&C:FJF<1CMBBQMZ6X`+P'=+<,1;1?E`]((NH"<
MK$W#N=H@P</;V#*N+5WQQMFW>+-6S&(G\A:+!.6BFEG^`HP;JHR[<E.-L]2#
M),KJ9U1]^X7(`,,=U<),I>DX"GZ[,OZI)O-6TS<>`N?KR9#R1M=AO#LDD>17
MF7^6O4(]\@>P9:QQ8&)@%(>%1"W`P1-R`V.@EL#S(<.".X\8,8@"=:WY8[+#
MU@$;4KYOW\)P.FOCKML7[KZ'#M(Y5%OF;I7:G:V$*%E;RNQ(EX6V!SRQ#:AS
MBU&!#U=(.K;ENDY`+<R=9Z2!"BUP&H0+_4W=TV--EQ;6P,47B76W7TCE(EVF
M=FT<;"%CB\/`GE-@\'RS14UF[!T3N4TQB!D2P!;UUS#;PZ)`;0(&U<<9@T)W
M`"2Q5'FXHW"K:V\EW#GLQL1K?[7Y"7MW\*OVM).D1D5?9F9SGYT3E&U!*Q(*
M^,%%@$,\B++7CJ*VQTS-`8[%O*$E%Y`7MC]2)_"!F[TL?;S+>FU],;XQ=1*L
M.PN&=&W;(%MY)%K1I6@H1[+R@"Z'1!OHJ\8"7.+E.H-%_I.:``\B`'4`6!(0
M2F$>HJ2J<V.77;-LWQA9G?`P"$2F/V,HDUFXEXR9B1A:,F)A\&R.>*UN#F+C
M&2`+M!RP(9D5AN<[*JN1&MJ#2%4[QM8YQ-X0R;:BJM0AGFOJAWO0&T/$LE%C
MS5F<`J^!=4H&,8G#/[O7RNSG8R%Z#;E<L<LI]P&\0XQE#NTULMC%13!+0HFE
M`/[P5*@3GU8IY<(V-=\96:SS1N)V7TEO3&N4P$3MZ6B<&V0]T@E)TP9VQL=Y
M[NJ`LU%SMS<BFRG#OB(N%C6*I#GC`)0%_4XP]RIN[AJ*7JUZ-`FZ>I)P*$J4
M+F64<M7F+0`H2!BPA3\L$S_@N`J"UX:'2+MG[K"UY9(`O!VBC%E+T$!)&WS"
MB[7@]VW+T-V1/-`N&[L%S<PV3$F]%HB6ND:U(!!;$=J5MH\UVX"`=0Q0&J2#
M[%2[3@CJ4!59KE.2C5<F8S5S2?$(2,-DM+ER!?O[XPD0HLUK4=,;"[$ITQ(!
MVJAN'DA#?#E&X&0=04N#L<<\,F406L4Q\7";?5C<`J$5<"?D&Y_!1T4=CB@I
M+576!>W\_?$$[M?4*,,(\NFH(Z*`AX[<@70AR@*S,%&;$5NT;3,\4$`[0FP%
M=E`'%1FH8R19NBO#W6#89D4/?)D>^8)T=[N%U`_"!(EE"9;Y)+=PG[5",#@$
M8`6W6*2?,"@[D8R>=%,'.LN;)Q>A9\28FICU?*30+/58B:=AS4"Z!O->D.[.
MNL=@X2V69^HL4UH.2`;W4:88VZH]J5)1YC+J.@P485)N9]*@R*8.)FJC4L>B
MBLY&5"=?"=UA:<QHB9S+VNGA,Q=U=6>G&/<^;TR***@K/*_.04Q-JOIM2\U@
MBJ99)GTT#%51NW-!I%+4.OC684*=Q46X8Z!=]2S&++WX4`Y<1X]9YV8O2'=G
MITCQ,K'KMGKY#H]K0UMOOYC@J$99-?S`;'3((<M,H-XEG6P%@3%>UJEW#^KY
MI3VC@A*F^-O4<*QT92@-TKPV[$JZWZZ+.E\:`2J>:C,#IGYUY&ECE<`7W)A.
M+473#M%YW3-NY(0)JPJ!%O$Q]7"Q#BA0+!8CUU.#^_IH&$`[KIL7]4[6(H*'
M!P<KK@92@0W:V;^3T&H,4NZ]8B+]RET]Y!"TD1;]@GQY([+?U+A7U(X./"W6
MPY-D)Y.!ND4+35!$9S2O6'?7J]2!'/)I;=Z".V>&F\Y9Y8#(TP%0G<HPO2)H
MS`'-6Z2KE7+Q'=S7F0XT`;AG<83XS29%Q2IP!YU0-$=M#8CO]GKV4M\(>+MW
M5$@D'8*(X*TU9#]\1RU'5'M@TG4"H^H<G)L2MA60I4`G-;%$+EJ"LF'[Z"L9
M0KV?P:EHNVY'?WAM'K$B]=JV<W?2*L/%3)\:+;NWAJ@'RAD=^(8B]3KKC$//
M%.<!L^H\X(PZE%QT@,J[HHWUHJVS0(F[RH,],-285+3A(22P'GZ\2"L7[X\G
M$"4VC+4N(@SP;FE[#!WMND[2H?E]R=GU?B2DERM`<E1;4.=0"SIH;2EQ6!Q3
M974,"M[`=R-&UCBP,PB&"];=[YABT.%E*AYA45'^4/>"H`?6`A.LMA@#DL./
M!UFN-JS:M-@<1K,-_MV1@?@+LH>RS?*EK,%J(*`%ZW`)<'18EXJ';-[V"HN/
M=6&7H&,T@DZV8]5P=SMT7Q;L@3UOB:7I!\J4!Z#X(*38T40ZX,OXT)ZN&E:E
MJ\.NV_2(1_7SVCFX\W`Z_B,0U.SP/QU(<@@Z'2^,*E]<!\N!/+/Y&%`U[(L!
MYZYUR\-1$(C!-%,A*G6MD/TZ&@NW39V5*_JN`=1VU17Y_A"4`*M.,*M0$ZOH
MM$EPX@TO72ZDL5`W6)F/W'7(6HTI,G$5V-CC7.%`U!5X@P[#10HPH&.O5F$Y
MF#*<P,C7GE$I]SMUV!446W4>RF:BD'O%XQFK=0U-9A@POT9E,7I[MJG2C*E[
M'2()C!,`[E0J\I7\)*%0`"ZK+SUV."*285]WRLS]:1!R!_(?3!DHZG1P)+%H
MZG:EWJNZUA%MCT4+A]K=52>VNS9BH@J>4)1A&!D,')9`@M;I_-QRSM1P.)T\
MZQ:#?46YNT-0J?)!%CY.(%7^-/$$5+6:O10L[X%,$Q)JV0,_6[V$2]7N&:5O
M=58FP8B`=2I1L(SG`&4JH(SB[0>8)96[_%51AONFD=S@A!>P,>?F0)EH6#"6
MY!M9_I4U1(QK/XX\KY)_,V<=E%WP+Y.^TC0ZN=8&?ZPZ$@,(Y:0OO"!%$CI<
M+NF",G?[\Z`$'IW5Q;NN++H0=;$26!_D9`,E4LI(".[%&@R4545F.;B7A7<>
M:/"4X-2W#-*VI>G[2LX-1I`\Y`X=PXKFVK#S=R>1M%O5,3^XJ<7MBHGP3833
MD;9M[VP&\Z%FB<>3\#1(H%B7Q(!,%W?7D>/"/[T,M^0_+9X@Y!I:JNMH$+*8
M[RKJXOT!/.)M3=U'E!+XL8MV7M"$5J=?8PC4%5"%@I4XY,F[Y@6F69TI`&?F
MKCHXF0<6T`.QN%]0N#-;H&$Y(*Z9=43NPC#IKD4?1=*=8)EZ)AN;@@K4MP$`
M8'AR@HQ!6S:4]4%R45PEU;!+3*+.5G7LDQ(E]4M@',99O+/."UO45#]ZB.Z+
MJLKW@*-3*5V--Z=OLTRUG(%,9MPQ#4`9@.6T)X(9\KU$-5]U4LC#H,Q;Z@M\
MU?D5?0>(65M@[@S";OCO2#F>^^7A4O7U3E/J&T'Z`I1%GR.H?#,Z;:<YATVQ
M(+7TP14QI4BDN@B`V:.X`0CH!-D=,=@ZV3!]AH63'.9`U4^U0<`)*&0`$%]V
MY/Q;^ZS3X_(OWN%$=421I-(Q=T#%Z,1`T4YI&)1C.Q`^6<>5\)LU:8.\ZY3J
MGNHHZS00&1XB"*(60@S27(>.Y\O@[C:^P,[]N6,U/YVZ(UE+7J`?)$T8"=93
M.B4D;B]NH%L.C"*F9R4=#F=1,<-F#H!]F#"+1V=H`[SK#'J!-+P9\PBRD:XB
MLB_/3_>PTRUVC*R+VR%U5C%=IV^]=$(M1N>LY]3&P3Y(+:^S6-GJN"B+HYUQ
M`[LZM7$VTI])KZ4`/Z'J+&T[9CN?K3'CHJK=7:M<1M5`*[:<#R#:C&31&:;1
MR#UR?NJK2BSVSK"'`Q^,5;-'I]''3+/K2TC5G'OWPWKM','>.IT.TV!#K*\Z
MG%NNYR^#>=.XX_9F((HRTU?4=.A>6ZY@0+4(UK&Q=(FJ,ZWGPXZ5T"_Z+I*^
MR8<0A.P"@MC(>"Q^/*%']+V.R^OD8SBF.B.+"J6(ZF4!XIVMT6:6T^%<)[B?
M.FVU+8)C.?`.Y>H1;F3-0%$?Z&_T;Q-/+7VK@.E.B94)%!#D8:*P"U&%O@;Q
M>#5U+BOJ'$.Z](_2_3<\--GP!F*-HM(^.Q:1*IX#$8]EIQ31+64$8$Q;D+;@
M5JVH<A64)K)*NRBD,'H:05`,7CMP*W5"HCM0_#%<4C_7^\Y10VE1,5WG]N!Z
M4'3T)GFV2M$!X!ETSABY<B`A,?MKR6SZ%)E7/*UMF(MB9D@Z(EU0>S`?`*@M
MD`CCC2(I,2YNNMXIO9R1&]J;B6A1YAE[C7)2Y<"3.R3JHIXWEXT[=(`GL4#1
MZ7L_3$8/6EN\KSHOZ%AUM=&84!:?5=H<("LHG8;[\FV^.ZE7T'H=-88EEI*5
MN$#I>SBOKI"931T-R>@96PZL#QY9;"-6L@$_A+/&F*BY0>&VWJK3SJZ^-P$*
M,'S'39H\R=55V;=:;V...AP[)"+/>V'J\Z=DC)>M#GVO"K8;AC4.4&);7D^K
MZ4%XG-4L>:%OYS)M">V#7D0L9!)2VVM`GUWEVC.]WYYK0.4`&7NJZM?B'+R#
M.-1C8-I32905]&GF(=K=$)LX/NC[=HZGLMQ4?\RM1X\SQ'!BQVOK@#%D'R1^
M$.GF0GGFKH&#8,H^>VK%UYJUX:.3?5`@"8A7,M3D!#QP9P=BGBS%20ZC<\\6
M$I?!&OJZJWK$.#E]3S@M?()Z`S$<6-[HKTWZNR:YUV8Z9$D`E8^B#W6ZKYBU
MXR(@C!(VE]]'5KS+SE=*0QL34XWDB07<Z%'X,$!Z0"V\BH''F`MOC^9TCO`"
M=/<SKMU:B5-*5D>L?)"&0A^PD`REG@_9,0<P!E),FU==QQRU=X6WX)&&-8)9
M.KH3`L:)Z<`%W(I07L?YJTYXV>OVB+W[1@_"JJC?##L-PSPZ'"_$L$T8H\V!
MQV+-BDX#'H%,T%DJCPE2FX:'[X%G;CK@@,RGJC$*:/%.20)(V1[F8F;NSML:
M;UQ#&272$U.TG;:.L"J9$HW;D"P(9$N9E'6D<CY7"/0E*;<\@>PZG3O[5U46
MI6?U[6GI?1U"0UK$8B#L',Y9IK^SZ<W?V_3A\Z?3XQ,4H;_:Z?JW&=S^(J??
MKT\O7_\'[!X>U_DO^/KP].'X?_WWDKU?[]?[]7Z]7^_7^_5^O5_OU_OU?KU?
M[]?[]7Z]7^_7^_5^O5_OU_OU?KU?[]?[]7Z]7^_7^_5^O5_OU_OU?KU?[]?[
0]7Z]7W_Y^M]]CF",`'@``/OU
`
end
end-of-input

uudecode <<'end-of-input'
begin 644 makeindex.gz
M'XL("%2R*3(``VUA:V5I;F1E>`"U5F%OTT@0_>Y?,1B+TE/BD)[@1'-!RI44
M(FBIFE1048YL['6\JKWV[3II`O1^^[VQ':<IZ.YTTO5#:L_.OGTS;V;6#Q]T
M9DIW;.PX#RD5UU+I4*ZHW29!;W)1Q%8*NC$BSZ6A*#-4Q)+]*K?J-S=9(*W-
MC`^,QT?[U'W^_%F+)G&6"DM#:Z7Q:10"2.B0(F5L04MIK,HTS=9T(HHB5O`\
M2H25VF<FDUA9QIT;D1(>(R,EV2PJ;H21/5IG"PJ$)B-#90NC9HM"DBH8OP..
M:1:J:`T8F!:@6+$NI$DM95'Y\NKT@EY)+8U(Z&PQ2U1`;U4@M94$)CE;;"Q#
M\`,,;SAF!N.:`1UGP!4%(NB15%@W340'+0*%QZ)@EH:RG+WV@2+TFA)1;%U_
M&.DVH!#I+8^.LQSL8R`BGAN5)#23M+`R6B0M(,"7WH\FK]]=3&AP>DGO!^?G
M@]/)90^^19QA52YEA:32/%$`1@Q&Z&*-;`#@9'A^]!H[!K^-WHXFETS_>#0Y
M'8['=/SNG`9T-CB?C(XNW@[.Z>SB_.S=>.@3C263DMC_-[F,2C60L%`60B6V
M#/D2ZED02T**Q5)"Q4"J)6@)"K)\_<\2<3*33,_+`.&[S6"/5$0Z*UJH686:
M*++OQ</NK7PM&NG`;]&S7YZB$*VEP5*VZ$BD,Z/".1Y/!O3DH/OS\Q9=C`<E
M_?>2M`1;8*,Y3!!746YZQT<_M<@J'4@:(=.Z8,_`2$A/`OOM.DV4OF:K*GP4
M`&=`6&X&&0."JX!W"`B]@TI+)<IJ1"5L0!ZKPI(6J6P*H]FRSRAS69#;F%SN
MB:H44(.S#`JA/O(%\F5$6<4`UW<V\+&NXP2Q#*X_(\S/>!=F_7C?^>H0.LH6
M,/2];@]O6=\;'8][A)_^(=IB"=TLCO?.!I/7E=G+V)'3I?`_S/!#K-A':J_(
M]53'JR%=^M1CFKKT())!G.TZU`M&%@NCZ4GY&E6H6CK-0M>Y9<WXR.L<;+(L
M*:?0)OP4@TO,I3UTN(+ZTQF/($ZG]V1:BUV+7%6<VZ"T;Q#_BGS?=R%WAKSG
M-#I].?PPGER^'2+-R/YD^&%T>G8Q&?O.=JD_W6(LJ:W)XZ-IS]NZ[$T=CI,7
MW3MFEQX]HJ];U/[.(E*^RC-3;-=[=.LL-&NP=7.<]%J%*Y9M>E_6B@EK/G6@
M2DGA027-9I/;R%)+PCL.>1BCZT!`!CR*&QR?!C-0DJ'OTHM'![QMA2'6=2#5
M9'AR]G)TWO>^3LJ'=J=(\]M.>9+O>4Z!6X?V@I`Z/3(IM4U$7KUGC[IT0-VG
M=9;"9H&^?:/T.E2FL3B)IK:E)H!FH5.2K$8P#ZHDR6X4%$;W<7M7#8YN"!-)
M4B^7PEA*U+6\D\O^GX@\,YA?1;+VJVI!,Y7]=:<4(I.E7"MIY`<ZJBI#P)#F
M/K;K2,U1N3@%9_%XD*6")\='I\>'3I7E1E'JT[^I'B1[&V=SLK.!1=W4BX?>
MQK93/J6%4S.*Z`VW[W@X^/QR^-O%*TX/CF^AS7C.EC<PQ]]TUQ[6"URYAM/7
M">6RHQ=)XCNAG"WF_4HP=^5]W86]O6]HKVY=!+M:<<E7>_<.7C1X>TQNH$6R
M_E+>0I1G5O$\Q\P19KY(I2ZL3^]TLF;U0=JUN0R42%R_;@E$"T_KW,2<^PVO
MKDL/<&RO&DZU#_)5/Q$<8`\P)5#[<%;<"FV[7XVCVGY0V_'GNO72=HH-5V#"
MUSN(_6J+=2)9_1>;!MGQO>#A=%AK_+&MDC],,/^$)\[RFA\R_@CCAX*2K%S*
M22]2/*#>GQ!^NCRC/MV'+]NPUZLL/_GXZM@2K48W,^M?3>\.O*;<>/)=(=`K
ME[Q2G:MI@_5?</C\'V!)*X+J:3..VE^0WQ+2Y5[?C*BHL>Y<&W461^5G:KE>
M=9IW4!9OQ)\!_DYF_M>TU[./FKL*?P_10FF&KR"_4P^*N"+)M]`A?_'QUXU`
M7]:?1?=O+IQ2(56)GM9S>9,C=&M(>[;S^Y5_U>ET<+/45+ZK[&I'C16KJ"A5
;J"4H#4YYMSJ[$Y0V",Z](>W\!3VA3!M<#```
`
end
end-of-input

uudecode <<'end-of-input'
begin 644 texconfig.gz
M'XL(""VR*3(``W1E>&-O;F9I9P#47'MSVS:V_UO\%"C#B:R,)<5NTV[E578=
M6TY]ZX?&5COMK.[*M`197/.U).7')KF?_9X'0((4)3M-=N_<3!*3P,'!P0_`
M>0'TBV^ZUU[831?6Y?ZO@\G^Q?O+ONV\LBWKA1C)W]H'43CW;L2=3%(O"L7K
MSG<=<2P642RWQ6.T%/>>[PL_NI,B6WBI2*>)%V>BUVXA@],HD6(:!8$,LW1;
M!/@*G*ZC5(I`IJE[(Z'8#6?B6F:93(1,DB@1"RCQO?!&N$`?2CF3LPYP.\Y$
M&BW]F;CQH#MBMI!^++9DYT:`;'[:OB!F?C1U_7D49BUZ==-;X8IK+Z,VP&@.
M?4QQ7$G@9C"JM(/"[H>/AJQ>$"<P*O76Z71$[$L7Y+[S7#$(7,\76=1#D!91
MX*9BD*8RV1:9_*L7`G]D?-M9AEX;!A,"HZ0SPZX/HO@Q\6X66:_2<.?''[^C
M_]_0_]^C1+\#OH'[*+!YXLVD.#S>/SE_/QD-+DZ/SX[.:71&F?!"G!.`,;SS
MDBA$X6EHHX4$R1'-5&;+&.F<T6`T^.WP^**;R8=@WIF&\XX%0[X)W4#VKZYA
MJ/@DG-=75A;$,R_I.Q]&I\-V%]X^82-$T'&L-)M-8IC(I$_H/LSNO$FZ2+SP
M=I+"-,C^#V^(1LZ\+$KZ=YYE@7AW;I+V;>O=\;OCL^$OHTOQ[G*DG@Y_/1Y>
M_C38/QQ<7(KW1T?G9U#X_N3WX4_\>'KT;O]R@#^Y@75Z-#P_/Q&GP]/!*10/
M%9_3H2J^_`6>+D9B^#,S@'$?G)\=';_')RJRZ.'B=)]K%0-X.CTZ.#O"A^'Q
M`9<,?^8?R'IT=,H<?V4I+1*=BWZ#YU^/^">7P,/)?RD)+N@G;+)E@*OS]>ZN
M90WW1S_U'?R_=Q7?SZ[VA'R(HR036&3YT4W?X8GHPO/<\Z6U#&$Z85'#RK+D
M=!%-W*V6]<%JX+-HA\)V_FI;GU3=M5$'%>-I434UF\EJ[8QK24W4<I95@@J#
M^0H#LP]K[H6P.J"<R7!S>KA"8<N*J9@)*>9[8A99C48FTTS85\34\<3T*G]T
MKVPA^F+JBI<O@9"&$O9U[<N7(H%UGX168Q:%TC*J48)<`/4X#S(218BCTU$?
MWN")NOY&M!\$#0,*D:LNG8ON,DV,&F@AQ`>NUVW<V3^6\/KQ8U&L&W'5GOB$
M3+%3+LB%0QFLJ9\JL;C]OP#$L_/)P<E@_\+&AE-04`FV>2$N(]BZZ6.:R2`%
M=4K:67J)B.Y#,?-<6$`=\0NH!-")4!&2(IE%(HPRL4Q)1;JW<B9(J6!=KG%@
MWWKNM2]3<8_M8(.3HLX6;J89L\C\DCW&4@D-7:O"_MSUH1,$:-F_6I*:::=7
M./S=M]V9O.N&2]^'^BGJ6]M9VK`<"-&C1,IWEX<M>A%:]0TOSM_W<RRY#T6A
MD;8=@Y;`,L3)DJ7<VX,6,G6G@)^HC@!*DJ4F?\X<".'-A5-TL4<HDTRF(*+=
MSKS,AS%F$FRM4L[+S/.][-'F3092,5B")J'OF/I>3TNIE.:)^WU>!W,/%\UT
M(:>W$V4Y]%9<AK.^L24=I;G5?I1WKH\KHC^VQX[CC6TH@X'_#;<$(@-5MOAO
M-7C8E32?6(KS">^-WJN/KWKPM_>JU8`9P")XXFYMAWX*Q[.I0A'0'#4:(+/:
MR\5$$+UM[G:>#>@W$W_^<UM&<VCI:",'^R(5W`<("$\^N#&XF`WK::QWP*YG
M@>I`)@4@U-Z$@Q3<V&Z,0>_TA8:%137D`/(A^Q,![#21+A/PIWB/`I<E](?6
M.KIE[RB"FN3>`^HIN!,W4)$(5OY0$72`V?&<O#&PR9D7+B6X9=E"W,,H;C0_
ME!G'Z5ZCLY:/:UOD@`";`%T3`8L=!I=%(DNB)1#Q7D>O*D-\T/:DZ'`ANYF7
MWG9P.&=1)ED/D"!N"+,P!Y<.V2"=G+M+/Q.Q"X)=/Z(/1QX>V!(9Q+@:L0;X
M@`L6`UJ`_9;7D1TP`]/(CU`@,8?Q9#AVC_N6X6P;7UW`'^6<,2DP24'_@=``
MH2(-O-G,ERV25&&%\.7&?EN`$]E!87O_TX6MT@W<:1(!.ELG;@NW#OFY*2RG
MZ4+`U@IOT!Y5Q^7R6B)A33;4[1%(2DYK[B!&X3:P)-TL?D8&P%_S$+QC`S=<
MNGY'+SRKX9#M$O8P`?]97`Q&OUR<H=CYS&]!-^"TP]3Y[0.L@0E/LA9ZL+`0
M$^F"IE\&P2,9%Z!+)TFD=)I67FS$+V3`^^'&CZYA9=\G'LQP+)/`2S$62&E*
MD`.L$RE[MGC[<I?4">Y:<IZZ7-W&1J*]*]JH3<&DM^6#G(IT(=I3T<0Y7X`3
M`[7"V4'[*!^\;"\OOHG:]Y4*$A"*H$-X;2*GYH=/33%&+6ZV8BDH,`"UP,V,
M,A:8AWL(BZ[#8RB0N:]%9G\V^QJX=+-Y4"Z(;\OO$.XD4]G]QVWHQC$LJ['5
M6`LAZ=8=UJROP*.(KB5H5S")60IBN*!7"3V"CW4H`[7SPP\_?#Z\WW___1>@
MR[8F0\A"UV=CPV_S",*,BC%KDVWWO>NNI@$62N^#F=6%W2N6P#20'V%_S40S
M[8ZW.N-6YU5WO--M7G5+-*:]`.T%(A;&8M7D0HR+7E*ZC-$W!^:@RRCFTF(H
MMPN5\B7N;56\]:8%"MZ;;NT$')5B!1227L8PEG1$89SF$&%"V"N&4)"X`>]B
MC(-9$>!4B1UV$!\X_IJ@<F$LE>,TW'\_N+!Y28#*3F$-]`2M`'A2BJ3)BH01
M,!4)*HPF31A875(;\RC"QLI+LD"$-)O@-*@)A(79AU6S)RB$=*"A<@9L!^O0
MW\`:<`D0\[^QT58EAH>D_Q0N%[@Q07IS'3W`!A"5/W:36#3!!$B>&I*K,QZ'
M\!<"7Q$S@H%2X8OHGM0_&1!,-[2QAUQS(["P4'>_%7]Z;36P!^5$X"-9>(95
M..AE4FEY!A0EST]#^U91E$H5`C-:I=%Y8;S,>'R-AOT[A?!$RZD*M/FH<"AG
M<=-F^SM=)@E82?\1ANF1>X*SYPP.CT=J\%43X4ZG,LXX3Z/-5H3)`EB*0(Z`
MT-*+Y@P.2Q#->7W#&+RI5*QMDI1`0I\=XM(NN$M+QT$UHG?30_\*-Y11>V6Z
M:P\V$J.\?>?!0(F@5'JW9B486*VL!4*.VN-X[SQY3R-1\?(ZR&@^OPYFW/=:
MR*H";P904]7AJ.NJ<-)8%)X6N?N3F/PP&4YEFJ-ZOT`\,/`1Y+S6(+TJ+>Q"
MZ%W8/)Y+0`^"B4=CL>(F8@38V03,5)[(NP&TR3H^B<9WM+34##2OW>DMSD/@
M@E'%[ILU#7$-G5^`FF>1GMHZ=2QX3VL.:Y=0DW<H6`.[T:1*HV)E/$_,JQNF
MSYI9H#.C&DV@E#S5>F75R8"T-*&I?01%NI6!MTJ$/'I4]5@(8VUQ(+5GJKZ]
MBMJK\N4)9,;*N!@49$/P@0(C6*NX\'B.P*(\:*^+1[BCQ@<5KSCT5P[J,@QQ
M;KT0'+`'LEU@I]`7\UURP=#)!C-FJVZW"NAF&+EA=5HL_8"\"56,"<X.YG+R
M`F):+D(:L@*)_.?22^3D&MR9Y!$%S=GF$4;_ZC9.)84)[5"0P/+A*A<>6,%C
MS2KQ0]&F?;1&G&(YH8LXF\RN<R+Q+"+%6I&TQ)_-%$S9?]NC-\Z5$._GS8?\
M&A,B:R9`E=7-`5<]-0U*,G,F%$]XVP2:K$+[7-Q\`.1A]_6/ST-.4W\A=II-
M&;V\M`X_76DUUD"7BV:"E[-\`CY3H,\$T`W29RL"IOU"\)A)&3I55@<<5SVU
M\)1D)G:*YQ/(%=)\)F[/0^S$Q:S#5UAM-4MM_3I["BTB*H'5'*?3)/)]//P8
MDTLH5!_90_/)E6?"MU')J5"G8ID:1>@CV@8>I7(`Q`?G8PD6TLHSD>2>&Q7:
ML);-7VX-=M^^A,`<7J5HNRKB4"WRSCG@AA8,,CD*96XY,)_)3ZW158;%2JWE
M^$*LYZD4[BK/0NU^-L]<$ZT9NM)'=7R+J`,7$D]NM,P@C`5@BHH)A)]]V]FU
MK0:^]AT5"E#ERK1C86J5,N%8A'%OG@N'RD>9AI'VIO$P!HFXM7"+:,/Y]B_:
M968'N<BG]\0+C'@7'F4CZ9P`2DE"VU9)<OQ'DM3+\4*?$(SYB$"=]_?$J<S<
M(TRWT@ZC>(\V"D;`I2BAT5!Q`1X"5#`;FW'BSG?BRD>@@CD1I`JI*Z9YZP#P
MEAX%IW(("U7!D?2-S"8F^"K?473+SC0XQ>!R-P^H'//#"DRBP,``CZFW!?P7
MIQ2V!#!<S+EUQ#X4P`A].0XIJ%L&U]O*,^9,<@33C/<$HM!_9(9+3#(AUSCQ
M0DJ1<Q8\$2DHJT[3:I@B&SX_B5D*BDU"T^G/-<@LFJ05#%::U2QTQ*ZF*</'
M:WH'=3-$)'3XE>CI`>D()=I5L/#SYPF>1/-6Z\2IQ1D-CCC5!#,#E>J@=JJZ
M6.=.@CL%"?C>0'V]VM`)ZH@I5KFW$O;U!-$5S;_W1*=S.IH<#HXFI^>'@Z:P
M>V+L?#"*^L3MD_TYK-X=#H\KK+"HCR(!)Y9:L0OF5B6(">:UE@*O5:S:"588
M^FS>L,W!?"6J00Z"+#,+0'6(.%9H%J8ATX*5IL:8=XROH-U,B2&*$UA>1WDN
MM/OW_%Z-Z/6[F$#&O*)1QBPPOXC9SWOX]T].5VIL2L+FR8@MF)8"&W8F@GF'
M1LI6@1ZAB$P!XP)OJ-,+W\?,/'',M,K#:A@>`?67$YDGSZM4AACE(VIT("HS
M']?.?""#^BF.5Z882&MF&.9.!ILFN$18!9>ZU]C&'>R"QX1/4)`C&^/;D\A6
M.)00PZXV57'C`CN%&VN(V(U5\F^#;6*U79R\01.V-)NL4Y.MZ$&AR4L,4N]?
M5(+^)5YT0W5._:B$U;AIF+(_*4MFR`SJLM"-VJ2M28Q2@\W)42(Q#("`7<4[
MV.BSH*MW;91`*JN#MFD:S/Y89I5!&&#:D[!#`T@Y\XB-GC[FI1>@:3KJJ8GX
M'8?B1H8R<7V^-(AW^NA@EYGXWBTH7S].FIA;Q0?1'LZCJ*FP/SL?#7I"'=O2
M)9K8.+38+LPN9?BOZ5`:#[=GT%8?IX(/@4%"ZMY)DMJE8VP\O5'+X-^:IBT\
ML(>2^T6[&65J9Q$E)_G`I>0$/7`9^#\XIPLWG9!7JT_--H0!O')>5PX;\J.4
M1L,>88YVO@QIR>.LI"H"!(2N\:0ZS5P?SZ'R$Q'%=*=87R@"KRX6*9?07/*H
M@_CV&MWER-T9'=FE&:82J:XV2*'33;VX\$`+454SUV(/)>>2IRY?M1JJJCW,
M&Y>H,,!KK.T5QTA>>LV1C?+>U3VXJGM3VF1KO%/;4$7:_2P<U-6-9`O;K-#E
M=MY/O7.I:PO=4O4MZQTT35>O6NJ:5)V*7,F`5^E\V&U7/<M/!4(5KZS0I."3
MG8(7=LI-[.>U.(06A^0[KDQ.K1:LU9-ZOQ.,.:FN?0[.FK:$-3CA=?*4R-=H
M\_J6C'HN%ZU(C/CXLJ3!M5]2-+D*VHADU!3-J)DKI*=H[4A\+'K4,9LI=32?
MP\,?LT&6Q?8'PCD/%"S=1X]=+Q%;^X+N5-^["2@P[H)O?HM9=!]2L<7%+771
M9S<(MMNO.V_`W=JBMEA";9:QP.)6S[*^KBU8.?JL[B$E.%4_:PD88#8>E".O
M9U[U4[8T]@`/O'L"-)?J#*_2T[%_+>N.N+SUP'V;J:L;C89>QIA6V"!_G8JH
MDW;C@CJ'!74N%+>B!N@IZ,@74<73+H>HUM<Z[R07M"?T">&*>BX\QJ<<B3<U
M-?J\\YTZ[V2SM?'4$P-;T53'L!@1H=;>`J47^4NRY]H;`JRF2S2T^"F$N)>^
MWZKC=W!ZF+.K=?'HQA_X"_F(5WF<'QU=#D:7.1^>\[24'*EK-QI<CO`J"G;C
MYB;Z__Y0M:&!5CZ&:2"UEP&XE6MSG:XI%"IE*K5;-`TBH`D*CRJO5L>IC>(H
MM;%RAEK:(GPY3:7'5B(L93`@"E$^E)GET1NLX(E9-]4`;SL\>8-EJ'8'7^[Y
M6E=%3'>X$C>NO=C0J(\&FSPPV,U3W"IY<$$Y/;HO#RJ2CK6SA1M"<1[94`!C
M$1U%,;`[;C#T2:+ES8+VS?N3\W?[)[1M._0)#]Z%7<*RXBYQ*X11:`VC-+OD
MKZ44:_SJ:)[?GN6[VI1%S.,;OEJF;FG=R20SN7!00T<1^3W<PEU$EO1=E>R(
M4_?Q6GV^!<46RO9^46(TBY0*P%Y2NJHJMI1PN1>>%K?@\&+M?C5\=G/2X<7Q
MV6AP`78[`<!]_,XJ`4451R'8:Y1;3>8RX:[XM@[G%G5;=9%7!3HJ!4#\HN01
MNC?C\^^?OD/2:*AY:JIKG(`W8IQRY?XA*$-W-C,&419QBR,D2OWB)V'MH9C[
M[DV+FQ\.@'&"%VBEP:'`AZD.?MH_>P\Z7%WJ=D,V93C3ZYJLN7JR(=E0KQ`;
M:S5AHZH"$8N/,*"/+&X+SQAJU4+98P8JK6-6$]Z-1L5-5LD.??FPZ&-3VEDW
MM=37`7ROM4Z%\URWQ/-RV:7.<UV:ZV+`HZ7.5.95=Z,JFAGL-];&X?#'/BCO
M@*B(\(3KX_W+1UX=:1&+-\@CSP%#GPR`C9;3Q5-B(:&1ERL3BQKB5>N0PP%+
MHZ4RBT^!\41])P)7O+"KO-SR<[3_#-9X@Y0^ZG@"Y@V`?,:-J>?;]DKP5Z1)
M.9G([C0F)?N;4Y,05+CWMZ+Y@?T+9^=3\RJ/&B9>.,'616+1P=<<U?49R#S6
MB\R3G*?%)&(EY9=(5CE"JA>NCFA5NFI,0BTX)"&R'H0EOQW>>:_X3>A.H(-:
MYE4/UDAKFTEM;%N3T]:M5E/;5;[Y,>SGI+BQU\YX?:RR\T:L3-35'W#+UZ6\
M5QWS:N:[%*NMG>+G!<RU1U^EB)FR3&N#9O+[UX7,6&D$S&:\K&Z"FPN_<@C^
MW,7/.;G5M;\N?9??0`]FZE2>#SQ+WPGL*$-_YR:@5LG`ET#9M0V]RIC\@M_N
M]XSKO92]9`;B\/A"YPM,!(HK"NH4&V7-)JH17Z_0ZK5RFY3F/R+)]#=+=13W
M+5U]3Y\Y1#%]WD_MTH4WS\RA.2]$7[Q^>F2*B3@?CH[/SR[I:*YV="QYD7I[
MA3FWMM$!GK[#@!7#$B#E*LXKFV#@)QO6YZ//Y/D>*Y$GT?/([I]%M@DE:E?'
M`W2:-]--0).ZOH\HS*4+J,*F:*_I&C1;&LLI:$+56#3;30IQM$N.VY,/@<![
MTE27=O$]2S%MYC<M^3;9<%%"60G>.KP?:??8=DNLF1[:D9A&T`*01C>']"LA
M0:J@MT)4O#Y3=4"1<W0Z6L^'^\;ODRC48D:KPLUK/EG$+Y&6].&INK*4=LR&
M&MG"'__W*+WZ>S`EG5=SK>0SCRC`JKQ%4V(<5?"OMNA?R8<XH2,&T54N@OE+
M+PK#ML&;".;81^Y.J%=UTE'5;6QD5VS<,[J)O0=0,T.9'(?31>&\E$KYL.2+
MNN'A'[D8C^>]E`J%PZ_VVFZT"X5&ROBRK#@]/3R^')[L_UXZ0^VQ;2U.&-=?
M<\2P%^^.\H71%#,'8XB!FIM:D%]&I&LDUHDH),P=OCP;3>.!4`M]HE,8%KA\
MP2T*F=<8]',34?Q%$1S+Y64KZ6ZSP9=GNIOC,/^NAX:-B0V0T/>FO/7QU)T^
M24T[2$J??.]P3IROQN'A91(%_*;3+1U%N=L3KD@?@^L(&(H36`G%1^EQW-:^
M*FDD^LQ2X'?6&)/)*?ZRH.21>JW-"N>?#E5K/NM#HN'^$+\"*GG-^.GB^I0U
M)6(X8_W_Z/L@&J?^/$BL.-45UXI2TR9MOCW_PQ\)W4I9.E[?<(.V=&76R!8K
MS67FQ>GF8^SB[Y\*Z:M518.__Z'O?&NM?EHR,SX_MAWF`C90E&_.*;WE_$5\
M`WZF\7LPV+:6!>KQLF\J;LU2'F+EZ$UW?__UNI_BKZG*U,?LL$_*XM0+(6^@
M.?\V'X6?O4$@\81$CH$[M'Y;L"HNQ(!"52[5VFN*C:X6IHOW$_^WMV-M2B/9
M?F9^1>^$K1$W#$(T)EK<C4E,8N5E13>[6W%7$0;#%80+J+BN__V>5[_F`9AL
M;:HB,'VZ^_1C3I\^SY+;+/Y&TT2R343C1':F+I$?<+/\<R#Q2\H<ARR%9L',
M`5(\*_"%Z[5Q&T;<B)TZ,W?:+EM']QD;Q\P!G*-'Q)U$R)Y$VTK)684/&YU1
M+_+L\IA]*M=5LZG"E_M[H=*LU*.["-LG7M:H;!9UP([4[#-?O5!1[4_D63_L
MO-^M_=#95I-:O-I4M1I^.XY7\<N(>LD(G*0WVA[1,Q51?`%J-H1&8J@YJ0'?
M%.'G4;D6J5IHVM$\HML&#0.H,K4##PG!!/WZ34FM9DDL%ZEX]<<OZNC+'ZO0
MTU%4<XNIVZ/H")#`]F0C7ZGPSQ7TQ?_[QTJ("`_'4X.7(P#1EV>*YA+!%L(`
M#)<3A["%3^*-61WO"?!\[#ROUV=0A,_[R1E<7SSX=3+:'P[[P$..!/X1%FS&
M:UC4JKM=;#R-UV=/UN.U]H`*&V[A>B->FR&$%#YR"QM/X\T90DCANE=8AYH(
M(84;;F%]/7ZR,4,0*7WLE:[1*`!$2C?=TLUXO3%#$"FLN_."XW#Q;;B%-%('
MWT=N(8W4P7?=+:21.NAN>(4X4A?=Q]Y*T5`=?#>]4APJCH@+3[V5V5R+'T/-
M-=WMJ;<T&_!\AB!2Z"W-HXWXT6S#UO279@-J(H04^DNS"9TBA!3Z*R/;2/?I
M+<R3^,D,`?10_'&FL/46A@;J8.LM#(W3P=9;&!JG@ZV_,#A.!UM_77"<#KK^
MLN`X83Q<UO96Y3$LZ.QI7;?:]M^7#2A$""GT%Z6!^V_#%/J+THB?SA!""OU%
M>1PW9@@AA?ZBU.-U&`J`2&EJ5>HS@M!C<<>)PW#1]5:%!NJ@Z[\N.%`'77]5
M<*`.NOZJX$`=;/U5P8&ZZ/K+0B.%$5&A>`1DE`D^4V95%EH\#WS:/\!W9;K=
MTH%\6*>LA5K_+CN6@]6W<&1TCH7/M$[B.[BQ'(3X<A!QV\Z44+RC9=A%AWM+
M8V.]3)ZIVGD+OAR5\>\SP)-8MIH>5&T;0:KU0=2JU@FN$WC.)H%EYX)Y[%SA
M.)=DZ'S!>JY`'4=;05$5<65\QR)A[CCYVII\K;##0GF:S/#G,=YS\!Z(@2/I
MR38'74N.*6[%MKJCRE]O1C`"J-SI38_Y!SU'-"HLY]Y6A9),5;ZM_X3RY3L.
M!81\3;867?\-)`'2'&4A^:WQ03GV;AI25`\I6)RC5K]?46::4`ILIPJU517Z
MBP4Z>E&!H!4_%HFKI<-%8+Q$BZ!X^A=!T;S#OR\B)?]C406:?K="5IZ>K<0K
M<<]*)+R_;R5<C3G2_=?)E",S8Q3"K853")#+3.`R<[;4%"TS)1:&`CE9:3;^
M]C0%UO[,V+N@\ZUC:!(66IJ$&8I1W:^89LJ-;?T.\<<V`:Q:"(EXUK!QSO!R
M%9TX%1CK'&L;H#-+X&B]#-*8MCJ=ROW5A.)QV^EHFS`[T5H5QD+/0H2TEI!I
M4M+_9B2@;C$2;,^R'!)$=X-Y2E-5I!AB3+Y4]S4F?V1U1:5%JB*UZ)_3B&GR
M_IJD.8T5JY/FX7)?]9)9'96G>G<4R+`J0<FX1-#2R.9MA#KT;!BF#I&<I3"&
MO"_>O[0J7Y]LO'(LFQ^ZGF;:^GK4&[$^$LOF-'1X,^IA..6;AV2);>.3I1WC
MU,''][M5E,HXLB6?#*>:1M%H%6V_L6%',\KFDZHCZ'-K$H>W6BET5?'<2$S4
M7J%4197\0Y_($JOHV2UCV9<X9Y7$D)J-K.V$9%:)`;0K?]J)Y*&:(-F!28K6
MXO7>Q<-JHW<1+;'WC->#1Q.(E?PNHL#<-DGJYU,"HZ6PFN/\M_T>)F&^`MD=
M_)+'6LY$:8,=;YY@XP"#ZXC12HN/#&X]E_EQ:/H<*&=JYT#E4^5E*WB[<ME*
M+L&A>:=0GVG;!*-H%+?(!\;,M4XO;8Z15#UT?")O>7-$F9DFKI.F!5<BM=F`
M5`S/+GK(9QAK,HI2O:7]T&V596S[9(N=A!CWG;U>9:"N]E]"LIS^E_3UPM>X
M_`P4N6[2=0G.C8YV@<X8P$!-^-(+?<=8FP[`F'E1N&RX[$$=ON/"[9;L$*+R
M,T,/'"_84A#0Y02C2$@@(.L?(;H")Z;/`I?=@L@]N;66B,^#@7.^+0I/0<TE
M8^W@,NHKF^CP4W.4CI]1XIC`4*K5;!R-P-'S^%T.1J1\=R[!W%$FQ%*F9Q.`
MV'9FG:GA-RD$A\WRWJN#H`1_FEL260!?:$K0P8_+0W^SL9D")AOHU<K25IC5
M'[FE@;5%0D-C&]7>=;/VU8\V2P8Z8\E#P2`SAV4'1KD1+HJ$/X*CH0E;*J\E
M*PU3$L5^XD0#Q1EB#P_T]4C=I-Q1Z@0A(N1(CT\>ZXYEC!R&?GC1/,F.-E7C
MQ!EG[C#3%;9*9=T\+HT^]O*!79E@WJ@PTO"QCK.?6K4K#N43D,UELVR?Z9P*
M?<JI<(O)$GYJWLFW*G*%%/?_CG(M"%Y0`O_[DF8`Z*K69D4:O!S99"S`M!WK
M0;KF-5UFCS-:V?J6HB/;C4D`3_W1&^-O1]#E))6)FCG_>&?U$IV$X?1&XNNC
M_PN]9BJG5L1-^GN&PFE*9+BKWA@_!ET)H`._X:^8OO"92^<<QI>;#H=]^G+]
MM0?,G]CG[+_5WPY?O:?I64B;]*3Q`9A";C`2>$1EQ-9*?&`63XZ>(Y,6P":B
MF`.N)\?;>DIG>N*$1OQ7LAN]FXM)02:,E>$Y.JJA$S%?=3#10D4M@8G.'Z)^
MW7W>>($H81XD_8E7&C5"XRAO,QEQH&B$_5V&H)E-YX,@IT$V*6ES%*R;,CEM
M1I-IKWU^@Q9:G>$$->)P$9N.8=M<HB$4<%/T"_GM+IK`P7#(Y#BBT&36A)<1
M>7]X_&IWY_"73[L'S1-6A_^Y%:\ZCZ-4#"HKR5EMDI[\#C7M:!>)Q$/0I-0C
M*<PE"8E<=)T>Y,H+K%_Y5H#OQ)B8I,_RK#ED*3)%BLP6=KM.Z@!-YR8Y0VZ-
MSR:<02X=YFJ*B<;::*BVY%@R*$C/UA@33IT9U(8N#6L(U<GB-,L(.A:EP`=F
MC(W__MMU/]/-H%D*?>-$--Q_23J6(MVWO][E^K8Q-*^>):J.#(P@Z:+FUO$6
M;LOVN&3<,KNI3-PRBX[SXRZT"KCT^IVEC-0]/RHBA,P-HZ5@'\4'VO(;QR1T
M4](`3CC)%)MK`]JG+8[*G5P@-:B)&,(8]?G>F^;M"SNCWH</'VI('N+1.06E
MP70$PZZB1U`V.H?U-!6PMO_*AL"D7)%D1F$RN'=[NY\H:V",K'(%ZOK@I@'S
MECL-'/Z^O_MJY\6N-)!<]N&BKYLP%8[X:.<T("%ZV!Z5/^]PVC=W!$=NOH^0
MDB-Q'<9!DR)44RGZ27D,*5C/M7%_Q3-T!>]GF+RPDW0J[',-+TC9-E'H(&IX
M6]<!(6MW:#;,_RZ3\<TQ&;$*M>V1;C83T_(%!S4S3KIP[?-#61I6XU:)32S^
M03=0)S,)/,(;8JZ)KO`DGI.-N['9(X*QU+//D67IY$<6R:P*DMA"EW;.+.`L
MH1U405(!#?G]>070_QSS/SG>SDX2AN]VK'<\?_5]3SO<9];;ABZQT6RR?CSS
MPI?D+@U_ISUD4>"'V)NS0>QCLTLV-S;L8]PI!CV5TUX-245NDU3B[SVW:''+
MT^Z@J&DJ*F@;R]*-9^F]/CN!UIL-JT*S'>%ZHZ?`R?PPL(%VK%DXGZW)K)E<
M=@?U-7V6G0CI9A):3F:P3T;GS7)#`8)H!EL022$T%N-3.(:3J4>4Z)A'!2/%
M)J3L#T#K=V>MP:B/-J?\ZAC7>PL/_7,*,S=P*VQYHT;`[&@KF#\)PPC$P#56
MMOBE@*GJ#NAS=(Z=N>$G-I<)"X`3^NFC\=XO3/)$=NZ3:>NB`_/NY'MR6OF5
M0P@4-@&=%S8`2XM\<60)#06.`*K/D!B-P1P63+6!J$Q[5XF$(-".6#JGQ9QC
MFBN\^_@:)O;?#2W`HZP8;LZC),1PRC#2('HT!,-+1EQKFGO!(,GEV\6T_\X5
MU8?F&`Y1/@*,\5)NY>0^`:2>)2+,Y!#S8]9)L[PK>G%PSN#JU.V-)],XT@W-
M\SO7./[`M$>/(/P6%$WJ08X7@JCF''`<=8`S)&%\^S.4$-X+5]H+WX6I[.$6
M1DZI4K[`/$Q7Y*6Y_ZPZ3J7ZW:THSY44/1QX#R[IV5^RS@WS'/M=`Q\^#;7D
MTMVLUXHEK%P2=UK3$W9CF_A0$@9J$@^Z]"+RH>'#X"DRU3F?3SA?K(X#V18W
MG]/+7A]#L\".^#H=].%E[7":`,Z%@]$..L/V)0H&B*Y#$\]OU,?IM'75&ZK7
ML?K4^^NO82`-'0/LPIA!>ZHUF4"+3A=(HKQN4/[50RH/S'X[A['"#8<CP<1#
MZ`&E.2J5SM.4RTK](T&*`#%,OX1[W\K/X:%"@?K+7D?M*3PE6[!)6Q@#N'O9
MM]C\')2T'`D#]Y)/&]<M#:[P#HVV,K06,2V+_S-^OO,6(!^H7UMC#I8#]PZX
M9TZCB3H;4II>6$!\YUO,#P2E]()TA^85Y-B@;4JX3I4PIZ::]@;)0YT*_;I%
MN=((7%ZNN#8X)]3^D\85?2EMTK2*C2G(;G8F^[2\^'`EM-)&G`/,[W8127JW
M'\+T54!`>3NTU'ERXR:S"P.;PT[?$AY4,__4:7+6N]@B42),2D\B'V4!,__\
M]+EIF;T5-HZN.P&>2%HFESZ1]',\D1@.;H=9('BH(=[OO-5MR5U29`-W@>0/
M9[&?A0NH7BK)8M,J>9CWO$M#-2F$;Z_-!6_W#W:/7WX\;%*N\CN3K%P_1S6>
MM6J4E,\ZE,O8RQ-I1,[9-$K8`-$Q[PLWB6]X`$OI4E`)6-9THT0%HO?1#Z^3
MTT8[H+C>_B.,3NT_T2Z:^BG^#HS#9=.X<-;0V37PU>$>#J(;#URQ3;-LET2O
M68P%`=$0J3ULNYD6B9JPEVL0<.J\V\][![_LO*N6;SGK5Q7N_!U)]G5W%TA"
MN%OZY#(ZJ'*48%I([NB)^,GP'(UI1>9UL/-Y]WCGT^N#@&59K&#1@*)/X@2/
M'&$AD]QQ(N:!N'BY;V%RT?FF=S!P0CN0Q$UOK-34(9T6@8/,I>,]#-#CUDA%
M\*2FMBFWS;AK:KI'@XUH!?U0G0CC29">:PV^JKIJJ,>J_DC5-Z`'4=];2Q@:
MOTX2WY50\S4=D-[DE[=%-@H]7Q@S.0B<QM)YS+SF,DG$<MIS==9!IJ;-\8/5
M;@M5Q?.4VM!I3LM.NJ7"II?0?%/C#[)#=M*(0?,/5'X'2RC(BSKP<FW-Z6))
M33IUX^?+#=CSC"UF`DQQ2B::?/MSS#DDS[NQ1(.[)F6LO1A>QW0%E+3CJ+0-
MX"J8)!>4$QU:Q_-]JAKK:CR\9M8?&*/VL'\YN)C$&"S1,:<>`T6FU*O7#P,3
MO'#*Z;*M4E@2T',`P\L)<2.`^6EKVO[*UC5#I]4X.`1Z%/E&PA$%6R3FB430
M4$'N>3'0R&$WT+FQ#W"@V(,0-)D(3H%-W"Y.1C*:P*STA]<\0<2'L*R:IL*;
M(HPAPJX``_1$/X.3YH&.-X)\1<QM]A-T5FS=X&/TWK@AH\#3RREP?9BFY_PA
M<&.DQ)TDR/CUNM`,\E64PP>8-)A'2MH>!]S6.KP@AAK=CQ@54J*%Q-"AA<Q4
MV3!5L:*Y10'T"5Q"DI-0_8?SRV0";]KT#4Y]*VPAMK%`I!2\@0V]19,N&D98
MZF1&80;[.B[M1`3PK/:MX*Q".V=)AU+7!QS?WP;@[`_A<&J)Q)6L5'D3DJ\^
M;>GVY7@""PR<XX1NQC#SE%6>`V7BJE)@4+K@]2_;YRR@^JE6I??C<.=YC!&C
M)6Q6G2\UN[_M'8:E"!="0@/L?]I]!4_0*&J(HW&RLPK$BX\?$((2%;?=0'52
M_FGWS<[!&X"0VY4B)@I6HX4G@P"]^7W_S>X'`&+3&#Y#IR216#'41R1%(5D;
MER(O2=(*\C;"O`RZ&O*WEY_W`)(4Z'FX0?'^`3;EN%+Y$'BY1H!Y4D+=V,<7
MSBCI$N'=!N\3$3,(2EK\E+G$L2P*I]W$,$CYZ^"B54J9=+ITH^?EJ-@\:CF>
M.P3(2U(I64*/3SFX<#JM%9;@7!MHFG%\2C-<\4+ZTG.<5XWB@"S_8?HPIJ"Y
K@>.S^X0F7,7:2,(;KIW#9`HGRJ1UD?B/I4VF.$;004*._P/,@?+Q8HP``*"Y
`
end
end-of-input

uudecode <<'end-of-input'
begin 644 teTeX-FAQ.gz
M'XL(",_**3(``W1E5&58+49!40"M7'MW&[>5_UO\%*CJ$XE>:FC9SJ-R[5:Q
MY4:-'UI+WCJGVQ,-9T!RPGEU,".*:;J??>_O7@"#H6373NPVB40"%Q?W_8(O
MEIE1]/]VJ=7SX_]6\ZI1K;[0[]3!@8H5?D@STS;9K&NSJN3OW[XZ?:>2JJCC
M-IOE>F0VIM6%B=3I7&VJ3BWC*ZW^V6F#'4;%LZIKE:D*K>HJ*UL<%K>JT46<
ME:HKDUS'S61$@#/9WRZS<B6+\./"T&%=GJJ95JDV">&B\4O;ZF:B?NI,J]*F
MJE6A1['*LU)'ZN5&G1#T7,5IVFACCD8C9?]<+*LB-NK$&-VH/[;ZSUE)=RKH
M*JNH*[.#95R6U95NHE0_&8U&%Z!/W+098:DRPK4C%%1<FK5NZ"+5$0&^-U9_
M6^I&JR0NU:E:Z);)*60,J?<G6GPX5J=,;EH?*R!)-R2TZ1:>]EAW?ZQ>56NA
MPJE:E>YGV0FD!IN/+!,!M22$DV5VI>72U9S1P2H`?D`(J,YH=5:9]IRH6>-D
ML(6X46Q46B5=H>GW"+<J5=WHJTRO<=`Z:Y?J.KW*)@+Y9;P"NF??,W?;K"#2
M$/T6#&IAYFU5KR):^A!'%D35E#&9967<9!KDHUNDV7Q.:)>MRJLD!IDBW'Q"
MI+A6)MZ8(SGL\O(4!-XC;+-2`*5Z'G<Y$XX82)_G^G=[>SCQ2YR89JDJJY9/
M'AP\4<2/@%.Z::KFUQSS%8XA&:.+L7SC*[Z\\/^Z(-(WF@3RVXY/VA!G-.,T
MK[HR!8BOQT+FIBM+T)CA5"3M1&8+KUTV5;=8@E;T6=H09TGP!?UUW&";$>1%
MU9*E3E:F*^1>!J=\@U,(=ZOI,])-TI=V6:5@`@#5JUX*8C6+VV2I?JIFD)@_
MV,VT,JV@I*>JU):7L@>2:S2A%>=$;=(0VG9(:O&4%<(L<>M0)1J=M%6S8>)`
MD]>:*-`+0IW'+8C-8$AACN>DZD[:+DC<8N*,^_7Y2V6ZA)1\WN7YANY2$AJM
MQ6RB5F2EEMK$0B!8K9S,CF$0:474!3>@#L"OU.L`1,HPB'R'I(S!<<0JHU[J
M-L;7HA0Q7]MI*U$)4/-LI;'[0:CRI=*QV1#?-J!G4M4;%;7S0A$%(\^#>5,5
M!).L:EV!IIYB<@O:2-`RHGE+UXB;-"#I3.=D*NY<G+Q[^1SD(]W[CCX0R2!1
MA8S53;5HXD*]^^$'G`M+DC25JN-D%2^T.O[V*1]A3='AE\Z^F27;83)'6M>P
M%=#8G+#HYG.U;Z$2S1D<_3>*HC$`?"4X$%F(-IJHW\9Y#E)`SDEJ##P+S)0[
M\>M@0Q&70(H0TM<ZZ5KA5),MEFUO22J0E23620Z`L,QO>B;;<R.S)`6G\T'J
M#`1N/2<"B08'"DMO-H%59ZS\6D"Q->F'I!]ORY0D]-GK\XD8UU3I`DM9.%[\
M58#"H&:$9.%$AV7&$Y6VR7&P];S1T>,^J=);`\X!P?-E0_[Q+FQ*"_]*"LLV
M6;'APDVASS-B)NYEM!`,VF%O`W)68J/(FY+JD9#>AU\BJ2R9&-`'XB1=45^+
ML?1NIZR@;DMH$G$&)NP^:8=5;"(U+.>Z:E9R`Y*15R?O+LXO3LX02\"11'%=
M3]0:FN*O3HS&-4E1SF'^K->W:L302+AJW>2;2$Q1N)/(]2?RU,?BD\G5$[4^
MVB&/)":@T*3)BICTQV0MWQ,>3).]+S?6,:AY6Q]-IX:4GY9$0=C0K-OE04SB
M1Y1,]=&T[F93&)HI46_*A\HQ+S/88S[!#('2OZ.4:*]I/W8=6`<^M:'5E"(3
M!VI['RV/XB3J5I^RT=V"HJ](IQVC_"(KN^LI<<?TB$\MM48CDH^/"5SXE!\T
MR?J%%9BJU/TJ`I=TAO4=!AC?[4,+V-R._3J&`EDF_+0-1L"D8#LOS:S?H],)
MY0^$<A:@^*P0\&UP#MR"_P3P`KHPDX@4:H/K2+1EY,YD`XVF4XE>Y*"@=PGI
M/?D?I\L(5WUH&L`"&ORYI<4M7WLL>0%%N74$'(KXIZI)JZ+Z`/)*J.F7$I(-
M?<.`.E@R]BL(,>=Z358*FB3J#CY(O,"?+G5>6]=2=;)?0/7W1A0NQLQ>5^UA
MUYZ+DF95NHEXYZNJM1YTP'D.F6J*5<FH4O90T0Z"YJA;N:2!5C$46D*"9U<'
M`B,>?P!YPANKDER^Q#/5:(O.E;4;"$5Q8C0:D;'[3('Y("[O]>:O2&BVI&9`
M0"\0;-<8MQ#L1\O`:/0`.OUY<H&/2P6<M04QZ!\0#T`KRB(+(R`I%R1^V*#`
M@$@+\R!Z]XY\*3#HX`89C`-*+B-G8WZDNIH"D)3YADT/'B"ZH9B.+CP:/>3+
M_L8LY*.S@]ZQD'G+YAD=^CTB4:.1H\X:N)K]_D?"@<]U*43%HKLR0MQUDU&R
M6ZK91GU/Y%'?4F"_&4N<X9.-&ZFZ$;?'$*[HJO$,D,]/7CP_?GOQ^MGI&]8(
M]_O9\9N35Q=D1Q#77'G9=]0@1HAT.<I!:?F3$*!-+_IHE(T_)08YK(3-POIO
MA\:0H0GLVS"#3R;!K&/FD@?BT#BYCBFTUX='*C:4^P`FI!/;.-<"H::=:=BW
MT2G3[.$W7QWD[/.P,/)JI=3C)^&MCOSGX?[;EPNN1\/E0PSO?S2&GXK61Z)D
MT8%L0M@D3XV2<@Y,2#[)EG#JTP"A.\&)D_XW`2K22;D&91OT/1>`VEO`SON4
M=^+$4KE=7C:M^891;I0NK[*F*F%\'(>10Y,HE8#G\VL^@,]S9)Q8:UO$2(9@
M=+,RJ1J("X,A?261LS+=8V'U"*`B]109M,T&<LJGB%>VA'1*B8:5-'$?4IJ"
M#76@'F]1B84Y\_ON"_5O+&8"'E-TB$5(I]L6(@(^>"3E,%XBJ<DL.-:)`<YB
M'YG$A@,QE+`0"<\X_"`*9M`@\9L2&-FBQ*)B5:1D"*9;;QL`X8Q8&BYKC$9?
MLE']-8663ZBS>'$MX\(%6+<MA@C\T6:A3Z)YT2+-T#8N\%\X(Q4"LU:'^8G4
M<%]'BTC9](?^-8X\#KWU8MA62#P.$JX86@#;;&PB/EWKV?U$@/S`AY2#Q,RJ
MG7@W_M3&6Z.=54V24%6Y.J@576GD8=@4:)Y1M$9<JE82'4GPZ;"$?[/J$B`I
MFN;"$OC(JF7ES5K_\814$%67@1+X,)`A[/NR24#*D!^M+3EY[>?46<>I\R84
M8EBM4+M,;7!M=WPTVJ&?25;G&8XLY\23T0Z9!/7]V?'%=^<GQS\^._GV[5\>
M'QRJGCYKT$=Y,*/`RH%$%G6G0TN*V\!OKK?)45TCDNX"$B(!B8%HB-I=DSE:
M["H@@+#3Q7S^"VB%CRD@!')C)'QT!$,)C%K@D1F2KYO#/.YS#8Y+1/@.V!&I
MA>@NBAA+#&\T?9OZRRW(=1N)ATDF6C`EU;-NL7!1DP\($>#8>KVM&G@];'1L
M;*F_Y<R8R4'1AX\`<`Q9A*ZMNY;M;2D1:\;5@T)S$9$LW@$B8:O`IS?DPWC#
M8R4.R-A(7"6$A=1ZBLA97A@T7,GS6''B>2VZSIV`IBM#X8&EE]THU)&BZ0QG
M!="'".'.A,5$R7]E#UDOFS^*`?-A.7-G6=5:2H_(:X3XJ+M4.7&3+:8E8.3(
MX*\9T]V!38#"1)$RX)J-GD/[)`IS<3CS+4P>7,F.<>V+-Q04DW6)<Y+3N#0"
MY_ZA6+'15VRS?U/5VALAQRTB.W8N8[-D%.K4D3<W!V^L5V6<N$J#-8</QT)5
M"OQUGD<1R<G74KGY/-7P]Q3#O5FXD?/$DN<2`UI-["01:1KXP=17#E"H%2R@
MJQ).^,3!G;35",.^_1?Q&/;!D#@DVKM2QU:)HZPJ\D6:+'4LML)F$/T[LG#I
MCF'U]+!GR-47%%;35;]A>O[*NG\HKFDEER&;PCE9SPYQE3>$U)=SQW(YIYQ2
M@,ES"`[D3^@OU<B""<?U6JR$(R9,C150:WSDLG0^J=K^C`L/L$(2NY9\K6FJ
MKZ9EQR5F"4PXQ:L;K@U8A(2E'2*C/.E@48QR56%KDUGJ!4\"P-NM>^T1VJ\:
MEQ7W6;J!/T19:VS%S8;^KNB'XST)+N'!KFO@LR?1PM[EE&BIGGRAIFU13_W2
M**\6ZHM>@"6E\GZMOP=;AE5@TH24VE6N=2JB.V"8Y7^R6C3LN$@(>LMM90"T
M9#E`7;07@HF771<1T"%)`1I/73$OS]/$LIL8)]]G@MU3TKF..SRH!):N<\/U
M&MYF/1$#>O94OB?_%QH@QNI%')3G`[5UQWH2>4?6MZ]`(I/]K*5.9)9QK0,Q
M\*GVIL[0\N"3!D0DK?>7MFB3W4^[I%<:9YTB'P-"*\0M+\JJ\=YN]`>GMY_4
M<O-6.2AI20&"JQRD[7`VME]EM0&.;M[+,*''V$DA3"),\A1B;&NS%2AQD(?=
MTGNQ$&T0ZWRPUS8G&T5EHS$.M6@/EG,K9`L1)^@E9&'C[*%(O6,I\82<QK[7
MD8EP82(L&-N\1PI&'+1P$6[!+`M#5G5PIL[>G+ZZ.'FC]B6R=[\6,%W()*5>
MQ;#<7;FF#<J,;9[%`8.7LX!?WCCP38-JB@-ECWNOQ7CNCB)98&EWO+!L=G#R
MVNN#.ZX'DO]$+KSQ15P(O5,HP5`6\"XXU35+`&<"1]8C./.5,,WR^KTVX@,R
M8\/:!E7K"I5F&&B1N5HGV3Q++`;.KIB6@S>?D0@1RS!5DM&/OI),`;[FT,#'
MUU:>Y8B-W>MP@!#2C[:6.(A,WL>1@(C>A2;7@MO^4PKNRJ?OY#<2#+8@Y,+9
M<CZX=R^MLQZ2Y9T93UA*PVL%HRN.ZL^P7QTPY.0ZR'/R>&'P-:@A7\-V22Y(
M%J&.#9!(472%80%WZ')HU'^&3GW0^5EJ,4'^VYZM/41)CJ5V@7*7BYJDXADT
M(KU'[2L/4A^]@83-`<B9#&N5F76#@Q:QI,MAY==TLZ!R.1\6MX`B)X0].[C@
MPBWP*5IEPZ+B!Y>9FM+]`Q(VPLW<CQX."@.<3A7D@R6_7"\KTAB/A[\_Q*Z@
M"Y'4L\^R)AL,C'.VL<[K2QS@F"<^9O19YRI^U5A%:#?(W=:Z=/UJ&])A?@*]
M8-\LQ4"!^_&"0G,;/;KR.(0BF5VWV>$]A$I^Z18#I+')><Z4+S.EL!X=T#Q+
MIBG^;V'0QP[$RF;=1^H8B*92F4/0CT02=LU51C@!SHAJN&.(A<.=V<OAOZ&$
M,8<>H+D=SZ3ML5&SIEKITOH3EWS3C](M@97VTETU&67V%`',D'@=1H</HP<V
M*R7CQ:9FJ[MRG<'PIH'(M$U<HU63YNS\+QHW!N%J/K"K@16B@PX2M<>0#O<>
M*9TL*W4GZ*2CW+`1C*0<<7C_:]A2LJY=WD;J>79M]5&":8\A>XT9R:A8WZLX
MRU$AX2J,#&1(#$M"6Y+=):DRB%5KM2B[".=%=#3W!"%\L9UWX'"P1*9$[CZD
M$S2EIS69TJYA,\!K]HG81[+RJ[$-]`@$SR+,T<64,`I!8Q^)L&1!MW[+O!`?
M]M;H/H*2B%3G9)D&]DHLO/&E4/R.TS_WO-''CQOU/N"MZ8,?.V1#CC7/VHVS
M\XTW\FW7(%^48&SW*FX8J5T&-B?UZAH)#7M8TD5X>W[RX_\<OWG^^M7%.>#,
MX]QH5\<8-!`8U+$E19__<KV:4>G)($4_=2<$S+=G&+MSJ-MN3PDR>XEVZ76O
M,_NVWBZC0"R_/&B5-#:VL.9B'"@6ZIOAE1[+?0(*'FQEBV[EWN4C5WTA]O_F
MB2_&Z&]DFUPKA4O:P6`.EI)X6P^:)/!5?5QT$`P2\:`8.W!*K7SI?M"E+#"3
M-=C,=H`#"#1(BPPN(Q:'"`A9H</U$A58>O>YGU4S::>HO0+XDO;FZ9Z+&^$C
M@Y:9S4AXN-E'%)$Z%@+&,#>>C'8>F6S_JO?1`2RFDR!Y)N4\F6D6GL"E$;)S
M9'RQ67'ZPPU79%K</N?M7'ZCU$]<+)T%-TP"1?Y8#G"7EE(>+@SH!::S]'P.
M@6%OG)D5Q5^Q'13I4$R:\%P=9?`4E4F_/)6*ME<5*4S6E3'9C-669'RBPIEL
M#C126QR1@+4$6[>,AZL#P3#]QD%""1@H*EDL4,?B8(',2LVU;NSO:Y>ND-O8
M;S@$&D28<5K5$F"1,'8)&QG)$&<;^[%5<<";>+=M>S<XU[MAV[WA&$%\./$\
MRS='$H]B-1O(%\P0_O%<_(7M8`I&I$A-:CMP+@/@"1C!BW419/S$<<JA.CN-
ML(58"JX4LM]F[LN]?>^4=1Z#/B,OU&90:DXKJ65@/;-2*DC$$E?B['T,,<3&
MU`PVX(OT*YPHB2]1^P@$W2,"=?B0D*^JL54;7R]MM.\Y<I5XD*]$G`A.7"8H
MTBMQ!-N,>]%]Y]_N10^<L4/DA"`$!+5U;&NWGKZT5]G_ONS(NF"EK$B]*'@W
M;\NS8\RG,*J@D:.;19LI!+PC5ZWSQ1*7OQ>T5IH5:5]"@"FR\+<5UH>+7EFW
M^6DVQ:RB4!=QW0IARV@K1OX7,AUR3O_FXB:;4`K$FIZX8Q5SXC!D@&@[7>;6
MU!%W>@\5I,;+V$PL/ZJ^$^XB%S90N-:VKPT\:)*&]PB'-&S0RD,-T+R[CQ@@
MS,@!Y:&9^N47&\AF^*;4?H"'CLNKJN9O]UR-F*66V?&S)C>:ZW+1+BERX#27
M[31'AJ270I8AS7U_8(L0/6A?=T2;TEFD,&Z0*EA?'['489QNQNH?O#:T?[Y]
M;Y>+-KK6ML]IZVZMKB5X%X$+&LT35S"1.I$T!@)^$-[XYY!EX>;G7Z)8_CDF
MOT4AW(C-L+LZ*`>X\FE?IO#A`U-60KY!3Q<3,6%%8'KVXOCB^>LW+Z.@TRS.
MV;&FY5J',S368['F<RO9YW/X<_[#.28Y+CONJ!\4EP?N1W/I%V';XR$6=V3C
MD<LQG4WV[3G-4$`^A_!@1$"2,9(?B8VWC(K<APD)H#STF7$4:!]$>0<<5'?*
MGH)\SQOB0'B/611L+W;++KGNLR-_'U]R>>7W*B^)*O,0HB3V6[-==]]K$KKR
MPT"VBS3O!\6]2PY.!E506[^@+`#4/[!YAX],F"R^1;$I<&^&(@LGWEY28&4R
MO"^PXBGQ*`?.:MV@<M+XR!1<$D-!WQK7O^=PRI-4-,A)/5DC&T%P)&OAV=L-
MQ"SD5CSD5U]><\.!O/T[EX*ZVNG.<%HI(/EHAZSWX+C1SE4F6/[HL-KY/=>'
M;-U'<D\0?R=94O*K_NMZN'ZT@^':QY=$B%XB+@D(EVUE])M\NR-0I$8[WE3>
MP;>PB:.='9:2+53N9*,=&$QK;"]@]YBM%*$W`^48TE#2TTS8'W&9@$31AC2B
M9/U,FG'S"CPT5W'S8L8U:LW1YDVMDIZK`*NXSQX.F$G'%+*Y-:,VIHR:\-5#
M@7$SU?PBQ8ZSE.$(E(QV8F0WXQE;7BS3T5RS9?\M!(O44XJ%JX+RP(F;V89Y
MZKW5[W\G:N?-H?_"CCJT2S\/$=BNONO*Y=M;*KT.SK>GKVZ3O%"5^R,IR>:7
M0038C>JPWUY+.IS8#B,:[9-^UUH[Y>]-K^\&^:S5PK[X[O3\1V>/MS'@69?=
M.X,UNRJ<.]W='0<II]W0^XOA8OSA!Q[CX6=JB,7C7D\>/1JN/._*U^?_8?>V
MR=R&<?KF]-U_`%%DM3G(FNSZR^C!]O:[-_9RS+9[Y]Z1FL=DP^R`H9+7+\R'
M5+<D*CJ-=M63+^[?V,]5S/!3;>*D/Q>_;7,&P8BZ(\(T'3)H>CDC+C`'[MR[
M),3^O$LQS6=[B/;!=VB\XD9B<FM2(DD;OQ+C5]1!EI;-@]QJT,<L@J$BC@=+
M-G1?BQ/_AJ.WS_P2;OLAG#@VZ;!%&.G"8*N4;;B:1^;\P;U[S\Y.51X;=HK2
M5J.U$6VP^N#KJK^\?/WL9*)(A"I;K>3W*2;>^+1BATZS?[BAIYZ^FZAS^N?%
MMV<'+]ZI?>GDC4>CS_I&[[8G>CZPX_<PKF,@S?88.9-:DE\/>IC;D!FJ=-=`
M4T'Q83^,@&X->["5WLPJKGQ4KNS,<]>`#U_$&Z4Z&\,*VT%)]0TG*IL:U%.[
MWYA=M>^*4L#AGQUEXTB(;91$XIO9"EQ5!J.O,TLSB)5D2+X+1C=@'9EG[>`2
MDT%GQ4FUG6(&X?>&57(YS<YW!N."KJ7*9LFW\[DE*S.5PFXK@/TDKY3F,:/`
MWMH6YH767'BA*",ATAK4;W[]4TNI#MC%_+8.P0`9.*FW^XJ5S,&`?O]+X&V1
M]U^TL2`?^F]Q0\\J=9?D\.[V$H+\;X@K:@Q^MD7MRS<XDTM:[HV>^UL@I$3(
M+.$ZC-L(J_"YWH?R@7]7KUY?G!S=*$RS(W^EWUWTK68[8NK;2%>95%+G;6T?
M'XIDZ9DD;V_?O."0I\\TEBT_EEROUQ$HE\D;*DVQ>#[3S0*/-?]OGB.:GB(O
M]M-WI7^6$U1!&$-;(Q5,+0+`1U[-F6!>W9KXX`(BKD?N#I_V;'1P\C^$EH[R
MI!P![<EV)I1_N8XG"INFJ^&=(GFZQ77KK"^=.Z[R4SB,5;."EJGU*(:\5DR1
MDDR5!3UV5S((PA2Y-!=)GYW3<>O*EJ!S\%G,FOO+/.*Q>JXQK1CW3ZS":_"K
M#[2S>+XHN`[Y,9XF&89'*(JP38`*=D;BO8OEUL-@?HTAAQRLD`7[Z%4X\G/<
MD)DKWRLN>&<+#DS]H^#96/W]586_#D7*O:E.?_</=?F<=+S5Y9Z09,](MWGK
M[P&0/WE,MHF8\PRQ.3M!J3[#&KM7)-Q90]>E!B\1K>_Z!K#](U^3^28[F>A=
M5=7RU[=`3Z56+4:2<$'3:?KZ[.+T]2OBTANN7H6@<,-;L,[L<%VCI6O&Y4T@
M*;FOL0\8@L?*_&??K;>5X5DPNI-@D#[O@GI_&!2->U5V/TBMVV9,I`YX:R5#
M`!0"W?)I,`/P_JU76Y_6[CFQDIP6+T`\./5(%5?J[I3^QXW8Z!%!)A+A(W57
M/?'3J^^#0:<%(.BW3X#`,S]N=[#QEDV2]`Y.KE?34E^W%)&4MU/P`WMQU0_3
M]Y9-VX1UG]ZZ1:;-WL.(FRNG(LY1.H^O.7*Z[4OZSD'HHP06:J<>9#62U2;E
M[GB@7FJ@30$,:=(ZL;2A$(5IA9_:<V;YP'NRX0P'*\A$'D\FO1G^2Z,7I`3?
M5?-YKBD^^J-XIC^_QQ0](<?\6_Z^!1SY'.5.=.EL#<,76QNU&_3?=SE468GN
M=\[JWGSA@T\YZ@I>L92*<(YMXW3-2<,MCVSBO)**:U!P9"\<S.&CA,*QP@=>
MX12@F`UL^,V--[]]C0C/I%!P[V9T]:XT=@)P"$D\5".GVEB`<A+T`A,_'K]T
MDTY]];`O:]O*:UQZ%/QU;3,R>*37OVET/5=?88S4F8V_;W]W:X'[@VTQA^&P
M/?:0)OVSI^U-/2=<6]O%PL)4<NIX6(Q15>[Q]J\PRHEMT[IG(L(#=*OX;Q68
E*Z2QY&1"N6$=8@KS8(RV?.[;7PNDVO$ZWD2C_P?LOVM2X4P``,(#
`
end
end-of-input

gzip -d dc.tar.gz xy.tar.gz makeindex.gz texconfig.gz teTeX-FAQ.gz

upd_dc=false
if test -d $TEXMF/fonts/source/jknappen/dc; then
  (cd $TEXMF; tar xvf -) <dc.tar
  upd_dc=true
fi | sed "s@^@$TEXMF/@"

if test -d $TEXMF/fonts/type1/public/xypic; then
  (cd $TEXMF; tar xvf -) <xy.tar
fi | sed "s@^@$TEXMF/@"

test -f $TEXMF/doc/tetex/teTeX-FAQ && {
  cat teTeX-FAQ > $TEXMF/doc/tetex/teTeX-FAQ
  echo $TEXMF/doc/tetex/teTeX-FAQ
}

files=`(find $TETEXDIR/bin -name makeindex -print 2>/dev/null)`
for i in $files; do
  cat makeindex > $i;
  echo "$i"
done

files=`(find $TETEXDIR/bin -name texconfig -print 2>/dev/null)`
for i in $files; do
  cat texconfig > $i;
  echo "$i"
done

if $upd_dc; then
  cat <<'eof'

The DC/TC font sources have been updated to version 1.3 patchlevel 4.
Now, the following actions are required by you:
- delete all the pk files for these fonts (propably stored in
  texmf/fonts/pk/*/jknappen/{dc,tc})
- delete the tfm files for the sans serif family (including *ss*, *si*,
  *sx*, *so*, *sq*, *qi*, *lq*, *li*, *lb*, *lo*) These files propably
  are stored in texmf/fonts/tfm/jknappen/{dc,tc}.
- optionally run the command 'alldc' to recompute most of the tfm/pk
  files for the DC fonts.
eof
fi
